#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 520
#define LARGE_STATE_COUNT 2
#define SYMBOL_COUNT 148
#define ALIAS_COUNT 0
#define TOKEN_COUNT 64
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 25
#define MAX_ALIAS_SEQUENCE_LENGTH 11
#define PRODUCTION_ID_COUNT 79

enum ts_symbol_identifiers {
  aux_sym_arrow_token1 = 1,
  sym_string = 2,
  sym_ident = 3,
  sym_comment = 4,
  aux_sym_num_token1 = 5,
  sym_weight = 6,
  anon_sym_DOLLAR = 7,
  sym_global_var_prefix = 8,
  sym_global_str_prefix = 9,
  sym_magic = 10,
  anon_sym_COLON = 11,
  anon_sym_LT = 12,
  anon_sym_GT = 13,
  anon_sym_DOT = 14,
  anon_sym_SEMI = 15,
  anon_sym_LBRACK = 16,
  anon_sym_RBRACK = 17,
  anon_sym_COMMA = 18,
  anon_sym_LPAREN = 19,
  anon_sym_RPAREN = 20,
  anon_sym_EQ = 21,
  anon_sym_AT = 22,
  sym_clip_side = 23,
  aux_sym_str_op_eq_token1 = 24,
  aux_sym_str_op_eq_token2 = 25,
  aux_sym_str_op_isprefix_token1 = 26,
  aux_sym_str_op_isprefix_token2 = 27,
  aux_sym_str_op_isprefix_token3 = 28,
  aux_sym_str_op_hasprefix_token1 = 29,
  aux_sym_str_op_hasprefix_token2 = 30,
  aux_sym_str_op_hasprefix_token3 = 31,
  aux_sym_str_op_issuffix_token1 = 32,
  aux_sym_str_op_issuffix_token2 = 33,
  aux_sym_str_op_hassuffix_token1 = 34,
  aux_sym_str_op_hassuffix_token2 = 35,
  aux_sym_str_op_in_token1 = 36,
  aux_sym_str_op_in_token2 = 37,
  aux_sym_str_op_contains_token1 = 38,
  aux_sym_str_op_contains_token2 = 39,
  aux_sym_and_token1 = 40,
  aux_sym_and_token2 = 41,
  aux_sym_or_token1 = 42,
  aux_sym_or_token2 = 43,
  aux_sym_not_token1 = 44,
  aux_sym_not_token2 = 45,
  aux_sym_not_token3 = 46,
  anon_sym_STAR = 47,
  anon_sym_LBRACK2 = 48,
  anon_sym_LPAREN2 = 49,
  anon_sym_AT2 = 50,
  anon_sym_LBRACE = 51,
  anon_sym_RBRACE = 52,
  sym_conjoin = 53,
  sym_blank = 54,
  sym_numbered_blank = 55,
  aux_sym_if_tok_token1 = 56,
  aux_sym_elif_tok_token1 = 57,
  aux_sym_elif_tok_token2 = 58,
  aux_sym_else_tok_token1 = 59,
  aux_sym_else_tok_token2 = 60,
  sym_always_tok = 61,
  anon_sym_PIPE = 62,
  anon_sym_QMARK = 63,
  sym_source_file = 64,
  sym_arrow = 65,
  sym_num = 66,
  sym_attr_prefix = 67,
  sym_colon = 68,
  sym_lit_tag = 69,
  sym_output_rule = 70,
  sym_attr_set_insert = 71,
  sym_attr_pair = 72,
  sym_retag_rule = 73,
  sym_attr_default = 74,
  sym_attr_rule = 75,
  sym_insert = 76,
  sym_inserted = 77,
  sym_clip = 78,
  sym_str_op_eq = 79,
  sym_str_op_isprefix = 80,
  sym_str_op_hasprefix = 81,
  sym_str_op_issuffix = 82,
  sym_str_op_hassuffix = 83,
  sym_str_op_in = 84,
  sym_str_op_contains = 85,
  sym_str_op = 86,
  sym_and = 87,
  sym_or = 88,
  sym_not = 89,
  sym__string_val = 90,
  sym__cond_base_bool = 91,
  sym__cond_bool = 92,
  sym_condition = 93,
  sym_pattern_clip = 94,
  sym_pattern_element = 95,
  sym_unknown = 96,
  sym_set_var = 97,
  sym_output_var_set = 98,
  sym_macro_name = 99,
  sym_literal_lu = 100,
  sym_null_lu = 101,
  sym_output_element = 102,
  sym_if_tok = 103,
  sym_elif_tok = 104,
  sym_else_tok = 105,
  sym_string_always_choice = 106,
  sym_string_if_choice = 107,
  sym_string_elif_choice = 108,
  sym_string_else_choice = 109,
  sym_string_cond = 110,
  sym_chunk_always_choice = 111,
  sym_chunk_if_choice = 112,
  sym_chunk_elif_choice = 113,
  sym_chunk_else_choice = 114,
  sym_chunk_cond = 115,
  sym_lu_always_choice = 116,
  sym_lu_if_choice = 117,
  sym_lu_elif_choice = 118,
  sym_lu_else_choice = 119,
  sym_lu_cond = 120,
  sym_reduce_output = 121,
  sym_output_chunk = 122,
  sym__chunk_val = 123,
  sym__lu_val = 124,
  sym_lu_sequence = 125,
  sym_reduce_rule_group = 126,
  sym_set_surf = 127,
  sym_set_global_var = 128,
  sym_set_global_str = 129,
  sym_set_chunk_attr = 130,
  sym_reduce_rule = 131,
  aux_sym_source_file_repeat1 = 132,
  aux_sym_output_rule_repeat1 = 133,
  aux_sym_retag_rule_repeat1 = 134,
  aux_sym_attr_rule_repeat1 = 135,
  aux_sym_pattern_element_repeat1 = 136,
  aux_sym_output_var_set_repeat1 = 137,
  aux_sym_literal_lu_repeat1 = 138,
  aux_sym_string_cond_repeat1 = 139,
  aux_sym_chunk_cond_repeat1 = 140,
  aux_sym_lu_cond_repeat1 = 141,
  aux_sym_reduce_output_repeat1 = 142,
  aux_sym_output_chunk_repeat1 = 143,
  aux_sym_reduce_rule_group_repeat1 = 144,
  aux_sym_reduce_rule_group_repeat2 = 145,
  aux_sym_reduce_rule_repeat1 = 146,
  aux_sym_reduce_rule_repeat2 = 147,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [aux_sym_arrow_token1] = "arrow_token1",
  [sym_string] = "string",
  [sym_ident] = "ident",
  [sym_comment] = "comment",
  [aux_sym_num_token1] = "num_token1",
  [sym_weight] = "weight",
  [anon_sym_DOLLAR] = "$",
  [sym_global_var_prefix] = "global_var_prefix",
  [sym_global_str_prefix] = "global_str_prefix",
  [sym_magic] = "magic",
  [anon_sym_COLON] = ":",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [anon_sym_DOT] = ".",
  [anon_sym_SEMI] = ";",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_COMMA] = ",",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_EQ] = "=",
  [anon_sym_AT] = "@",
  [sym_clip_side] = "clip_side",
  [aux_sym_str_op_eq_token1] = "str_op_eq_token1",
  [aux_sym_str_op_eq_token2] = "str_op_eq_token2",
  [aux_sym_str_op_isprefix_token1] = "str_op_isprefix_token1",
  [aux_sym_str_op_isprefix_token2] = "str_op_isprefix_token2",
  [aux_sym_str_op_isprefix_token3] = "str_op_isprefix_token3",
  [aux_sym_str_op_hasprefix_token1] = "str_op_hasprefix_token1",
  [aux_sym_str_op_hasprefix_token2] = "str_op_hasprefix_token2",
  [aux_sym_str_op_hasprefix_token3] = "str_op_hasprefix_token3",
  [aux_sym_str_op_issuffix_token1] = "str_op_issuffix_token1",
  [aux_sym_str_op_issuffix_token2] = "str_op_issuffix_token2",
  [aux_sym_str_op_hassuffix_token1] = "str_op_hassuffix_token1",
  [aux_sym_str_op_hassuffix_token2] = "str_op_hassuffix_token2",
  [aux_sym_str_op_in_token1] = "str_op_in_token1",
  [aux_sym_str_op_in_token2] = "str_op_in_token2",
  [aux_sym_str_op_contains_token1] = "str_op_contains_token1",
  [aux_sym_str_op_contains_token2] = "str_op_contains_token2",
  [aux_sym_and_token1] = "and_token1",
  [aux_sym_and_token2] = "and_token2",
  [aux_sym_or_token1] = "or_token1",
  [aux_sym_or_token2] = "or_token2",
  [aux_sym_not_token1] = "not_token1",
  [aux_sym_not_token2] = "not_token2",
  [aux_sym_not_token3] = "not_token3",
  [anon_sym_STAR] = "*",
  [anon_sym_LBRACK2] = "[",
  [anon_sym_LPAREN2] = "(",
  [anon_sym_AT2] = "@",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [sym_conjoin] = "conjoin",
  [sym_blank] = "blank",
  [sym_numbered_blank] = "numbered_blank",
  [aux_sym_if_tok_token1] = "if_tok_token1",
  [aux_sym_elif_tok_token1] = "elif_tok_token1",
  [aux_sym_elif_tok_token2] = "elif_tok_token2",
  [aux_sym_else_tok_token1] = "else_tok_token1",
  [aux_sym_else_tok_token2] = "else_tok_token2",
  [sym_always_tok] = "always_tok",
  [anon_sym_PIPE] = "|",
  [anon_sym_QMARK] = "\?",
  [sym_source_file] = "source_file",
  [sym_arrow] = "arrow",
  [sym_num] = "num",
  [sym_attr_prefix] = "attr_prefix",
  [sym_colon] = "colon",
  [sym_lit_tag] = "lit_tag",
  [sym_output_rule] = "output_rule",
  [sym_attr_set_insert] = "attr_set_insert",
  [sym_attr_pair] = "attr_pair",
  [sym_retag_rule] = "retag_rule",
  [sym_attr_default] = "attr_default",
  [sym_attr_rule] = "attr_rule",
  [sym_insert] = "insert",
  [sym_inserted] = "inserted",
  [sym_clip] = "clip",
  [sym_str_op_eq] = "str_op_eq",
  [sym_str_op_isprefix] = "str_op_isprefix",
  [sym_str_op_hasprefix] = "str_op_hasprefix",
  [sym_str_op_issuffix] = "str_op_issuffix",
  [sym_str_op_hassuffix] = "str_op_hassuffix",
  [sym_str_op_in] = "str_op_in",
  [sym_str_op_contains] = "str_op_contains",
  [sym_str_op] = "str_op",
  [sym_and] = "and",
  [sym_or] = "or",
  [sym_not] = "not",
  [sym__string_val] = "_string_val",
  [sym__cond_base_bool] = "_cond_base_bool",
  [sym__cond_bool] = "_cond_bool",
  [sym_condition] = "condition",
  [sym_pattern_clip] = "pattern_clip",
  [sym_pattern_element] = "pattern_element",
  [sym_unknown] = "unknown",
  [sym_set_var] = "set_var",
  [sym_output_var_set] = "output_var_set",
  [sym_macro_name] = "macro_name",
  [sym_literal_lu] = "literal_lu",
  [sym_null_lu] = "null_lu",
  [sym_output_element] = "output_element",
  [sym_if_tok] = "if_tok",
  [sym_elif_tok] = "elif_tok",
  [sym_else_tok] = "else_tok",
  [sym_string_always_choice] = "choice",
  [sym_string_if_choice] = "choice",
  [sym_string_elif_choice] = "choice",
  [sym_string_else_choice] = "choice",
  [sym_string_cond] = "string_cond",
  [sym_chunk_always_choice] = "choice",
  [sym_chunk_if_choice] = "choice",
  [sym_chunk_elif_choice] = "choice",
  [sym_chunk_else_choice] = "choice",
  [sym_chunk_cond] = "chunk_cond",
  [sym_lu_always_choice] = "choice",
  [sym_lu_if_choice] = "choice",
  [sym_lu_elif_choice] = "choice",
  [sym_lu_else_choice] = "choice",
  [sym_lu_cond] = "lu_cond",
  [sym_reduce_output] = "reduce_output",
  [sym_output_chunk] = "output_chunk",
  [sym__chunk_val] = "_chunk_val",
  [sym__lu_val] = "_lu_val",
  [sym_lu_sequence] = "lu_sequence",
  [sym_reduce_rule_group] = "reduce_rule_group",
  [sym_set_surf] = "set_surf",
  [sym_set_global_var] = "set_global_var",
  [sym_set_global_str] = "set_global_str",
  [sym_set_chunk_attr] = "set_chunk_attr",
  [sym_reduce_rule] = "reduce_rule",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_output_rule_repeat1] = "output_rule_repeat1",
  [aux_sym_retag_rule_repeat1] = "retag_rule_repeat1",
  [aux_sym_attr_rule_repeat1] = "attr_rule_repeat1",
  [aux_sym_pattern_element_repeat1] = "pattern_element_repeat1",
  [aux_sym_output_var_set_repeat1] = "output_var_set_repeat1",
  [aux_sym_literal_lu_repeat1] = "literal_lu_repeat1",
  [aux_sym_string_cond_repeat1] = "string_cond_repeat1",
  [aux_sym_chunk_cond_repeat1] = "chunk_cond_repeat1",
  [aux_sym_lu_cond_repeat1] = "lu_cond_repeat1",
  [aux_sym_reduce_output_repeat1] = "reduce_output_repeat1",
  [aux_sym_output_chunk_repeat1] = "output_chunk_repeat1",
  [aux_sym_reduce_rule_group_repeat1] = "reduce_rule_group_repeat1",
  [aux_sym_reduce_rule_group_repeat2] = "reduce_rule_group_repeat2",
  [aux_sym_reduce_rule_repeat1] = "reduce_rule_repeat1",
  [aux_sym_reduce_rule_repeat2] = "reduce_rule_repeat2",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [aux_sym_arrow_token1] = aux_sym_arrow_token1,
  [sym_string] = sym_string,
  [sym_ident] = sym_ident,
  [sym_comment] = sym_comment,
  [aux_sym_num_token1] = aux_sym_num_token1,
  [sym_weight] = sym_weight,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [sym_global_var_prefix] = sym_global_var_prefix,
  [sym_global_str_prefix] = sym_global_str_prefix,
  [sym_magic] = sym_magic,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_AT] = anon_sym_AT,
  [sym_clip_side] = sym_clip_side,
  [aux_sym_str_op_eq_token1] = aux_sym_str_op_eq_token1,
  [aux_sym_str_op_eq_token2] = aux_sym_str_op_eq_token2,
  [aux_sym_str_op_isprefix_token1] = aux_sym_str_op_isprefix_token1,
  [aux_sym_str_op_isprefix_token2] = aux_sym_str_op_isprefix_token2,
  [aux_sym_str_op_isprefix_token3] = aux_sym_str_op_isprefix_token3,
  [aux_sym_str_op_hasprefix_token1] = aux_sym_str_op_hasprefix_token1,
  [aux_sym_str_op_hasprefix_token2] = aux_sym_str_op_hasprefix_token2,
  [aux_sym_str_op_hasprefix_token3] = aux_sym_str_op_hasprefix_token3,
  [aux_sym_str_op_issuffix_token1] = aux_sym_str_op_issuffix_token1,
  [aux_sym_str_op_issuffix_token2] = aux_sym_str_op_issuffix_token2,
  [aux_sym_str_op_hassuffix_token1] = aux_sym_str_op_hassuffix_token1,
  [aux_sym_str_op_hassuffix_token2] = aux_sym_str_op_hassuffix_token2,
  [aux_sym_str_op_in_token1] = aux_sym_str_op_in_token1,
  [aux_sym_str_op_in_token2] = aux_sym_str_op_in_token2,
  [aux_sym_str_op_contains_token1] = aux_sym_str_op_contains_token1,
  [aux_sym_str_op_contains_token2] = aux_sym_str_op_contains_token2,
  [aux_sym_and_token1] = aux_sym_and_token1,
  [aux_sym_and_token2] = aux_sym_and_token2,
  [aux_sym_or_token1] = aux_sym_or_token1,
  [aux_sym_or_token2] = aux_sym_or_token2,
  [aux_sym_not_token1] = aux_sym_not_token1,
  [aux_sym_not_token2] = aux_sym_not_token2,
  [aux_sym_not_token3] = aux_sym_not_token3,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_LBRACK2] = anon_sym_LBRACK,
  [anon_sym_LPAREN2] = anon_sym_LPAREN,
  [anon_sym_AT2] = anon_sym_AT,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [sym_conjoin] = sym_conjoin,
  [sym_blank] = sym_blank,
  [sym_numbered_blank] = sym_numbered_blank,
  [aux_sym_if_tok_token1] = aux_sym_if_tok_token1,
  [aux_sym_elif_tok_token1] = aux_sym_elif_tok_token1,
  [aux_sym_elif_tok_token2] = aux_sym_elif_tok_token2,
  [aux_sym_else_tok_token1] = aux_sym_else_tok_token1,
  [aux_sym_else_tok_token2] = aux_sym_else_tok_token2,
  [sym_always_tok] = sym_always_tok,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [sym_source_file] = sym_source_file,
  [sym_arrow] = sym_arrow,
  [sym_num] = sym_num,
  [sym_attr_prefix] = sym_attr_prefix,
  [sym_colon] = sym_colon,
  [sym_lit_tag] = sym_lit_tag,
  [sym_output_rule] = sym_output_rule,
  [sym_attr_set_insert] = sym_attr_set_insert,
  [sym_attr_pair] = sym_attr_pair,
  [sym_retag_rule] = sym_retag_rule,
  [sym_attr_default] = sym_attr_default,
  [sym_attr_rule] = sym_attr_rule,
  [sym_insert] = sym_insert,
  [sym_inserted] = sym_inserted,
  [sym_clip] = sym_clip,
  [sym_str_op_eq] = sym_str_op_eq,
  [sym_str_op_isprefix] = sym_str_op_isprefix,
  [sym_str_op_hasprefix] = sym_str_op_hasprefix,
  [sym_str_op_issuffix] = sym_str_op_issuffix,
  [sym_str_op_hassuffix] = sym_str_op_hassuffix,
  [sym_str_op_in] = sym_str_op_in,
  [sym_str_op_contains] = sym_str_op_contains,
  [sym_str_op] = sym_str_op,
  [sym_and] = sym_and,
  [sym_or] = sym_or,
  [sym_not] = sym_not,
  [sym__string_val] = sym__string_val,
  [sym__cond_base_bool] = sym__cond_base_bool,
  [sym__cond_bool] = sym__cond_bool,
  [sym_condition] = sym_condition,
  [sym_pattern_clip] = sym_pattern_clip,
  [sym_pattern_element] = sym_pattern_element,
  [sym_unknown] = sym_unknown,
  [sym_set_var] = sym_set_var,
  [sym_output_var_set] = sym_output_var_set,
  [sym_macro_name] = sym_macro_name,
  [sym_literal_lu] = sym_literal_lu,
  [sym_null_lu] = sym_null_lu,
  [sym_output_element] = sym_output_element,
  [sym_if_tok] = sym_if_tok,
  [sym_elif_tok] = sym_elif_tok,
  [sym_else_tok] = sym_else_tok,
  [sym_string_always_choice] = sym_string_always_choice,
  [sym_string_if_choice] = sym_string_always_choice,
  [sym_string_elif_choice] = sym_string_always_choice,
  [sym_string_else_choice] = sym_string_always_choice,
  [sym_string_cond] = sym_string_cond,
  [sym_chunk_always_choice] = sym_string_always_choice,
  [sym_chunk_if_choice] = sym_string_always_choice,
  [sym_chunk_elif_choice] = sym_string_always_choice,
  [sym_chunk_else_choice] = sym_string_always_choice,
  [sym_chunk_cond] = sym_chunk_cond,
  [sym_lu_always_choice] = sym_string_always_choice,
  [sym_lu_if_choice] = sym_string_always_choice,
  [sym_lu_elif_choice] = sym_string_always_choice,
  [sym_lu_else_choice] = sym_string_always_choice,
  [sym_lu_cond] = sym_lu_cond,
  [sym_reduce_output] = sym_reduce_output,
  [sym_output_chunk] = sym_output_chunk,
  [sym__chunk_val] = sym__chunk_val,
  [sym__lu_val] = sym__lu_val,
  [sym_lu_sequence] = sym_lu_sequence,
  [sym_reduce_rule_group] = sym_reduce_rule_group,
  [sym_set_surf] = sym_set_surf,
  [sym_set_global_var] = sym_set_global_var,
  [sym_set_global_str] = sym_set_global_str,
  [sym_set_chunk_attr] = sym_set_chunk_attr,
  [sym_reduce_rule] = sym_reduce_rule,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_output_rule_repeat1] = aux_sym_output_rule_repeat1,
  [aux_sym_retag_rule_repeat1] = aux_sym_retag_rule_repeat1,
  [aux_sym_attr_rule_repeat1] = aux_sym_attr_rule_repeat1,
  [aux_sym_pattern_element_repeat1] = aux_sym_pattern_element_repeat1,
  [aux_sym_output_var_set_repeat1] = aux_sym_output_var_set_repeat1,
  [aux_sym_literal_lu_repeat1] = aux_sym_literal_lu_repeat1,
  [aux_sym_string_cond_repeat1] = aux_sym_string_cond_repeat1,
  [aux_sym_chunk_cond_repeat1] = aux_sym_chunk_cond_repeat1,
  [aux_sym_lu_cond_repeat1] = aux_sym_lu_cond_repeat1,
  [aux_sym_reduce_output_repeat1] = aux_sym_reduce_output_repeat1,
  [aux_sym_output_chunk_repeat1] = aux_sym_output_chunk_repeat1,
  [aux_sym_reduce_rule_group_repeat1] = aux_sym_reduce_rule_group_repeat1,
  [aux_sym_reduce_rule_group_repeat2] = aux_sym_reduce_rule_group_repeat2,
  [aux_sym_reduce_rule_repeat1] = aux_sym_reduce_rule_repeat1,
  [aux_sym_reduce_rule_repeat2] = aux_sym_reduce_rule_repeat2,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [aux_sym_arrow_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_ident] = {
    .visible = true,
    .named = true,
  },
  [sym_comment] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_num_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_weight] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [sym_global_var_prefix] = {
    .visible = true,
    .named = true,
  },
  [sym_global_str_prefix] = {
    .visible = true,
    .named = true,
  },
  [sym_magic] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [sym_clip_side] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_str_op_eq_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_eq_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_isprefix_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_isprefix_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_isprefix_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_hasprefix_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_hasprefix_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_hasprefix_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_issuffix_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_issuffix_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_hassuffix_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_hassuffix_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_in_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_in_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_contains_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_str_op_contains_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_and_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_and_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_or_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_or_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_not_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_not_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_not_token3] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [sym_conjoin] = {
    .visible = true,
    .named = true,
  },
  [sym_blank] = {
    .visible = true,
    .named = true,
  },
  [sym_numbered_blank] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_if_tok_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_elif_tok_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_elif_tok_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_else_tok_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_else_tok_token2] = {
    .visible = false,
    .named = false,
  },
  [sym_always_tok] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_arrow] = {
    .visible = true,
    .named = true,
  },
  [sym_num] = {
    .visible = true,
    .named = true,
  },
  [sym_attr_prefix] = {
    .visible = true,
    .named = true,
  },
  [sym_colon] = {
    .visible = true,
    .named = true,
  },
  [sym_lit_tag] = {
    .visible = true,
    .named = true,
  },
  [sym_output_rule] = {
    .visible = true,
    .named = true,
  },
  [sym_attr_set_insert] = {
    .visible = true,
    .named = true,
  },
  [sym_attr_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_retag_rule] = {
    .visible = true,
    .named = true,
  },
  [sym_attr_default] = {
    .visible = true,
    .named = true,
  },
  [sym_attr_rule] = {
    .visible = true,
    .named = true,
  },
  [sym_insert] = {
    .visible = true,
    .named = true,
  },
  [sym_inserted] = {
    .visible = true,
    .named = true,
  },
  [sym_clip] = {
    .visible = true,
    .named = true,
  },
  [sym_str_op_eq] = {
    .visible = true,
    .named = true,
  },
  [sym_str_op_isprefix] = {
    .visible = true,
    .named = true,
  },
  [sym_str_op_hasprefix] = {
    .visible = true,
    .named = true,
  },
  [sym_str_op_issuffix] = {
    .visible = true,
    .named = true,
  },
  [sym_str_op_hassuffix] = {
    .visible = true,
    .named = true,
  },
  [sym_str_op_in] = {
    .visible = true,
    .named = true,
  },
  [sym_str_op_contains] = {
    .visible = true,
    .named = true,
  },
  [sym_str_op] = {
    .visible = true,
    .named = true,
  },
  [sym_and] = {
    .visible = true,
    .named = true,
  },
  [sym_or] = {
    .visible = true,
    .named = true,
  },
  [sym_not] = {
    .visible = true,
    .named = true,
  },
  [sym__string_val] = {
    .visible = false,
    .named = true,
  },
  [sym__cond_base_bool] = {
    .visible = false,
    .named = true,
  },
  [sym__cond_bool] = {
    .visible = false,
    .named = true,
  },
  [sym_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern_clip] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern_element] = {
    .visible = true,
    .named = true,
  },
  [sym_unknown] = {
    .visible = true,
    .named = true,
  },
  [sym_set_var] = {
    .visible = true,
    .named = true,
  },
  [sym_output_var_set] = {
    .visible = true,
    .named = true,
  },
  [sym_macro_name] = {
    .visible = true,
    .named = true,
  },
  [sym_literal_lu] = {
    .visible = true,
    .named = true,
  },
  [sym_null_lu] = {
    .visible = true,
    .named = true,
  },
  [sym_output_element] = {
    .visible = true,
    .named = true,
  },
  [sym_if_tok] = {
    .visible = true,
    .named = true,
  },
  [sym_elif_tok] = {
    .visible = true,
    .named = true,
  },
  [sym_else_tok] = {
    .visible = true,
    .named = true,
  },
  [sym_string_always_choice] = {
    .visible = true,
    .named = true,
  },
  [sym_string_if_choice] = {
    .visible = true,
    .named = true,
  },
  [sym_string_elif_choice] = {
    .visible = true,
    .named = true,
  },
  [sym_string_else_choice] = {
    .visible = true,
    .named = true,
  },
  [sym_string_cond] = {
    .visible = true,
    .named = true,
  },
  [sym_chunk_always_choice] = {
    .visible = true,
    .named = true,
  },
  [sym_chunk_if_choice] = {
    .visible = true,
    .named = true,
  },
  [sym_chunk_elif_choice] = {
    .visible = true,
    .named = true,
  },
  [sym_chunk_else_choice] = {
    .visible = true,
    .named = true,
  },
  [sym_chunk_cond] = {
    .visible = true,
    .named = true,
  },
  [sym_lu_always_choice] = {
    .visible = true,
    .named = true,
  },
  [sym_lu_if_choice] = {
    .visible = true,
    .named = true,
  },
  [sym_lu_elif_choice] = {
    .visible = true,
    .named = true,
  },
  [sym_lu_else_choice] = {
    .visible = true,
    .named = true,
  },
  [sym_lu_cond] = {
    .visible = true,
    .named = true,
  },
  [sym_reduce_output] = {
    .visible = true,
    .named = true,
  },
  [sym_output_chunk] = {
    .visible = true,
    .named = true,
  },
  [sym__chunk_val] = {
    .visible = false,
    .named = true,
  },
  [sym__lu_val] = {
    .visible = false,
    .named = true,
  },
  [sym_lu_sequence] = {
    .visible = true,
    .named = true,
  },
  [sym_reduce_rule_group] = {
    .visible = true,
    .named = true,
  },
  [sym_set_surf] = {
    .visible = true,
    .named = true,
  },
  [sym_set_global_var] = {
    .visible = true,
    .named = true,
  },
  [sym_set_global_str] = {
    .visible = true,
    .named = true,
  },
  [sym_set_chunk_attr] = {
    .visible = true,
    .named = true,
  },
  [sym_reduce_rule] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_output_rule_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_retag_rule_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attr_rule_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_pattern_element_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_output_var_set_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_literal_lu_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_cond_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_chunk_cond_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_lu_cond_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_reduce_output_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_output_chunk_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_reduce_rule_group_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_reduce_rule_group_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_reduce_rule_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_reduce_rule_repeat2] = {
    .visible = false,
    .named = false,
  },
};

enum ts_field_identifiers {
  field_attr = 1,
  field_complex_tag = 2,
  field_cond = 3,
  field_convert = 4,
  field_inserted = 5,
  field_lemcase = 6,
  field_lemma = 7,
  field_lit_tag = 8,
  field_name = 9,
  field_output = 10,
  field_parent_tag = 11,
  field_pattern = 12,
  field_pos = 13,
  field_rule_name = 14,
  field_side = 15,
  field_src = 16,
  field_src_attr = 17,
  field_trg = 18,
  field_trg_attr = 19,
  field_type = 20,
  field_val = 21,
  field_value = 22,
  field_var_name = 23,
  field_vars = 24,
  field_weight = 25,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_attr] = "attr",
  [field_complex_tag] = "complex_tag",
  [field_cond] = "cond",
  [field_convert] = "convert",
  [field_inserted] = "inserted",
  [field_lemcase] = "lemcase",
  [field_lemma] = "lemma",
  [field_lit_tag] = "lit_tag",
  [field_name] = "name",
  [field_output] = "output",
  [field_parent_tag] = "parent_tag",
  [field_pattern] = "pattern",
  [field_pos] = "pos",
  [field_rule_name] = "rule_name",
  [field_side] = "side",
  [field_src] = "src",
  [field_src_attr] = "src_attr",
  [field_trg] = "trg",
  [field_trg_attr] = "trg_attr",
  [field_type] = "type",
  [field_val] = "val",
  [field_value] = "value",
  [field_var_name] = "var_name",
  [field_vars] = "vars",
  [field_weight] = "weight",
};

static const TSFieldMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 1},
  [4] = {.index = 3, .length = 2},
  [5] = {.index = 5, .length = 2},
  [6] = {.index = 7, .length = 2},
  [7] = {.index = 9, .length = 3},
  [8] = {.index = 12, .length = 2},
  [9] = {.index = 14, .length = 2},
  [10] = {.index = 16, .length = 2},
  [11] = {.index = 18, .length = 1},
  [12] = {.index = 19, .length = 3},
  [13] = {.index = 22, .length = 4},
  [14] = {.index = 26, .length = 2},
  [15] = {.index = 28, .length = 3},
  [16] = {.index = 31, .length = 4},
  [17] = {.index = 35, .length = 2},
  [18] = {.index = 37, .length = 1},
  [19] = {.index = 38, .length = 2},
  [20] = {.index = 40, .length = 5},
  [21] = {.index = 45, .length = 5},
  [22] = {.index = 50, .length = 3},
  [23] = {.index = 53, .length = 2},
  [24] = {.index = 55, .length = 3},
  [25] = {.index = 58, .length = 6},
  [26] = {.index = 64, .length = 3},
  [27] = {.index = 67, .length = 2},
  [28] = {.index = 69, .length = 3},
  [29] = {.index = 72, .length = 3},
  [30] = {.index = 75, .length = 6},
  [31] = {.index = 81, .length = 2},
  [32] = {.index = 83, .length = 2},
  [33] = {.index = 85, .length = 2},
  [34] = {.index = 87, .length = 1},
  [35] = {.index = 88, .length = 7},
  [36] = {.index = 95, .length = 8},
  [37] = {.index = 103, .length = 4},
  [38] = {.index = 107, .length = 7},
  [39] = {.index = 114, .length = 4},
  [40] = {.index = 118, .length = 4},
  [41] = {.index = 122, .length = 2},
  [42] = {.index = 124, .length = 3},
  [43] = {.index = 127, .length = 3},
  [44] = {.index = 130, .length = 3},
  [45] = {.index = 133, .length = 7},
  [46] = {.index = 140, .length = 3},
  [47] = {.index = 143, .length = 4},
  [48] = {.index = 147, .length = 2},
  [49] = {.index = 149, .length = 4},
  [50] = {.index = 153, .length = 2},
  [51] = {.index = 155, .length = 8},
  [52] = {.index = 163, .length = 5},
  [53] = {.index = 168, .length = 8},
  [54] = {.index = 176, .length = 5},
  [55] = {.index = 181, .length = 8},
  [56] = {.index = 189, .length = 3},
  [57] = {.index = 192, .length = 3},
  [58] = {.index = 195, .length = 4},
  [59] = {.index = 199, .length = 4},
  [60] = {.index = 203, .length = 5},
  [61] = {.index = 208, .length = 5},
  [62] = {.index = 213, .length = 4},
  [63] = {.index = 217, .length = 4},
  [64] = {.index = 221, .length = 3},
  [65] = {.index = 224, .length = 3},
  [66] = {.index = 227, .length = 9},
  [67] = {.index = 236, .length = 9},
  [68] = {.index = 245, .length = 3},
  [69] = {.index = 248, .length = 4},
  [70] = {.index = 252, .length = 4},
  [71] = {.index = 256, .length = 5},
  [72] = {.index = 261, .length = 5},
  [73] = {.index = 266, .length = 6},
  [74] = {.index = 272, .length = 4},
  [75] = {.index = 276, .length = 5},
  [76] = {.index = 281, .length = 7},
  [77] = {.index = 288, .length = 6},
  [78] = {.index = 294, .length = 7},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_pos, 0},
  [1] =
    {field_name, 0},
  [2] =
    {field_pos, 1},
  [3] =
    {field_output, 1},
    {field_pattern, 0},
  [5] =
    {field_type, 0},
    {field_value, 1},
  [7] =
    {field_lemma, 0},
    {field_pos, 2},
  [9] =
    {field_output, 2},
    {field_pattern, 1},
    {field_rule_name, 0},
  [12] =
    {field_src, 0},
    {field_trg, 1},
  [14] =
    {field_src_attr, 0},
    {field_trg_attr, 2},
  [16] =
    {field_src, 1},
    {field_trg, 2},
  [18] =
    {field_val, 0},
  [19] =
    {field_cond, 1},
    {field_type, 0},
    {field_value, 2},
  [22] =
    {field_output, 3},
    {field_pattern, 2},
    {field_weight, 0},
    {field_weight, 1},
  [26] =
    {field_lemma, 1},
    {field_pos, 3},
  [28] =
    {field_lemma, 0},
    {field_lemma, 1},
    {field_pos, 3},
  [31] =
    {field_cond, 1},
    {field_cond, 2},
    {field_output, 3},
    {field_pattern, 0},
  [35] =
    {field_lemma, 0},
    {field_lit_tag, 2},
  [37] =
    {field_var_name, 1},
  [38] =
    {field_attr, 1},
    {field_pos, 0},
  [40] =
    {field_output, 4},
    {field_pattern, 3},
    {field_rule_name, 0},
    {field_weight, 1},
    {field_weight, 2},
  [45] =
    {field_cond, 2},
    {field_cond, 3},
    {field_output, 4},
    {field_pattern, 1},
    {field_rule_name, 0},
  [50] =
    {field_lemma, 1},
    {field_lemma, 2},
    {field_pos, 4},
  [53] =
    {field_output, 4},
    {field_pattern, 0},
  [55] =
    {field_lemma, 0},
    {field_lit_tag, 2},
    {field_vars, 3},
  [58] =
    {field_complex_tag, 3, .inherited = true},
    {field_lemcase, 3, .inherited = true},
    {field_lemma, 0},
    {field_lit_tag, 2},
    {field_lit_tag, 3, .inherited = true},
    {field_parent_tag, 3, .inherited = true},
  [64] =
    {field_lemma, 0},
    {field_parent_tag, 2},
    {field_parent_tag, 3},
  [67] =
    {field_attr, 2},
    {field_pos, 0},
  [69] =
    {field_attr, 1},
    {field_pos, 0},
    {field_side, 2},
  [72] =
    {field_output, 5},
    {field_pattern, 1},
    {field_rule_name, 0},
  [75] =
    {field_cond, 3},
    {field_cond, 4},
    {field_output, 5},
    {field_pattern, 2},
    {field_weight, 0},
    {field_weight, 1},
  [81] =
    {field_name, 1},
    {field_value, 3},
  [83] =
    {field_output, 5},
    {field_pattern, 0},
  [85] =
    {field_name, 0},
    {field_value, 2},
  [87] =
    {field_lit_tag, 1},
  [88] =
    {field_complex_tag, 3, .inherited = true},
    {field_lemcase, 3, .inherited = true},
    {field_lemma, 0},
    {field_lit_tag, 2},
    {field_lit_tag, 3, .inherited = true},
    {field_parent_tag, 3, .inherited = true},
    {field_vars, 4},
  [95] =
    {field_complex_tag, 0, .inherited = true},
    {field_complex_tag, 1, .inherited = true},
    {field_lemcase, 0, .inherited = true},
    {field_lemcase, 1, .inherited = true},
    {field_lit_tag, 0, .inherited = true},
    {field_lit_tag, 1, .inherited = true},
    {field_parent_tag, 0, .inherited = true},
    {field_parent_tag, 1, .inherited = true},
  [103] =
    {field_lemma, 0},
    {field_parent_tag, 2},
    {field_parent_tag, 3},
    {field_vars, 4},
  [107] =
    {field_complex_tag, 4, .inherited = true},
    {field_lemcase, 4, .inherited = true},
    {field_lemma, 0},
    {field_lit_tag, 4, .inherited = true},
    {field_parent_tag, 2},
    {field_parent_tag, 3},
    {field_parent_tag, 4, .inherited = true},
  [114] =
    {field_complex_tag, 2},
    {field_complex_tag, 3},
    {field_complex_tag, 4},
    {field_lemma, 0},
  [118] =
    {field_lemcase, 2},
    {field_lemcase, 3},
    {field_lemcase, 4},
    {field_lemma, 0},
  [122] =
    {field_attr, 3},
    {field_var_name, 1},
  [124] =
    {field_attr, 2},
    {field_pos, 0},
    {field_side, 3},
  [127] =
    {field_attr, 1},
    {field_convert, 3},
    {field_pos, 0},
  [130] =
    {field_attr, 3},
    {field_inserted, 0},
    {field_pos, 1},
  [133] =
    {field_cond, 4},
    {field_cond, 5},
    {field_output, 6},
    {field_pattern, 3},
    {field_rule_name, 0},
    {field_weight, 1},
    {field_weight, 2},
  [140] =
    {field_output, 6},
    {field_pattern, 1},
    {field_rule_name, 0},
  [143] =
    {field_output, 6},
    {field_pattern, 2},
    {field_weight, 0},
    {field_weight, 1},
  [147] =
    {field_pos, 1},
    {field_side, 2},
  [149] =
    {field_cond, 1},
    {field_cond, 2},
    {field_output, 6},
    {field_pattern, 0},
  [153] =
    {field_parent_tag, 1},
    {field_parent_tag, 2},
  [155] =
    {field_complex_tag, 4, .inherited = true},
    {field_lemcase, 4, .inherited = true},
    {field_lemma, 0},
    {field_lit_tag, 4, .inherited = true},
    {field_parent_tag, 2},
    {field_parent_tag, 3},
    {field_parent_tag, 4, .inherited = true},
    {field_vars, 5},
  [163] =
    {field_complex_tag, 2},
    {field_complex_tag, 3},
    {field_complex_tag, 4},
    {field_lemma, 0},
    {field_vars, 5},
  [168] =
    {field_complex_tag, 2},
    {field_complex_tag, 3},
    {field_complex_tag, 4},
    {field_complex_tag, 5, .inherited = true},
    {field_lemcase, 5, .inherited = true},
    {field_lemma, 0},
    {field_lit_tag, 5, .inherited = true},
    {field_parent_tag, 5, .inherited = true},
  [176] =
    {field_lemcase, 2},
    {field_lemcase, 3},
    {field_lemcase, 4},
    {field_lemma, 0},
    {field_vars, 5},
  [181] =
    {field_complex_tag, 5, .inherited = true},
    {field_lemcase, 2},
    {field_lemcase, 3},
    {field_lemcase, 4},
    {field_lemcase, 5, .inherited = true},
    {field_lemma, 0},
    {field_lit_tag, 5, .inherited = true},
    {field_parent_tag, 5, .inherited = true},
  [189] =
    {field_attr, 3},
    {field_side, 4},
    {field_var_name, 1},
  [192] =
    {field_attr, 2},
    {field_convert, 4},
    {field_pos, 0},
  [195] =
    {field_attr, 1},
    {field_convert, 4},
    {field_pos, 0},
    {field_side, 2},
  [199] =
    {field_attr, 3},
    {field_inserted, 0},
    {field_pos, 1},
    {field_side, 4},
  [203] =
    {field_output, 7},
    {field_pattern, 3},
    {field_rule_name, 0},
    {field_weight, 1},
    {field_weight, 2},
  [208] =
    {field_cond, 2},
    {field_cond, 3},
    {field_output, 7},
    {field_pattern, 1},
    {field_rule_name, 0},
  [213] =
    {field_output, 7},
    {field_pattern, 2},
    {field_weight, 0},
    {field_weight, 1},
  [217] =
    {field_cond, 1},
    {field_cond, 2},
    {field_output, 7},
    {field_pattern, 0},
  [221] =
    {field_complex_tag, 1},
    {field_complex_tag, 2},
    {field_complex_tag, 3},
  [224] =
    {field_lemcase, 1},
    {field_lemcase, 2},
    {field_lemcase, 3},
  [227] =
    {field_complex_tag, 2},
    {field_complex_tag, 3},
    {field_complex_tag, 4},
    {field_complex_tag, 5, .inherited = true},
    {field_lemcase, 5, .inherited = true},
    {field_lemma, 0},
    {field_lit_tag, 5, .inherited = true},
    {field_parent_tag, 5, .inherited = true},
    {field_vars, 6},
  [236] =
    {field_complex_tag, 5, .inherited = true},
    {field_lemcase, 2},
    {field_lemcase, 3},
    {field_lemcase, 4},
    {field_lemcase, 5, .inherited = true},
    {field_lemma, 0},
    {field_lit_tag, 5, .inherited = true},
    {field_parent_tag, 5, .inherited = true},
    {field_vars, 6},
  [245] =
    {field_attr, 3},
    {field_convert, 5},
    {field_var_name, 1},
  [248] =
    {field_attr, 2},
    {field_convert, 5},
    {field_pos, 0},
    {field_side, 3},
  [252] =
    {field_attr, 3},
    {field_convert, 5},
    {field_inserted, 0},
    {field_pos, 1},
  [256] =
    {field_output, 8},
    {field_pattern, 3},
    {field_rule_name, 0},
    {field_weight, 1},
    {field_weight, 2},
  [261] =
    {field_cond, 2},
    {field_cond, 3},
    {field_output, 8},
    {field_pattern, 1},
    {field_rule_name, 0},
  [266] =
    {field_cond, 3},
    {field_cond, 4},
    {field_output, 8},
    {field_pattern, 2},
    {field_weight, 0},
    {field_weight, 1},
  [272] =
    {field_attr, 3},
    {field_convert, 6},
    {field_side, 4},
    {field_var_name, 1},
  [276] =
    {field_attr, 3},
    {field_convert, 6},
    {field_inserted, 0},
    {field_pos, 1},
    {field_side, 4},
  [281] =
    {field_cond, 4},
    {field_cond, 5},
    {field_output, 9},
    {field_pattern, 3},
    {field_rule_name, 0},
    {field_weight, 1},
    {field_weight, 2},
  [288] =
    {field_cond, 3},
    {field_cond, 4},
    {field_output, 9},
    {field_pattern, 2},
    {field_weight, 0},
    {field_weight, 1},
  [294] =
    {field_cond, 4},
    {field_cond, 5},
    {field_output, 10},
    {field_pattern, 3},
    {field_rule_name, 0},
    {field_weight, 1},
    {field_weight, 2},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
};

static const uint16_t ts_non_terminal_alias_map[] = {
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 34,
  [37] = 33,
  [38] = 35,
  [39] = 32,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 68,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 91,
  [92] = 92,
  [93] = 93,
  [94] = 94,
  [95] = 95,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 100,
  [101] = 101,
  [102] = 102,
  [103] = 103,
  [104] = 104,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 117,
  [118] = 118,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 126,
  [128] = 125,
  [129] = 129,
  [130] = 130,
  [131] = 131,
  [132] = 132,
  [133] = 103,
  [134] = 134,
  [135] = 135,
  [136] = 136,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 40,
  [153] = 142,
  [154] = 41,
  [155] = 143,
  [156] = 147,
  [157] = 135,
  [158] = 141,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 53,
  [166] = 48,
  [167] = 59,
  [168] = 60,
  [169] = 45,
  [170] = 46,
  [171] = 47,
  [172] = 51,
  [173] = 50,
  [174] = 54,
  [175] = 52,
  [176] = 161,
  [177] = 55,
  [178] = 164,
  [179] = 179,
  [180] = 180,
  [181] = 181,
  [182] = 182,
  [183] = 183,
  [184] = 184,
  [185] = 185,
  [186] = 186,
  [187] = 61,
  [188] = 188,
  [189] = 189,
  [190] = 190,
  [191] = 42,
  [192] = 66,
  [193] = 193,
  [194] = 119,
  [195] = 65,
  [196] = 196,
  [197] = 63,
  [198] = 198,
  [199] = 110,
  [200] = 200,
  [201] = 71,
  [202] = 64,
  [203] = 203,
  [204] = 62,
  [205] = 69,
  [206] = 206,
  [207] = 72,
  [208] = 73,
  [209] = 209,
  [210] = 210,
  [211] = 211,
  [212] = 212,
  [213] = 213,
  [214] = 214,
  [215] = 215,
  [216] = 216,
  [217] = 217,
  [218] = 218,
  [219] = 219,
  [220] = 220,
  [221] = 221,
  [222] = 222,
  [223] = 223,
  [224] = 78,
  [225] = 225,
  [226] = 226,
  [227] = 227,
  [228] = 218,
  [229] = 229,
  [230] = 230,
  [231] = 227,
  [232] = 226,
  [233] = 233,
  [234] = 230,
  [235] = 96,
  [236] = 90,
  [237] = 100,
  [238] = 238,
  [239] = 239,
  [240] = 82,
  [241] = 241,
  [242] = 81,
  [243] = 243,
  [244] = 83,
  [245] = 245,
  [246] = 246,
  [247] = 241,
  [248] = 93,
  [249] = 77,
  [250] = 91,
  [251] = 84,
  [252] = 85,
  [253] = 105,
  [254] = 87,
  [255] = 255,
  [256] = 88,
  [257] = 80,
  [258] = 99,
  [259] = 97,
  [260] = 94,
  [261] = 76,
  [262] = 98,
  [263] = 263,
  [264] = 264,
  [265] = 86,
  [266] = 79,
  [267] = 89,
  [268] = 101,
  [269] = 269,
  [270] = 92,
  [271] = 264,
  [272] = 95,
  [273] = 273,
  [274] = 274,
  [275] = 275,
  [276] = 263,
  [277] = 277,
  [278] = 278,
  [279] = 279,
  [280] = 280,
  [281] = 278,
  [282] = 282,
  [283] = 283,
  [284] = 284,
  [285] = 285,
  [286] = 163,
  [287] = 287,
  [288] = 288,
  [289] = 289,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 294,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 285,
  [299] = 299,
  [300] = 300,
  [301] = 301,
  [302] = 301,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 306,
  [307] = 307,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 313,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 335,
  [336] = 336,
  [337] = 337,
  [338] = 338,
  [339] = 339,
  [340] = 340,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 347,
  [348] = 348,
  [349] = 349,
  [350] = 350,
  [351] = 329,
  [352] = 338,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 358,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 362,
  [363] = 363,
  [364] = 364,
  [365] = 365,
  [366] = 366,
  [367] = 367,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 371,
  [372] = 372,
  [373] = 373,
  [374] = 374,
  [375] = 375,
  [376] = 376,
  [377] = 377,
  [378] = 378,
  [379] = 379,
  [380] = 380,
  [381] = 381,
  [382] = 382,
  [383] = 383,
  [384] = 384,
  [385] = 385,
  [386] = 386,
  [387] = 387,
  [388] = 388,
  [389] = 389,
  [390] = 390,
  [391] = 391,
  [392] = 392,
  [393] = 393,
  [394] = 394,
  [395] = 395,
  [396] = 396,
  [397] = 397,
  [398] = 398,
  [399] = 399,
  [400] = 400,
  [401] = 401,
  [402] = 402,
  [403] = 403,
  [404] = 404,
  [405] = 405,
  [406] = 406,
  [407] = 407,
  [408] = 408,
  [409] = 409,
  [410] = 410,
  [411] = 411,
  [412] = 412,
  [413] = 413,
  [414] = 414,
  [415] = 415,
  [416] = 416,
  [417] = 417,
  [418] = 418,
  [419] = 418,
  [420] = 420,
  [421] = 421,
  [422] = 422,
  [423] = 423,
  [424] = 424,
  [425] = 425,
  [426] = 426,
  [427] = 427,
  [428] = 428,
  [429] = 429,
  [430] = 430,
  [431] = 431,
  [432] = 432,
  [433] = 433,
  [434] = 434,
  [435] = 435,
  [436] = 436,
  [437] = 437,
  [438] = 438,
  [439] = 439,
  [440] = 440,
  [441] = 441,
  [442] = 442,
  [443] = 443,
  [444] = 444,
  [445] = 445,
  [446] = 446,
  [447] = 447,
  [448] = 448,
  [449] = 449,
  [450] = 450,
  [451] = 451,
  [452] = 452,
  [453] = 453,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 457,
  [458] = 458,
  [459] = 459,
  [460] = 460,
  [461] = 461,
  [462] = 462,
  [463] = 463,
  [464] = 464,
  [465] = 465,
  [466] = 466,
  [467] = 467,
  [468] = 468,
  [469] = 469,
  [470] = 470,
  [471] = 471,
  [472] = 472,
  [473] = 473,
  [474] = 474,
  [475] = 475,
  [476] = 476,
  [477] = 477,
  [478] = 478,
  [479] = 427,
  [480] = 452,
  [481] = 481,
  [482] = 449,
  [483] = 483,
  [484] = 442,
  [485] = 485,
  [486] = 478,
  [487] = 487,
  [488] = 488,
  [489] = 489,
  [490] = 490,
  [491] = 491,
  [492] = 463,
  [493] = 493,
  [494] = 462,
  [495] = 440,
  [496] = 496,
  [497] = 497,
  [498] = 498,
  [499] = 424,
  [500] = 426,
  [501] = 497,
  [502] = 502,
  [503] = 503,
  [504] = 504,
  [505] = 505,
  [506] = 429,
  [507] = 428,
  [508] = 432,
  [509] = 491,
  [510] = 510,
  [511] = 511,
  [512] = 512,
  [513] = 505,
  [514] = 511,
  [515] = 515,
  [516] = 504,
  [517] = 517,
  [518] = 518,
  [519] = 519,
};

static TSCharacterRange sym_ident_character_set_1[] = {
  {0, 0x08}, {0x0e, 0x1f}, {'#', '#'}, {'&', '\''}, {'*', '+'}, {'-', '-'}, {'?', '?'}, {'A', 'Z'},
  {'\\', '\\'}, {'^', 'z'}, {'~', 0x2191}, {0x2193, 0x10ffff},
};

static TSCharacterRange sym_ident_character_set_2[] = {
  {0, 0x08}, {0x0e, 0x1f}, {'"', '#'}, {'&', '\''}, {'*', '+'}, {'-', '-'}, {'0', '9'}, {'?', '?'},
  {'A', 'Z'}, {'\\', '\\'}, {'^', 'z'}, {'~', 0x2191}, {0x2193, 0x10ffff},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(314);
      ADVANCE_MAP(
        '!', 333,
        '"', 13,
        '$', 338,
        '%', 341,
        '(', 410,
        ')', 351,
        '*', 408,
        '+', 414,
        ',', 349,
        '-', 318,
        '.', 345,
        '/', 20,
        ':', 342,
        ';', 346,
        '<', 343,
        '=', 352,
        '>', 344,
        '?', 423,
        '@', 411,
        '[', 409,
        '\\', 330,
        ']', 348,
        '_', 415,
        '{', 412,
        '|', 422,
        '}', 413,
        0x2192, 315,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(312);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(334);
      if (lookahead != 0) ADVANCE(331);
      END_STATE();
    case 1:
      ADVANCE_MAP(
        '!', 333,
        '"', 13,
        '$', 338,
        '(', 350,
        '>', 344,
        '\\', 330,
        '~', 406,
        0x2310, 407,
        '-', 319,
        '_', 319,
        'A', 320,
        'a', 320,
        'I', 321,
        'i', 321,
        'N', 322,
        'n', 322,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(334);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '!', 333,
        '"', 13,
        '$', 15,
        '%', 341,
        '(', 410,
        ')', 351,
        '*', 408,
        '+', 414,
        ',', 349,
        '.', 345,
        '/', 20,
        '<', 343,
        '>', 344,
        '@', 411,
        '[', 409,
        '\\', 330,
        ']', 348,
        '_', 415,
        '{', 412,
        '}', 413,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(334);
      if (lookahead != 0 &&
          (lookahead < '.' || '>' < lookahead) &&
          (lookahead < '{' || '}' < lookahead) &&
          lookahead != 0x2192) ADVANCE(331);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '!', 333,
        '"', 13,
        '$', 15,
        '%', 341,
        '(', 350,
        ')', 351,
        '*', 408,
        '+', 414,
        ',', 349,
        '.', 345,
        '/', 20,
        '<', 343,
        '>', 344,
        '[', 347,
        '\\', 330,
        ']', 348,
        '_', 415,
        '{', 412,
        '}', 413,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(3);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(334);
      if (lookahead != 0 &&
          (lookahead < '.' || '>' < lookahead) &&
          lookahead != '@' &&
          (lookahead < '{' || '}' < lookahead) &&
          lookahead != 0x2192) ADVANCE(331);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '!', 333,
        '"', 13,
        '$', 15,
        '%', 341,
        '(', 350,
        ')', 351,
        '*', 408,
        '+', 414,
        ',', 349,
        '.', 345,
        '<', 343,
        '>', 344,
        '[', 409,
        '\\', 330,
        ']', 348,
        '_', 415,
        '{', 412,
        '}', 413,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(5);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(334);
      if (lookahead != 0 &&
          (lookahead < '.' || '>' < lookahead) &&
          lookahead != '@' &&
          (lookahead < '{' || '}' < lookahead) &&
          lookahead != 0x2192) ADVANCE(331);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '!', 333,
        '"', 13,
        '$', 15,
        '%', 341,
        '(', 350,
        ')', 351,
        '*', 408,
        '+', 414,
        ',', 349,
        '.', 345,
        '<', 343,
        '>', 344,
        '[', 347,
        '\\', 330,
        ']', 348,
        '_', 415,
        '{', 412,
        '}', 413,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(5);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(334);
      if (lookahead != 0 &&
          (lookahead < '.' || '>' < lookahead) &&
          lookahead != '@' &&
          (lookahead < '{' || '}' < lookahead) &&
          lookahead != 0x2192) ADVANCE(331);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '!', 333,
        '"', 13,
        '$', 15,
        '%', 341,
        '(', 350,
        ')', 351,
        '*', 408,
        '+', 414,
        ',', 349,
        ';', 346,
        '<', 343,
        '>', 344,
        '[', 347,
        '\\', 330,
        ']', 348,
        '_', 415,
        '{', 412,
        '|', 422,
        '}', 413,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(6);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(334);
      if (lookahead != 0 &&
          (lookahead < '.' || '>' < lookahead) &&
          lookahead != '@' &&
          lookahead != 0x2192) ADVANCE(331);
      END_STATE();
    case 7:
      if (lookahead == '!') ADVANCE(333);
      if (lookahead == '"') ADVANCE(13);
      if (lookahead == '$') ADVANCE(15);
      if (lookahead == '%') ADVANCE(341);
      if (lookahead == '*') ADVANCE(408);
      if (lookahead == '>') ADVANCE(344);
      if (lookahead == '\\') ADVANCE(330);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(334);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 333,
        '"', 13,
        '$', 337,
        '%', 341,
        '(', 350,
        '*', 408,
        '.', 345,
        '/', 20,
        '?', 423,
        '@', 353,
        '[', 347,
        '\\', 330,
        '{', 412,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(8);
      if (lookahead != 0 &&
          (lookahead < '(' || '*' < lookahead) &&
          lookahead != ',' &&
          (lookahead < '.' || '@' < lookahead) &&
          (lookahead < '[' || ']' < lookahead) &&
          (lookahead < '{' || '}' < lookahead) &&
          lookahead != 0x2192) ADVANCE(331);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '!', 333,
        '"', 13,
        '$', 337,
        '%', 341,
        '*', 408,
        '@', 353,
        '[', 347,
        '\\', 330,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(335);
      if (lookahead != 0 &&
          (lookahead < '(' || '*' < lookahead) &&
          lookahead != ',' &&
          (lookahead < '.' || '>' < lookahead) &&
          (lookahead < '[' || ']' < lookahead) &&
          (lookahead < '{' || '}' < lookahead) &&
          lookahead != 0x2192) ADVANCE(331);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '!', 333,
        '&', 402,
        '(', 410,
        ')', 351,
        ',', 349,
        '.', 345,
        '/', 20,
        '=', 358,
        '>', 344,
        '@', 411,
        '[', 409,
        ']', 348,
        '|', 404,
        '}', 413,
        '~', 406,
        0x2208, 394,
        0x2310, 407,
        '-', 16,
        '_', 16,
        'A', 21,
        'a', 21,
        'B', 22,
        'b', 22,
        'C', 23,
        'c', 23,
        'E', 24,
        'e', 24,
        'H', 25,
        'h', 25,
        'I', 26,
        'i', 26,
        'N', 47,
        'n', 47,
        'O', 27,
        'o', 27,
        'S', 28,
        's', 28,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '!', 333,
        '&', 402,
        ')', 351,
        ',', 349,
        '.', 345,
        '/', 20,
        '=', 358,
        '>', 344,
        ']', 348,
        '|', 404,
        '}', 413,
        '~', 406,
        0x2208, 394,
        0x2310, 407,
        '-', 16,
        '_', 16,
        'A', 21,
        'a', 21,
        'B', 22,
        'b', 22,
        'C', 23,
        'c', 23,
        'E', 24,
        'e', 24,
        'H', 25,
        'h', 25,
        'I', 26,
        'i', 26,
        'N', 47,
        'n', 47,
        'O', 27,
        'o', 27,
        'S', 28,
        's', 28,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      END_STATE();
    case 12:
      if (lookahead == '!') ADVANCE(333);
      if (lookahead == '-') ADVANCE(318);
      if (lookahead == ':') ADVANCE(342);
      if (lookahead == '=') ADVANCE(352);
      if (lookahead == '>') ADVANCE(344);
      if (lookahead == '\\') ADVANCE(330);
      if (lookahead == 0x2192) ADVANCE(315);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      if ((!eof && set_contains(sym_ident_character_set_1, 12, lookahead))) ADVANCE(331);
      END_STATE();
    case 13:
      if (lookahead == '"') ADVANCE(316);
      if (lookahead == '\\') ADVANCE(14);
      if (lookahead != 0) ADVANCE(13);
      END_STATE();
    case 14:
      if (lookahead == '"') ADVANCE(317);
      if (lookahead == '\\') ADVANCE(14);
      if (lookahead != 0) ADVANCE(13);
      END_STATE();
    case 15:
      if (lookahead == '$') ADVANCE(339);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '&', 402,
        '=', 358,
        '|', 404,
        '~', 406,
        0x2208, 394,
        0x2310, 407,
        '-', 16,
        '_', 16,
        'A', 21,
        'a', 21,
        'B', 22,
        'b', 22,
        'C', 23,
        'c', 23,
        'E', 24,
        'e', 24,
        'H', 25,
        'h', 25,
        'I', 26,
        'i', 26,
        'N', 47,
        'n', 47,
        'O', 27,
        'o', 27,
        'S', 28,
        's', 28,
      );
      END_STATE();
    case 17:
      if (lookahead == 'e') ADVANCE(18);
      END_STATE();
    case 18:
      if (lookahead == 'f') ADVANCE(354);
      END_STATE();
    case 19:
      if (lookahead == 'l') ADVANCE(354);
      END_STATE();
    case 20:
      if (lookahead == 'r') ADVANCE(17);
      if (lookahead == 's') ADVANCE(19);
      if (lookahead == 't') ADVANCE(19);
      END_STATE();
    case 21:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(21);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(30);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(31);
      END_STATE();
    case 22:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(22);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(32);
      END_STATE();
    case 23:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(23);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(33);
      END_STATE();
    case 24:
      ADVANCE_MAP(
        '-', 24,
        '_', 24,
        'L', 34,
        'l', 34,
        'N', 52,
        'n', 52,
        'Q', 35,
        'q', 35,
      );
      END_STATE();
    case 25:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(25);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(36);
      END_STATE();
    case 26:
      ADVANCE_MAP(
        '-', 26,
        '_', 26,
        'F', 416,
        'f', 416,
        'N', 391,
        'n', 391,
        'S', 37,
        's', 37,
      );
      END_STATE();
    case 27:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(27);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(403);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(38);
      END_STATE();
    case 28:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(28);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(48);
      END_STATE();
    case 29:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(29);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(56);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(359);
      END_STATE();
    case 30:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(30);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(65);
      END_STATE();
    case 31:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(31);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(401);
      END_STATE();
    case 32:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(32);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(40);
      END_STATE();
    case 33:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(33);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(168);
      END_STATE();
    case 34:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(34);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(41);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(46);
      END_STATE();
    case 35:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(35);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(79);
      END_STATE();
    case 36:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(36);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(169);
      END_STATE();
    case 37:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(37);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(42);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(55);
      END_STATE();
    case 38:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(38);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(63);
      END_STATE();
    case 39:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(39);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(68);
      END_STATE();
    case 40:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(40);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(54);
      END_STATE();
    case 41:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(41);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(417);
      END_STATE();
    case 42:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(42);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(89);
      END_STATE();
    case 43:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(43);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(83);
      END_STATE();
    case 44:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(44);
      if (lookahead == 'B' ||
          lookahead == 'b') ADVANCE(94);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(96);
      END_STATE();
    case 45:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(45);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(361);
      END_STATE();
    case 46:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(46);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(419);
      END_STATE();
    case 47:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(47);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(49);
      END_STATE();
    case 48:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(48);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(61);
      END_STATE();
    case 49:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(49);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(405);
      END_STATE();
    case 50:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(50);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(297);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(395);
      END_STATE();
    case 51:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(51);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(59);
      END_STATE();
    case 52:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(52);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(71);
      END_STATE();
    case 53:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(53);
      if (lookahead == 'G' ||
          lookahead == 'g') ADVANCE(397);
      END_STATE();
    case 54:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(54);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(252);
      END_STATE();
    case 55:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(55);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(44);
      END_STATE();
    case 56:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(56);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(78);
      END_STATE();
    case 57:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(57);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(382);
      END_STATE();
    case 58:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(58);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(355);
      END_STATE();
    case 59:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(59);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(80);
      END_STATE();
    case 60:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(60);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(418);
      END_STATE();
    case 61:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(61);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(66);
      END_STATE();
    case 62:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(62);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(379);
      END_STATE();
    case 63:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(63);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(76);
      END_STATE();
    case 64:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(64);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(39);
      END_STATE();
    case 65:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(65);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(43);
      END_STATE();
    case 66:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(66);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(257);
      END_STATE();
    case 67:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(67);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(298);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(392);
      END_STATE();
    case 68:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(68);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(360);
      END_STATE();
    case 69:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(69);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(53);
      END_STATE();
    case 70:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(70);
      if (lookahead == 'U' ||
          lookahead == 'u') ADVANCE(75);
      END_STATE();
    case 71:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(71);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(51);
      END_STATE();
    case 72:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(72);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(367);
      END_STATE();
    case 73:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(73);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(104);
      END_STATE();
    case 74:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(74);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(45);
      END_STATE();
    case 75:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(75);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(110);
      END_STATE();
    case 76:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(76);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(173);
      END_STATE();
    case 77:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(77);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(370);
      END_STATE();
    case 78:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(78);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(73);
      END_STATE();
    case 79:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(79);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(58);
      END_STATE();
    case 80:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(80);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(57);
      END_STATE();
    case 81:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(81);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(299);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(356);
      END_STATE();
    case 82:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(82);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(396);
      END_STATE();
    case 83:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(83);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(421);
      END_STATE();
    case 84:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(84);
      if (lookahead == 'H' ||
          lookahead == 'h') ADVANCE(364);
      END_STATE();
    case 85:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(85);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(62);
      END_STATE();
    case 86:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(86);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(74);
      END_STATE();
    case 87:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(87);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(171);
      END_STATE();
    case 88:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(88);
      if (lookahead == 'X' ||
          lookahead == 'x') ADVANCE(385);
      END_STATE();
    case 89:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(89);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(86);
      END_STATE();
    case 90:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(90);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(250);
      END_STATE();
    case 91:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(91);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(87);
      END_STATE();
    case 92:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(92);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(300);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(383);
      END_STATE();
    case 93:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(93);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(393);
      END_STATE();
    case 94:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(94);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(91);
      END_STATE();
    case 95:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(95);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(189);
      END_STATE();
    case 96:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(96);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(85);
      END_STATE();
    case 97:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(97);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(103);
      END_STATE();
    case 98:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(98);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(72);
      END_STATE();
    case 99:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(99);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(301);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(362);
      END_STATE();
    case 100:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(100);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(357);
      END_STATE();
    case 101:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(101);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(115);
      END_STATE();
    case 102:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(102);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(77);
      END_STATE();
    case 103:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(103);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(102);
      END_STATE();
    case 104:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(104);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(101);
      END_STATE();
    case 105:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(105);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(84);
      END_STATE();
    case 106:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(106);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(302);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(380);
      END_STATE();
    case 107:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(107);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(384);
      END_STATE();
    case 108:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(108);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(400);
      END_STATE();
    case 109:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(109);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(88);
      END_STATE();
    case 110:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(110);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(109);
      END_STATE();
    case 111:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(111);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(359);
      END_STATE();
    case 112:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(112);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(388);
      END_STATE();
    case 113:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(113);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(303);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(371);
      END_STATE();
    case 114:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(114);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(363);
      END_STATE();
    case 115:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(115);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(359);
      END_STATE();
    case 116:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(116);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(130);
      END_STATE();
    case 117:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(117);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(395);
      END_STATE();
    case 118:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(118);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(376);
      END_STATE();
    case 119:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(119);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(304);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(386);
      END_STATE();
    case 120:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(120);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(381);
      END_STATE();
    case 121:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(121);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(395);
      END_STATE();
    case 122:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(122);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(420);
      END_STATE();
    case 123:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(123);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(373);
      END_STATE();
    case 124:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(124);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(305);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(368);
      END_STATE();
    case 125:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(125);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(372);
      END_STATE();
    case 126:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(126);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(392);
      END_STATE();
    case 127:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(127);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(392);
      END_STATE();
    case 128:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(128);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(306);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(365);
      END_STATE();
    case 129:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(129);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(387);
      END_STATE();
    case 130:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(130);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(112);
      END_STATE();
    case 131:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(131);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(356);
      END_STATE();
    case 132:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(132);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(307);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(398);
      END_STATE();
    case 133:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(133);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(369);
      END_STATE();
    case 134:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(134);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(118);
      END_STATE();
    case 135:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(135);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(383);
      END_STATE();
    case 136:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(136);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(308);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(389);
      END_STATE();
    case 137:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(137);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(366);
      END_STATE();
    case 138:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(138);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(356);
      END_STATE();
    case 139:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(139);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(362);
      END_STATE();
    case 140:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(140);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(309);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(377);
      END_STATE();
    case 141:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(141);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(399);
      END_STATE();
    case 142:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(142);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(123);
      END_STATE();
    case 143:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(143);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(380);
      END_STATE();
    case 144:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(144);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(310);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(374);
      END_STATE();
    case 145:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(145);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(390);
      END_STATE();
    case 146:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(146);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(383);
      END_STATE();
    case 147:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(147);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(371);
      END_STATE();
    case 148:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(148);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(378);
      END_STATE();
    case 149:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(149);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(362);
      END_STATE();
    case 150:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(150);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(386);
      END_STATE();
    case 151:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(151);
      if (lookahead == 'D' ||
          lookahead == 'd') ADVANCE(375);
      END_STATE();
    case 152:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(152);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(380);
      END_STATE();
    case 153:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(153);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(368);
      END_STATE();
    case 154:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(154);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(371);
      END_STATE();
    case 155:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(155);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(365);
      END_STATE();
    case 156:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(156);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(386);
      END_STATE();
    case 157:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(157);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(398);
      END_STATE();
    case 158:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(158);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(368);
      END_STATE();
    case 159:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(159);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(389);
      END_STATE();
    case 160:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(160);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(365);
      END_STATE();
    case 161:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(161);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(377);
      END_STATE();
    case 162:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(162);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(398);
      END_STATE();
    case 163:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(163);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(374);
      END_STATE();
    case 164:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(164);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(389);
      END_STATE();
    case 165:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(165);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(377);
      END_STATE();
    case 166:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(166);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(374);
      END_STATE();
    case 167:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(167);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(175);
      END_STATE();
    case 168:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(168);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(90);
      END_STATE();
    case 169:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(169);
      if (lookahead == 'P' ||
          lookahead == 'p') ADVANCE(172);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(70);
      END_STATE();
    case 170:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(170);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(82);
      END_STATE();
    case 171:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(171);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(69);
      END_STATE();
    case 172:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(172);
      if (lookahead == 'R' ||
          lookahead == 'r') ADVANCE(97);
      END_STATE();
    case 173:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(173);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(95);
      END_STATE();
    case 174:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(174);
      if (lookahead == 'N' ||
          lookahead == 'n') ADVANCE(108);
      END_STATE();
    case 175:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(175);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(111);
      END_STATE();
    case 176:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(176);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(98);
      END_STATE();
    case 177:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(177);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(170);
      END_STATE();
    case 178:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(178);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(121);
      END_STATE();
    case 179:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(179);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(178);
      END_STATE();
    case 180:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(180);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(134);
      END_STATE();
    case 181:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(181);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(93);
      END_STATE();
    case 182:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(182);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(117);
      END_STATE();
    case 183:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(183);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(105);
      END_STATE();
    case 184:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(184);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(181);
      END_STATE();
    case 185:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(185);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(126);
      END_STATE();
    case 186:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(186);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(185);
      END_STATE();
    case 187:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(187);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(142);
      END_STATE();
    case 188:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(188);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(100);
      END_STATE();
    case 189:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(189);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(122);
      END_STATE();
    case 190:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(190);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(188);
      END_STATE();
    case 191:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(191);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(138);
      END_STATE();
    case 192:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(192);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(191);
      END_STATE();
    case 193:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(193);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(107);
      END_STATE();
    case 194:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(194);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(127);
      END_STATE();
    case 195:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(195);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(193);
      END_STATE();
    case 196:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(196);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(146);
      END_STATE();
    case 197:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(197);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(196);
      END_STATE();
    case 198:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(198);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(114);
      END_STATE();
    case 199:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(199);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(131);
      END_STATE();
    case 200:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(200);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(198);
      END_STATE();
    case 201:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(201);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(149);
      END_STATE();
    case 202:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(202);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(201);
      END_STATE();
    case 203:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(203);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(120);
      END_STATE();
    case 204:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(204);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(135);
      END_STATE();
    case 205:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(205);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(203);
      END_STATE();
    case 206:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(206);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(152);
      END_STATE();
    case 207:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(207);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(206);
      END_STATE();
    case 208:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(208);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(125);
      END_STATE();
    case 209:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(209);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(139);
      END_STATE();
    case 210:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(210);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(208);
      END_STATE();
    case 211:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(211);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(154);
      END_STATE();
    case 212:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(212);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(211);
      END_STATE();
    case 213:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(213);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(129);
      END_STATE();
    case 214:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(214);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(143);
      END_STATE();
    case 215:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(215);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(213);
      END_STATE();
    case 216:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(216);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(156);
      END_STATE();
    case 217:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(217);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(216);
      END_STATE();
    case 218:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(218);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(133);
      END_STATE();
    case 219:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(219);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(147);
      END_STATE();
    case 220:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(220);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(218);
      END_STATE();
    case 221:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(221);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(158);
      END_STATE();
    case 222:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(222);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(221);
      END_STATE();
    case 223:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(223);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(137);
      END_STATE();
    case 224:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(224);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(150);
      END_STATE();
    case 225:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(225);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(223);
      END_STATE();
    case 226:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(226);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(160);
      END_STATE();
    case 227:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(227);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(226);
      END_STATE();
    case 228:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(228);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(141);
      END_STATE();
    case 229:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(229);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(153);
      END_STATE();
    case 230:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(230);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(228);
      END_STATE();
    case 231:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(231);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(162);
      END_STATE();
    case 232:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(232);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(231);
      END_STATE();
    case 233:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(233);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(145);
      END_STATE();
    case 234:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(234);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(155);
      END_STATE();
    case 235:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(235);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(233);
      END_STATE();
    case 236:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(236);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(164);
      END_STATE();
    case 237:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(237);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(236);
      END_STATE();
    case 238:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(238);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(148);
      END_STATE();
    case 239:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(239);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(157);
      END_STATE();
    case 240:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(240);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(238);
      END_STATE();
    case 241:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(241);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(165);
      END_STATE();
    case 242:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(242);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(241);
      END_STATE();
    case 243:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(243);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(151);
      END_STATE();
    case 244:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(244);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(159);
      END_STATE();
    case 245:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(245);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(243);
      END_STATE();
    case 246:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(246);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(166);
      END_STATE();
    case 247:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(247);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(246);
      END_STATE();
    case 248:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(248);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(161);
      END_STATE();
    case 249:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(249);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(163);
      END_STATE();
    case 250:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(250);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(174);
      END_STATE();
    case 251:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(251);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(176);
      END_STATE();
    case 252:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(252);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(251);
      END_STATE();
    case 253:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(253);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(179);
      END_STATE();
    case 254:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(254);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(253);
      END_STATE();
    case 255:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(255);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(182);
      END_STATE();
    case 256:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(256);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(183);
      END_STATE();
    case 257:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(257);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(256);
      END_STATE();
    case 258:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(258);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(186);
      END_STATE();
    case 259:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(259);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(258);
      END_STATE();
    case 260:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(260);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(194);
      END_STATE();
    case 261:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(261);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(192);
      END_STATE();
    case 262:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(262);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(261);
      END_STATE();
    case 263:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(263);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(199);
      END_STATE();
    case 264:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(264);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(197);
      END_STATE();
    case 265:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(265);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(264);
      END_STATE();
    case 266:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(266);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(204);
      END_STATE();
    case 267:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(267);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(202);
      END_STATE();
    case 268:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(268);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(267);
      END_STATE();
    case 269:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(269);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(209);
      END_STATE();
    case 270:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(270);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(207);
      END_STATE();
    case 271:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(271);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(270);
      END_STATE();
    case 272:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(272);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(214);
      END_STATE();
    case 273:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(273);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(212);
      END_STATE();
    case 274:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(274);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(273);
      END_STATE();
    case 275:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(275);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(219);
      END_STATE();
    case 276:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(276);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(217);
      END_STATE();
    case 277:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(277);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(276);
      END_STATE();
    case 278:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(278);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(224);
      END_STATE();
    case 279:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(279);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(222);
      END_STATE();
    case 280:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(280);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(279);
      END_STATE();
    case 281:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(281);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(229);
      END_STATE();
    case 282:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(282);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(227);
      END_STATE();
    case 283:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(283);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(282);
      END_STATE();
    case 284:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(284);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(234);
      END_STATE();
    case 285:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(285);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(232);
      END_STATE();
    case 286:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(286);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(285);
      END_STATE();
    case 287:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(287);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(239);
      END_STATE();
    case 288:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(288);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(237);
      END_STATE();
    case 289:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(289);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(288);
      END_STATE();
    case 290:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(290);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(244);
      END_STATE();
    case 291:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(291);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(242);
      END_STATE();
    case 292:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(292);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(291);
      END_STATE();
    case 293:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(293);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(248);
      END_STATE();
    case 294:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(294);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(247);
      END_STATE();
    case 295:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(295);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(294);
      END_STATE();
    case 296:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(296);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(249);
      END_STATE();
    case 297:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(297);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(254);
      END_STATE();
    case 298:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(298);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(259);
      END_STATE();
    case 299:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(299);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(262);
      END_STATE();
    case 300:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(300);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(265);
      END_STATE();
    case 301:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(301);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(268);
      END_STATE();
    case 302:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(302);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(271);
      END_STATE();
    case 303:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(303);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(274);
      END_STATE();
    case 304:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(304);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(277);
      END_STATE();
    case 305:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(305);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(280);
      END_STATE();
    case 306:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(306);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(283);
      END_STATE();
    case 307:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(307);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(286);
      END_STATE();
    case 308:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(308);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(289);
      END_STATE();
    case 309:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(309);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(292);
      END_STATE();
    case 310:
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(310);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(295);
      END_STATE();
    case 311:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(336);
      END_STATE();
    case 312:
      if (eof) ADVANCE(314);
      ADVANCE_MAP(
        '!', 333,
        '"', 13,
        '$', 338,
        '%', 341,
        '(', 350,
        ')', 351,
        '*', 408,
        '+', 414,
        ',', 349,
        '-', 318,
        '.', 345,
        '/', 20,
        ':', 342,
        ';', 346,
        '<', 343,
        '=', 352,
        '>', 344,
        '?', 423,
        '@', 353,
        '[', 347,
        '\\', 330,
        ']', 348,
        '_', 415,
        '{', 412,
        '|', 422,
        '}', 413,
        0x2192, 315,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(312);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(334);
      if (lookahead != 0) ADVANCE(331);
      END_STATE();
    case 313:
      if (eof) ADVANCE(314);
      ADVANCE_MAP(
        '!', 333,
        '"', 13,
        '$', 338,
        '%', 341,
        '(', 350,
        ':', 342,
        ';', 346,
        '<', 343,
        '>', 344,
        '@', 353,
        '[', 347,
        '\\', 330,
        '{', 412,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(313);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(334);
      if (lookahead != 0 &&
          lookahead != '(' &&
          lookahead != ')' &&
          lookahead != ',' &&
          (lookahead < '.' || '>' < lookahead) &&
          (lookahead < '[' || ']' < lookahead) &&
          (lookahead < '{' || '}' < lookahead) &&
          lookahead != 0x2192) ADVANCE(331);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 315:
      ACCEPT_TOKEN(aux_sym_arrow_token1);
      END_STATE();
    case 316:
      ACCEPT_TOKEN(sym_string);
      END_STATE();
    case 317:
      ACCEPT_TOKEN(sym_string);
      if (lookahead == '"') ADVANCE(316);
      if (lookahead == '\\') ADVANCE(14);
      if (lookahead != 0) ADVANCE(13);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '>') ADVANCE(315);
      if (lookahead == '\\') ADVANCE(332);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 319:
      ACCEPT_TOKEN(sym_ident);
      ADVANCE_MAP(
        '\\', 332,
        '~', 406,
        0x2310, 407,
        '-', 319,
        '_', 319,
        'A', 320,
        'a', 320,
        'I', 321,
        'i', 321,
        'N', 322,
        'n', 322,
      );
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 320:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(320);
      if (lookahead == 'L' ||
          lookahead == 'l') ADVANCE(323);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(321);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(324);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 322:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(322);
      if (lookahead == 'O' ||
          lookahead == 'o') ADVANCE(325);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(323);
      if (lookahead == 'W' ||
          lookahead == 'w') ADVANCE(326);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(324);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 325:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(325);
      if (lookahead == 'T' ||
          lookahead == 't') ADVANCE(405);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 326:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(326);
      if (lookahead == 'A' ||
          lookahead == 'a') ADVANCE(327);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(327);
      if (lookahead == 'Y' ||
          lookahead == 'y') ADVANCE(328);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(328);
      if (lookahead == 'S' ||
          lookahead == 's') ADVANCE(324);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\\') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(329);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead == '\t' ||
          (0x0b <= lookahead && lookahead <= '\r') ||
          lookahead == ' ' ||
          lookahead == '!' ||
          lookahead == '$' ||
          lookahead == '%' ||
          lookahead == '(' ||
          lookahead == ')' ||
          lookahead == ',' ||
          lookahead == '.' ||
          lookahead == '/' ||
          (':' <= lookahead && lookahead <= '>') ||
          lookahead == '@' ||
          ('[' <= lookahead && lookahead <= ']') ||
          ('{' <= lookahead && lookahead <= '}') ||
          lookahead == 0x2192) ADVANCE(331);
      if (lookahead != 0 &&
          (lookahead < '\t' || '\r' < lookahead)) ADVANCE(331);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\\') ADVANCE(332);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(sym_ident);
      if (lookahead == '\\') ADVANCE(332);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(331);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(sym_comment);
      if (lookahead != 0 &&
          lookahead != '\n') ADVANCE(333);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(aux_sym_num_token1);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(334);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(sym_weight);
      if (lookahead == '.') ADVANCE(311);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(335);
      END_STATE();
    case 336:
      ACCEPT_TOKEN(sym_weight);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(336);
      END_STATE();
    case 337:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      if (lookahead == '$') ADVANCE(339);
      if (lookahead == '%') ADVANCE(340);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(sym_global_var_prefix);
      END_STATE();
    case 340:
      ACCEPT_TOKEN(sym_global_str_prefix);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(sym_magic);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 343:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 349:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 351:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 352:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 353:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 354:
      ACCEPT_TOKEN(sym_clip_side);
      END_STATE();
    case 355:
      ACCEPT_TOKEN(aux_sym_str_op_eq_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(355);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(81);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(190);
      END_STATE();
    case 356:
      ACCEPT_TOKEN(aux_sym_str_op_eq_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(356);
      END_STATE();
    case 357:
      ACCEPT_TOKEN(aux_sym_str_op_eq_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(357);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(263);
      END_STATE();
    case 358:
      ACCEPT_TOKEN(aux_sym_str_op_eq_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(358);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(29);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(64);
      END_STATE();
    case 359:
      ACCEPT_TOKEN(aux_sym_str_op_eq_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(359);
      END_STATE();
    case 360:
      ACCEPT_TOKEN(aux_sym_str_op_eq_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(360);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(167);
      END_STATE();
    case 361:
      ACCEPT_TOKEN(aux_sym_str_op_isprefix_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(361);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(99);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(200);
      END_STATE();
    case 362:
      ACCEPT_TOKEN(aux_sym_str_op_isprefix_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(362);
      END_STATE();
    case 363:
      ACCEPT_TOKEN(aux_sym_str_op_isprefix_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(363);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(269);
      END_STATE();
    case 364:
      ACCEPT_TOKEN(aux_sym_str_op_isprefix_token2);
      ADVANCE_MAP(
        '-', 364,
        '_', 364,
        'C', 128,
        'c', 128,
        'F', 225,
        'f', 225,
        'L', 187,
        'l', 187,
      );
      END_STATE();
    case 365:
      ACCEPT_TOKEN(aux_sym_str_op_isprefix_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(365);
      END_STATE();
    case 366:
      ACCEPT_TOKEN(aux_sym_str_op_isprefix_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(366);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(284);
      END_STATE();
    case 367:
      ACCEPT_TOKEN(aux_sym_str_op_isprefix_token3);
      ADVANCE_MAP(
        '-', 367,
        '_', 367,
        'C', 124,
        'c', 124,
        'F', 220,
        'f', 220,
        'L', 180,
        'l', 180,
      );
      END_STATE();
    case 368:
      ACCEPT_TOKEN(aux_sym_str_op_isprefix_token3);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(368);
      END_STATE();
    case 369:
      ACCEPT_TOKEN(aux_sym_str_op_isprefix_token3);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(369);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(281);
      END_STATE();
    case 370:
      ACCEPT_TOKEN(aux_sym_str_op_hasprefix_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(370);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(113);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(210);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(aux_sym_str_op_hasprefix_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(371);
      END_STATE();
    case 372:
      ACCEPT_TOKEN(aux_sym_str_op_hasprefix_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(372);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(275);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(aux_sym_str_op_hasprefix_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(373);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(144);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(245);
      END_STATE();
    case 374:
      ACCEPT_TOKEN(aux_sym_str_op_hasprefix_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(374);
      END_STATE();
    case 375:
      ACCEPT_TOKEN(aux_sym_str_op_hasprefix_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(375);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(296);
      END_STATE();
    case 376:
      ACCEPT_TOKEN(aux_sym_str_op_hasprefix_token3);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(376);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(140);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(240);
      END_STATE();
    case 377:
      ACCEPT_TOKEN(aux_sym_str_op_hasprefix_token3);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(377);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(aux_sym_str_op_hasprefix_token3);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(378);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(293);
      END_STATE();
    case 379:
      ACCEPT_TOKEN(aux_sym_str_op_issuffix_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(379);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(106);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(205);
      END_STATE();
    case 380:
      ACCEPT_TOKEN(aux_sym_str_op_issuffix_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(380);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(aux_sym_str_op_issuffix_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(381);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(272);
      END_STATE();
    case 382:
      ACCEPT_TOKEN(aux_sym_str_op_issuffix_token2);
      ADVANCE_MAP(
        '-', 382,
        '_', 382,
        'C', 92,
        'c', 92,
        'F', 195,
        'f', 195,
        'L', 116,
        'l', 116,
      );
      END_STATE();
    case 383:
      ACCEPT_TOKEN(aux_sym_str_op_issuffix_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(383);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(aux_sym_str_op_issuffix_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(384);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(266);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(aux_sym_str_op_hassuffix_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(385);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(119);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(215);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(aux_sym_str_op_hassuffix_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(386);
      END_STATE();
    case 387:
      ACCEPT_TOKEN(aux_sym_str_op_hassuffix_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(387);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(278);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(aux_sym_str_op_hassuffix_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(388);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(136);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(235);
      END_STATE();
    case 389:
      ACCEPT_TOKEN(aux_sym_str_op_hassuffix_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(389);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(aux_sym_str_op_hassuffix_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(390);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(290);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(aux_sym_str_op_in_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(391);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(67);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(184);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(aux_sym_str_op_in_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(392);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(aux_sym_str_op_in_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(393);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(260);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(aux_sym_str_op_in_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(394);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(50);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(177);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(aux_sym_str_op_in_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(395);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(aux_sym_str_op_in_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(396);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(255);
      END_STATE();
    case 397:
      ACCEPT_TOKEN(aux_sym_str_op_contains_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(397);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(132);
      if (lookahead == 'F' ||
          lookahead == 'f') ADVANCE(230);
      END_STATE();
    case 398:
      ACCEPT_TOKEN(aux_sym_str_op_contains_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(398);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(aux_sym_str_op_contains_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(399);
      if (lookahead == 'C' ||
          lookahead == 'c') ADVANCE(287);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(aux_sym_str_op_contains_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(400);
      END_STATE();
    case 401:
      ACCEPT_TOKEN(aux_sym_and_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(401);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(aux_sym_and_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(402);
      END_STATE();
    case 403:
      ACCEPT_TOKEN(aux_sym_or_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(403);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(aux_sym_or_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(404);
      END_STATE();
    case 405:
      ACCEPT_TOKEN(aux_sym_not_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(405);
      END_STATE();
    case 406:
      ACCEPT_TOKEN(aux_sym_not_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(406);
      END_STATE();
    case 407:
      ACCEPT_TOKEN(aux_sym_not_token3);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(407);
      END_STATE();
    case 408:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '\\') ADVANCE(332);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(anon_sym_LBRACK2);
      END_STATE();
    case 410:
      ACCEPT_TOKEN(anon_sym_LPAREN2);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(anon_sym_AT2);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 413:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(sym_conjoin);
      if (lookahead == '\\') ADVANCE(332);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(sym_blank);
      if (lookahead == '\\') ADVANCE(332);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(329);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    case 416:
      ACCEPT_TOKEN(aux_sym_if_tok_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(416);
      END_STATE();
    case 417:
      ACCEPT_TOKEN(aux_sym_elif_tok_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(417);
      END_STATE();
    case 418:
      ACCEPT_TOKEN(aux_sym_elif_tok_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(418);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(aux_sym_else_tok_token1);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(419);
      if (lookahead == 'I' ||
          lookahead == 'i') ADVANCE(60);
      END_STATE();
    case 420:
      ACCEPT_TOKEN(aux_sym_else_tok_token2);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(420);
      END_STATE();
    case 421:
      ACCEPT_TOKEN(sym_always_tok);
      if (lookahead == '-' ||
          lookahead == '_') ADVANCE(421);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 423:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (lookahead == '\\') ADVANCE(332);
      if ((!eof && set_contains(sym_ident_character_set_2, 13, lookahead))) ADVANCE(331);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 313},
  [2] = {.lex_state = 10},
  [3] = {.lex_state = 10},
  [4] = {.lex_state = 10},
  [5] = {.lex_state = 10},
  [6] = {.lex_state = 10},
  [7] = {.lex_state = 10},
  [8] = {.lex_state = 10},
  [9] = {.lex_state = 10},
  [10] = {.lex_state = 10},
  [11] = {.lex_state = 10},
  [12] = {.lex_state = 10},
  [13] = {.lex_state = 10},
  [14] = {.lex_state = 10},
  [15] = {.lex_state = 10},
  [16] = {.lex_state = 10},
  [17] = {.lex_state = 10},
  [18] = {.lex_state = 10},
  [19] = {.lex_state = 10},
  [20] = {.lex_state = 10},
  [21] = {.lex_state = 10},
  [22] = {.lex_state = 10},
  [23] = {.lex_state = 6},
  [24] = {.lex_state = 6},
  [25] = {.lex_state = 6},
  [26] = {.lex_state = 10},
  [27] = {.lex_state = 6},
  [28] = {.lex_state = 6},
  [29] = {.lex_state = 6},
  [30] = {.lex_state = 1},
  [31] = {.lex_state = 10},
  [32] = {.lex_state = 6},
  [33] = {.lex_state = 6},
  [34] = {.lex_state = 6},
  [35] = {.lex_state = 6},
  [36] = {.lex_state = 6},
  [37] = {.lex_state = 6},
  [38] = {.lex_state = 6},
  [39] = {.lex_state = 6},
  [40] = {.lex_state = 2},
  [41] = {.lex_state = 2},
  [42] = {.lex_state = 2},
  [43] = {.lex_state = 6},
  [44] = {.lex_state = 6},
  [45] = {.lex_state = 4},
  [46] = {.lex_state = 4},
  [47] = {.lex_state = 2},
  [48] = {.lex_state = 2},
  [49] = {.lex_state = 6},
  [50] = {.lex_state = 4},
  [51] = {.lex_state = 4},
  [52] = {.lex_state = 4},
  [53] = {.lex_state = 2},
  [54] = {.lex_state = 4},
  [55] = {.lex_state = 4},
  [56] = {.lex_state = 6},
  [57] = {.lex_state = 6},
  [58] = {.lex_state = 6},
  [59] = {.lex_state = 4},
  [60] = {.lex_state = 2},
  [61] = {.lex_state = 4},
  [62] = {.lex_state = 4},
  [63] = {.lex_state = 4},
  [64] = {.lex_state = 4},
  [65] = {.lex_state = 4},
  [66] = {.lex_state = 2},
  [67] = {.lex_state = 1},
  [68] = {.lex_state = 1},
  [69] = {.lex_state = 4},
  [70] = {.lex_state = 1},
  [71] = {.lex_state = 4},
  [72] = {.lex_state = 4},
  [73] = {.lex_state = 4},
  [74] = {.lex_state = 1},
  [75] = {.lex_state = 1},
  [76] = {.lex_state = 6},
  [77] = {.lex_state = 6},
  [78] = {.lex_state = 4},
  [79] = {.lex_state = 6},
  [80] = {.lex_state = 6},
  [81] = {.lex_state = 6},
  [82] = {.lex_state = 6},
  [83] = {.lex_state = 6},
  [84] = {.lex_state = 6},
  [85] = {.lex_state = 6},
  [86] = {.lex_state = 6},
  [87] = {.lex_state = 6},
  [88] = {.lex_state = 6},
  [89] = {.lex_state = 6},
  [90] = {.lex_state = 6},
  [91] = {.lex_state = 6},
  [92] = {.lex_state = 6},
  [93] = {.lex_state = 6},
  [94] = {.lex_state = 6},
  [95] = {.lex_state = 6},
  [96] = {.lex_state = 6},
  [97] = {.lex_state = 6},
  [98] = {.lex_state = 6},
  [99] = {.lex_state = 6},
  [100] = {.lex_state = 6},
  [101] = {.lex_state = 6},
  [102] = {.lex_state = 8},
  [103] = {.lex_state = 10},
  [104] = {.lex_state = 8},
  [105] = {.lex_state = 6},
  [106] = {.lex_state = 8},
  [107] = {.lex_state = 8},
  [108] = {.lex_state = 8},
  [109] = {.lex_state = 313},
  [110] = {.lex_state = 6},
  [111] = {.lex_state = 313},
  [112] = {.lex_state = 313},
  [113] = {.lex_state = 313},
  [114] = {.lex_state = 313},
  [115] = {.lex_state = 313},
  [116] = {.lex_state = 313},
  [117] = {.lex_state = 313},
  [118] = {.lex_state = 313},
  [119] = {.lex_state = 6},
  [120] = {.lex_state = 9},
  [121] = {.lex_state = 9},
  [122] = {.lex_state = 9},
  [123] = {.lex_state = 8},
  [124] = {.lex_state = 8},
  [125] = {.lex_state = 313},
  [126] = {.lex_state = 313},
  [127] = {.lex_state = 313},
  [128] = {.lex_state = 313},
  [129] = {.lex_state = 8},
  [130] = {.lex_state = 10},
  [131] = {.lex_state = 1},
  [132] = {.lex_state = 8},
  [133] = {.lex_state = 1},
  [134] = {.lex_state = 8},
  [135] = {.lex_state = 10},
  [136] = {.lex_state = 8},
  [137] = {.lex_state = 8},
  [138] = {.lex_state = 8},
  [139] = {.lex_state = 8},
  [140] = {.lex_state = 8},
  [141] = {.lex_state = 10},
  [142] = {.lex_state = 7},
  [143] = {.lex_state = 10},
  [144] = {.lex_state = 8},
  [145] = {.lex_state = 9},
  [146] = {.lex_state = 8},
  [147] = {.lex_state = 10},
  [148] = {.lex_state = 8},
  [149] = {.lex_state = 9},
  [150] = {.lex_state = 10},
  [151] = {.lex_state = 8},
  [152] = {.lex_state = 10},
  [153] = {.lex_state = 7},
  [154] = {.lex_state = 10},
  [155] = {.lex_state = 10},
  [156] = {.lex_state = 10},
  [157] = {.lex_state = 10},
  [158] = {.lex_state = 10},
  [159] = {.lex_state = 1},
  [160] = {.lex_state = 8},
  [161] = {.lex_state = 313},
  [162] = {.lex_state = 8},
  [163] = {.lex_state = 8},
  [164] = {.lex_state = 313},
  [165] = {.lex_state = 10},
  [166] = {.lex_state = 10},
  [167] = {.lex_state = 10},
  [168] = {.lex_state = 10},
  [169] = {.lex_state = 10},
  [170] = {.lex_state = 10},
  [171] = {.lex_state = 10},
  [172] = {.lex_state = 10},
  [173] = {.lex_state = 10},
  [174] = {.lex_state = 10},
  [175] = {.lex_state = 10},
  [176] = {.lex_state = 313},
  [177] = {.lex_state = 10},
  [178] = {.lex_state = 313},
  [179] = {.lex_state = 313},
  [180] = {.lex_state = 10},
  [181] = {.lex_state = 313},
  [182] = {.lex_state = 8},
  [183] = {.lex_state = 313},
  [184] = {.lex_state = 10},
  [185] = {.lex_state = 10},
  [186] = {.lex_state = 313},
  [187] = {.lex_state = 10},
  [188] = {.lex_state = 313},
  [189] = {.lex_state = 313},
  [190] = {.lex_state = 0},
  [191] = {.lex_state = 10},
  [192] = {.lex_state = 10},
  [193] = {.lex_state = 313},
  [194] = {.lex_state = 313},
  [195] = {.lex_state = 10},
  [196] = {.lex_state = 0},
  [197] = {.lex_state = 10},
  [198] = {.lex_state = 313},
  [199] = {.lex_state = 313},
  [200] = {.lex_state = 313},
  [201] = {.lex_state = 10},
  [202] = {.lex_state = 10},
  [203] = {.lex_state = 0},
  [204] = {.lex_state = 10},
  [205] = {.lex_state = 10},
  [206] = {.lex_state = 0},
  [207] = {.lex_state = 10},
  [208] = {.lex_state = 10},
  [209] = {.lex_state = 313},
  [210] = {.lex_state = 313},
  [211] = {.lex_state = 313},
  [212] = {.lex_state = 313},
  [213] = {.lex_state = 313},
  [214] = {.lex_state = 313},
  [215] = {.lex_state = 313},
  [216] = {.lex_state = 0},
  [217] = {.lex_state = 313},
  [218] = {.lex_state = 7},
  [219] = {.lex_state = 10},
  [220] = {.lex_state = 313},
  [221] = {.lex_state = 10},
  [222] = {.lex_state = 10},
  [223] = {.lex_state = 7},
  [224] = {.lex_state = 10},
  [225] = {.lex_state = 9},
  [226] = {.lex_state = 7},
  [227] = {.lex_state = 10},
  [228] = {.lex_state = 7},
  [229] = {.lex_state = 10},
  [230] = {.lex_state = 10},
  [231] = {.lex_state = 10},
  [232] = {.lex_state = 7},
  [233] = {.lex_state = 313},
  [234] = {.lex_state = 10},
  [235] = {.lex_state = 10},
  [236] = {.lex_state = 10},
  [237] = {.lex_state = 10},
  [238] = {.lex_state = 10},
  [239] = {.lex_state = 10},
  [240] = {.lex_state = 10},
  [241] = {.lex_state = 7},
  [242] = {.lex_state = 10},
  [243] = {.lex_state = 10},
  [244] = {.lex_state = 10},
  [245] = {.lex_state = 10},
  [246] = {.lex_state = 10},
  [247] = {.lex_state = 7},
  [248] = {.lex_state = 10},
  [249] = {.lex_state = 10},
  [250] = {.lex_state = 10},
  [251] = {.lex_state = 10},
  [252] = {.lex_state = 10},
  [253] = {.lex_state = 10},
  [254] = {.lex_state = 10},
  [255] = {.lex_state = 313},
  [256] = {.lex_state = 10},
  [257] = {.lex_state = 10},
  [258] = {.lex_state = 10},
  [259] = {.lex_state = 10},
  [260] = {.lex_state = 10},
  [261] = {.lex_state = 10},
  [262] = {.lex_state = 10},
  [263] = {.lex_state = 7},
  [264] = {.lex_state = 7},
  [265] = {.lex_state = 10},
  [266] = {.lex_state = 10},
  [267] = {.lex_state = 10},
  [268] = {.lex_state = 10},
  [269] = {.lex_state = 12},
  [270] = {.lex_state = 10},
  [271] = {.lex_state = 7},
  [272] = {.lex_state = 10},
  [273] = {.lex_state = 313},
  [274] = {.lex_state = 313},
  [275] = {.lex_state = 313},
  [276] = {.lex_state = 7},
  [277] = {.lex_state = 10},
  [278] = {.lex_state = 10},
  [279] = {.lex_state = 313},
  [280] = {.lex_state = 10},
  [281] = {.lex_state = 10},
  [282] = {.lex_state = 10},
  [283] = {.lex_state = 10},
  [284] = {.lex_state = 313},
  [285] = {.lex_state = 10},
  [286] = {.lex_state = 313},
  [287] = {.lex_state = 313},
  [288] = {.lex_state = 10},
  [289] = {.lex_state = 313},
  [290] = {.lex_state = 313},
  [291] = {.lex_state = 7},
  [292] = {.lex_state = 313},
  [293] = {.lex_state = 313},
  [294] = {.lex_state = 313},
  [295] = {.lex_state = 313},
  [296] = {.lex_state = 313},
  [297] = {.lex_state = 313},
  [298] = {.lex_state = 10},
  [299] = {.lex_state = 313},
  [300] = {.lex_state = 313},
  [301] = {.lex_state = 313},
  [302] = {.lex_state = 313},
  [303] = {.lex_state = 313},
  [304] = {.lex_state = 313},
  [305] = {.lex_state = 313},
  [306] = {.lex_state = 313},
  [307] = {.lex_state = 313},
  [308] = {.lex_state = 313},
  [309] = {.lex_state = 313},
  [310] = {.lex_state = 313},
  [311] = {.lex_state = 313},
  [312] = {.lex_state = 313},
  [313] = {.lex_state = 313},
  [314] = {.lex_state = 313},
  [315] = {.lex_state = 313},
  [316] = {.lex_state = 12},
  [317] = {.lex_state = 313},
  [318] = {.lex_state = 313},
  [319] = {.lex_state = 313},
  [320] = {.lex_state = 313},
  [321] = {.lex_state = 313},
  [322] = {.lex_state = 0},
  [323] = {.lex_state = 0},
  [324] = {.lex_state = 0},
  [325] = {.lex_state = 0},
  [326] = {.lex_state = 12},
  [327] = {.lex_state = 0},
  [328] = {.lex_state = 0},
  [329] = {.lex_state = 0},
  [330] = {.lex_state = 0},
  [331] = {.lex_state = 0},
  [332] = {.lex_state = 0},
  [333] = {.lex_state = 313},
  [334] = {.lex_state = 0},
  [335] = {.lex_state = 0},
  [336] = {.lex_state = 0},
  [337] = {.lex_state = 0},
  [338] = {.lex_state = 0},
  [339] = {.lex_state = 0},
  [340] = {.lex_state = 313},
  [341] = {.lex_state = 0},
  [342] = {.lex_state = 0},
  [343] = {.lex_state = 0},
  [344] = {.lex_state = 0},
  [345] = {.lex_state = 0},
  [346] = {.lex_state = 0},
  [347] = {.lex_state = 0},
  [348] = {.lex_state = 0},
  [349] = {.lex_state = 0},
  [350] = {.lex_state = 0},
  [351] = {.lex_state = 0},
  [352] = {.lex_state = 0},
  [353] = {.lex_state = 0},
  [354] = {.lex_state = 0},
  [355] = {.lex_state = 0},
  [356] = {.lex_state = 0},
  [357] = {.lex_state = 0},
  [358] = {.lex_state = 313},
  [359] = {.lex_state = 0},
  [360] = {.lex_state = 0},
  [361] = {.lex_state = 0},
  [362] = {.lex_state = 0},
  [363] = {.lex_state = 0},
  [364] = {.lex_state = 0},
  [365] = {.lex_state = 0},
  [366] = {.lex_state = 0},
  [367] = {.lex_state = 313},
  [368] = {.lex_state = 0},
  [369] = {.lex_state = 0},
  [370] = {.lex_state = 0},
  [371] = {.lex_state = 0},
  [372] = {.lex_state = 0},
  [373] = {.lex_state = 0},
  [374] = {.lex_state = 0},
  [375] = {.lex_state = 0},
  [376] = {.lex_state = 313},
  [377] = {.lex_state = 313},
  [378] = {.lex_state = 0},
  [379] = {.lex_state = 0},
  [380] = {.lex_state = 0},
  [381] = {.lex_state = 0},
  [382] = {.lex_state = 0},
  [383] = {.lex_state = 0},
  [384] = {.lex_state = 0},
  [385] = {.lex_state = 0},
  [386] = {.lex_state = 0},
  [387] = {.lex_state = 0},
  [388] = {.lex_state = 0},
  [389] = {.lex_state = 313},
  [390] = {.lex_state = 0},
  [391] = {.lex_state = 313},
  [392] = {.lex_state = 313},
  [393] = {.lex_state = 313},
  [394] = {.lex_state = 313},
  [395] = {.lex_state = 313},
  [396] = {.lex_state = 0},
  [397] = {.lex_state = 313},
  [398] = {.lex_state = 0},
  [399] = {.lex_state = 313},
  [400] = {.lex_state = 313},
  [401] = {.lex_state = 0},
  [402] = {.lex_state = 313},
  [403] = {.lex_state = 0},
  [404] = {.lex_state = 313},
  [405] = {.lex_state = 313},
  [406] = {.lex_state = 0},
  [407] = {.lex_state = 313},
  [408] = {.lex_state = 0},
  [409] = {.lex_state = 313},
  [410] = {.lex_state = 313},
  [411] = {.lex_state = 0},
  [412] = {.lex_state = 0},
  [413] = {.lex_state = 313},
  [414] = {.lex_state = 0},
  [415] = {.lex_state = 313},
  [416] = {.lex_state = 0},
  [417] = {.lex_state = 0},
  [418] = {.lex_state = 313},
  [419] = {.lex_state = 313},
  [420] = {.lex_state = 0},
  [421] = {.lex_state = 313},
  [422] = {.lex_state = 313},
  [423] = {.lex_state = 0},
  [424] = {.lex_state = 0},
  [425] = {.lex_state = 313},
  [426] = {.lex_state = 313},
  [427] = {.lex_state = 0},
  [428] = {.lex_state = 0},
  [429] = {.lex_state = 313},
  [430] = {.lex_state = 313},
  [431] = {.lex_state = 0},
  [432] = {.lex_state = 0},
  [433] = {.lex_state = 313},
  [434] = {.lex_state = 313},
  [435] = {.lex_state = 0},
  [436] = {.lex_state = 313},
  [437] = {.lex_state = 0},
  [438] = {.lex_state = 0},
  [439] = {.lex_state = 0},
  [440] = {.lex_state = 0},
  [441] = {.lex_state = 0},
  [442] = {.lex_state = 0},
  [443] = {.lex_state = 313},
  [444] = {.lex_state = 0},
  [445] = {.lex_state = 0},
  [446] = {.lex_state = 313},
  [447] = {.lex_state = 313},
  [448] = {.lex_state = 0},
  [449] = {.lex_state = 313},
  [450] = {.lex_state = 0},
  [451] = {.lex_state = 313},
  [452] = {.lex_state = 0},
  [453] = {.lex_state = 313},
  [454] = {.lex_state = 0},
  [455] = {.lex_state = 313},
  [456] = {.lex_state = 313},
  [457] = {.lex_state = 0},
  [458] = {.lex_state = 313},
  [459] = {.lex_state = 313},
  [460] = {.lex_state = 0},
  [461] = {.lex_state = 313},
  [462] = {.lex_state = 0},
  [463] = {.lex_state = 313},
  [464] = {.lex_state = 313},
  [465] = {.lex_state = 0},
  [466] = {.lex_state = 313},
  [467] = {.lex_state = 313},
  [468] = {.lex_state = 313},
  [469] = {.lex_state = 313},
  [470] = {.lex_state = 313},
  [471] = {.lex_state = 0},
  [472] = {.lex_state = 313},
  [473] = {.lex_state = 313},
  [474] = {.lex_state = 0},
  [475] = {.lex_state = 313},
  [476] = {.lex_state = 0},
  [477] = {.lex_state = 0},
  [478] = {.lex_state = 0},
  [479] = {.lex_state = 0},
  [480] = {.lex_state = 0},
  [481] = {.lex_state = 0},
  [482] = {.lex_state = 313},
  [483] = {.lex_state = 0},
  [484] = {.lex_state = 0},
  [485] = {.lex_state = 313},
  [486] = {.lex_state = 0},
  [487] = {.lex_state = 0},
  [488] = {.lex_state = 313},
  [489] = {.lex_state = 313},
  [490] = {.lex_state = 313},
  [491] = {.lex_state = 313},
  [492] = {.lex_state = 313},
  [493] = {.lex_state = 0},
  [494] = {.lex_state = 0},
  [495] = {.lex_state = 0},
  [496] = {.lex_state = 0},
  [497] = {.lex_state = 0},
  [498] = {.lex_state = 313},
  [499] = {.lex_state = 0},
  [500] = {.lex_state = 313},
  [501] = {.lex_state = 0},
  [502] = {.lex_state = 313},
  [503] = {.lex_state = 0},
  [504] = {.lex_state = 0},
  [505] = {.lex_state = 0},
  [506] = {.lex_state = 313},
  [507] = {.lex_state = 0},
  [508] = {.lex_state = 0},
  [509] = {.lex_state = 313},
  [510] = {.lex_state = 313},
  [511] = {.lex_state = 313},
  [512] = {.lex_state = 313},
  [513] = {.lex_state = 0},
  [514] = {.lex_state = 313},
  [515] = {.lex_state = 313},
  [516] = {.lex_state = 0},
  [517] = {.lex_state = 0},
  [518] = {.lex_state = 313},
  [519] = {.lex_state = 313},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [0] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [aux_sym_arrow_token1] = ACTIONS(1),
    [sym_string] = ACTIONS(1),
    [sym_ident] = ACTIONS(1),
    [sym_comment] = ACTIONS(3),
    [aux_sym_num_token1] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [sym_global_var_prefix] = ACTIONS(1),
    [sym_global_str_prefix] = ACTIONS(1),
    [sym_magic] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [sym_clip_side] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_LBRACK2] = ACTIONS(1),
    [anon_sym_LPAREN2] = ACTIONS(1),
    [anon_sym_AT2] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [sym_conjoin] = ACTIONS(1),
    [sym_blank] = ACTIONS(1),
    [sym_numbered_blank] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
  },
  [1] = {
    [sym_source_file] = STATE(460),
    [sym_output_rule] = STATE(198),
    [sym_retag_rule] = STATE(198),
    [sym_attr_rule] = STATE(198),
    [sym_reduce_rule_group] = STATE(198),
    [aux_sym_source_file_repeat1] = STATE(198),
    [aux_sym_reduce_rule_group_repeat1] = STATE(316),
    [ts_builtin_sym_end] = ACTIONS(5),
    [sym_ident] = ACTIONS(7),
    [sym_comment] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(9), 1,
      anon_sym_GT,
    ACTIONS(13), 1,
      sym_clip_side,
    ACTIONS(15), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(11), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [46] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(17), 1,
      anon_sym_GT,
    ACTIONS(21), 1,
      sym_clip_side,
    ACTIONS(23), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(19), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [92] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(25), 1,
      anon_sym_GT,
    ACTIONS(29), 1,
      sym_clip_side,
    ACTIONS(31), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(27), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [138] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(33), 1,
      anon_sym_GT,
    ACTIONS(37), 1,
      sym_clip_side,
    ACTIONS(39), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(35), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [184] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(41), 1,
      anon_sym_GT,
    ACTIONS(45), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(43), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [227] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(47), 1,
      anon_sym_GT,
    ACTIONS(51), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(49), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [270] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(53), 1,
      anon_sym_GT,
    ACTIONS(57), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(55), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [313] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(59), 1,
      anon_sym_GT,
    ACTIONS(63), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(61), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [356] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(67), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(65), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [396] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(71), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(69), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [436] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(75), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(73), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [476] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(79), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(77), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [516] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(83), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(81), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [556] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(87), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(85), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [596] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(91), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(89), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [636] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(95), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(93), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [676] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(99), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(97), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [716] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(103), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(101), 28,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      anon_sym_RBRACE,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [756] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(107), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(105), 27,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [795] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(111), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(109), 27,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [834] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(115), 4,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
      aux_sym_else_tok_token1,
    ACTIONS(113), 27,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [873] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(139), 1,
      anon_sym_RBRACE,
    ACTIONS(141), 1,
      sym_conjoin,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(143), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(25), 8,
      sym_output_element,
      sym_chunk_cond,
      sym_lu_cond,
      sym_output_chunk,
      sym__chunk_val,
      sym__lu_val,
      sym_lu_sequence,
      aux_sym_reduce_output_repeat1,
  [943] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(145), 1,
      sym_string,
    ACTIONS(148), 1,
      sym_ident,
    ACTIONS(151), 1,
      aux_sym_num_token1,
    ACTIONS(154), 1,
      sym_global_var_prefix,
    ACTIONS(157), 1,
      sym_magic,
    ACTIONS(160), 1,
      anon_sym_LT,
    ACTIONS(163), 1,
      anon_sym_GT,
    ACTIONS(166), 1,
      anon_sym_LBRACK,
    ACTIONS(169), 1,
      anon_sym_LPAREN,
    ACTIONS(172), 1,
      anon_sym_STAR,
    ACTIONS(175), 1,
      anon_sym_LBRACE,
    ACTIONS(178), 1,
      anon_sym_RBRACE,
    ACTIONS(180), 1,
      sym_conjoin,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(183), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(24), 8,
      sym_output_element,
      sym_chunk_cond,
      sym_lu_cond,
      sym_output_chunk,
      sym__chunk_val,
      sym__lu_val,
      sym_lu_sequence,
      aux_sym_reduce_output_repeat1,
  [1013] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      sym_conjoin,
    ACTIONS(186), 1,
      anon_sym_RBRACE,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(188), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(24), 8,
      sym_output_element,
      sym_chunk_cond,
      sym_lu_cond,
      sym_output_chunk,
      sym__chunk_val,
      sym__lu_val,
      sym_lu_sequence,
      aux_sym_reduce_output_repeat1,
  [1083] = 14,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(192), 1,
      aux_sym_str_op_isprefix_token1,
    ACTIONS(198), 1,
      aux_sym_str_op_issuffix_token1,
    ACTIONS(200), 1,
      aux_sym_str_op_issuffix_token2,
    STATE(31), 1,
      sym_not,
    STATE(109), 1,
      sym_str_op,
    ACTIONS(190), 2,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
    ACTIONS(194), 2,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
    ACTIONS(202), 2,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
    ACTIONS(204), 2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
    ACTIONS(206), 2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
    ACTIONS(196), 3,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
    ACTIONS(208), 3,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
    STATE(209), 7,
      sym_str_op_eq,
      sym_str_op_isprefix,
      sym_str_op_hasprefix,
      sym_str_op_issuffix,
      sym_str_op_hassuffix,
      sym_str_op_in,
      sym_str_op_contains,
  [1141] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(210), 1,
      sym_string,
    ACTIONS(212), 1,
      sym_ident,
    ACTIONS(214), 1,
      aux_sym_num_token1,
    ACTIONS(216), 1,
      sym_global_var_prefix,
    ACTIONS(218), 1,
      sym_magic,
    ACTIONS(220), 1,
      anon_sym_LBRACK,
    ACTIONS(222), 1,
      anon_sym_LPAREN,
    ACTIONS(224), 1,
      anon_sym_STAR,
    ACTIONS(226), 1,
      anon_sym_LBRACE,
    ACTIONS(228), 1,
      sym_conjoin,
    STATE(153), 1,
      sym_insert,
    STATE(226), 1,
      sym_inserted,
    STATE(257), 1,
      sym_literal_lu,
    ACTIONS(230), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(165), 2,
      sym_num,
      sym_null_lu,
    STATE(243), 3,
      sym_chunk_cond,
      sym_output_chunk,
      sym__chunk_val,
    STATE(239), 4,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
  [1209] = 20,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(133), 1,
      anon_sym_LPAREN,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(141), 1,
      sym_conjoin,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(232), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(483), 3,
      sym_chunk_cond,
      sym_output_chunk,
      sym__chunk_val,
    STATE(431), 4,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
  [1277] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(234), 1,
      sym_string,
    ACTIONS(237), 1,
      sym_ident,
    ACTIONS(240), 1,
      aux_sym_num_token1,
    ACTIONS(243), 1,
      sym_global_var_prefix,
    ACTIONS(246), 1,
      sym_magic,
    ACTIONS(249), 1,
      anon_sym_LT,
    ACTIONS(252), 1,
      anon_sym_GT,
    ACTIONS(255), 1,
      anon_sym_LBRACK,
    ACTIONS(260), 1,
      anon_sym_LPAREN,
    ACTIONS(263), 1,
      anon_sym_STAR,
    ACTIONS(266), 1,
      sym_conjoin,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(258), 2,
      anon_sym_RBRACK,
      anon_sym_RBRACE,
    ACTIONS(269), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(29), 5,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
      aux_sym_output_chunk_repeat1,
  [1342] = 21,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(272), 1,
      sym_string,
    ACTIONS(274), 1,
      sym_ident,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(282), 1,
      anon_sym_LPAREN,
    ACTIONS(286), 1,
      aux_sym_if_tok_token1,
    ACTIONS(288), 1,
      sym_always_tok,
    STATE(74), 1,
      sym_not,
    STATE(150), 1,
      sym_string_if_choice,
    STATE(390), 1,
      sym_inserted,
    STATE(397), 1,
      sym_if_tok,
    STATE(441), 1,
      sym_string_always_choice,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(221), 2,
      sym__cond_base_bool,
      sym__cond_bool,
    ACTIONS(284), 3,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
    STATE(26), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [1411] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(192), 1,
      aux_sym_str_op_isprefix_token1,
    ACTIONS(198), 1,
      aux_sym_str_op_issuffix_token1,
    ACTIONS(200), 1,
      aux_sym_str_op_issuffix_token2,
    STATE(116), 1,
      sym_str_op,
    ACTIONS(190), 2,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
    ACTIONS(194), 2,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
    ACTIONS(202), 2,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
    ACTIONS(204), 2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
    ACTIONS(206), 2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
    ACTIONS(196), 3,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
    STATE(209), 7,
      sym_str_op_eq,
      sym_str_op_isprefix,
      sym_str_op_hasprefix,
      sym_str_op_issuffix,
      sym_str_op_hassuffix,
      sym_str_op_in,
      sym_str_op_contains,
  [1461] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(141), 1,
      sym_conjoin,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    ACTIONS(292), 1,
      anon_sym_RBRACE,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(294), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(29), 5,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
      aux_sym_output_chunk_repeat1,
  [1525] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(141), 1,
      sym_conjoin,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    ACTIONS(296), 1,
      anon_sym_RBRACE,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(298), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(32), 5,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
      aux_sym_output_chunk_repeat1,
  [1589] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(141), 1,
      sym_conjoin,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    ACTIONS(300), 1,
      anon_sym_RBRACK,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(302), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(35), 5,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
      aux_sym_output_chunk_repeat1,
  [1653] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(141), 1,
      sym_conjoin,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    ACTIONS(304), 1,
      anon_sym_RBRACK,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(294), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(29), 5,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
      aux_sym_output_chunk_repeat1,
  [1717] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(141), 1,
      sym_conjoin,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    ACTIONS(306), 1,
      anon_sym_RBRACK,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(308), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(38), 5,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
      aux_sym_output_chunk_repeat1,
  [1781] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(141), 1,
      sym_conjoin,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    ACTIONS(310), 1,
      anon_sym_RBRACE,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(312), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(39), 5,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
      aux_sym_output_chunk_repeat1,
  [1845] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(141), 1,
      sym_conjoin,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    ACTIONS(314), 1,
      anon_sym_RBRACK,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(294), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(29), 5,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
      aux_sym_output_chunk_repeat1,
  [1909] = 19,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(141), 1,
      sym_conjoin,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    ACTIONS(316), 1,
      anon_sym_RBRACE,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(294), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(29), 5,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
      aux_sym_output_chunk_repeat1,
  [1973] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(324), 1,
      anon_sym_LPAREN2,
    ACTIONS(326), 1,
      anon_sym_AT2,
    STATE(65), 1,
      sym_macro_name,
    STATE(86), 1,
      sym_output_var_set,
    ACTIONS(320), 7,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(318), 11,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2014] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(324), 1,
      anon_sym_LPAREN2,
    ACTIONS(326), 1,
      anon_sym_AT2,
    STATE(63), 1,
      sym_macro_name,
    STATE(99), 1,
      sym_output_var_set,
    ACTIONS(330), 7,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(328), 11,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2055] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(334), 7,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(332), 15,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DOT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      sym_clip_side,
      anon_sym_LBRACK2,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2085] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(141), 1,
      sym_conjoin,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(232), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(431), 4,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
  [2145] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(141), 1,
      sym_conjoin,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(336), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(370), 4,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
  [2205] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(342), 1,
      anon_sym_DOT,
    STATE(61), 1,
      aux_sym_literal_lu_repeat1,
    STATE(81), 1,
      sym_output_var_set,
    ACTIONS(340), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(338), 12,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2243] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(342), 1,
      anon_sym_DOT,
    STATE(50), 1,
      aux_sym_literal_lu_repeat1,
    STATE(83), 1,
      sym_output_var_set,
    ACTIONS(346), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(344), 12,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2281] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(324), 1,
      anon_sym_LPAREN2,
    STATE(62), 1,
      sym_macro_name,
    STATE(93), 1,
      sym_output_var_set,
    ACTIONS(350), 7,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(348), 11,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2319] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(324), 1,
      anon_sym_LPAREN2,
    STATE(63), 1,
      sym_macro_name,
    STATE(99), 1,
      sym_output_var_set,
    ACTIONS(330), 7,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(328), 11,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2357] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(141), 1,
      sym_conjoin,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(352), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(363), 4,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
  [2417] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(342), 1,
      anon_sym_DOT,
    STATE(61), 1,
      aux_sym_literal_lu_repeat1,
    STATE(84), 1,
      sym_output_var_set,
    ACTIONS(356), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(354), 12,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2455] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(342), 1,
      anon_sym_DOT,
    STATE(54), 1,
      aux_sym_literal_lu_repeat1,
    STATE(85), 1,
      sym_output_var_set,
    ACTIONS(360), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(358), 12,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2493] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(342), 1,
      anon_sym_DOT,
    STATE(55), 1,
      aux_sym_literal_lu_repeat1,
    STATE(87), 1,
      sym_output_var_set,
    ACTIONS(364), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(362), 12,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2531] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(324), 1,
      anon_sym_LPAREN2,
    STATE(65), 1,
      sym_macro_name,
    STATE(86), 1,
      sym_output_var_set,
    ACTIONS(320), 7,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(318), 11,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2569] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(342), 1,
      anon_sym_DOT,
    STATE(61), 1,
      aux_sym_literal_lu_repeat1,
    STATE(97), 1,
      sym_output_var_set,
    ACTIONS(368), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(366), 12,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2607] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(342), 1,
      anon_sym_DOT,
    STATE(61), 1,
      aux_sym_literal_lu_repeat1,
    STATE(94), 1,
      sym_output_var_set,
    ACTIONS(372), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(370), 12,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2645] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(210), 1,
      sym_string,
    ACTIONS(212), 1,
      sym_ident,
    ACTIONS(214), 1,
      aux_sym_num_token1,
    ACTIONS(216), 1,
      sym_global_var_prefix,
    ACTIONS(218), 1,
      sym_magic,
    ACTIONS(220), 1,
      anon_sym_LBRACK,
    ACTIONS(224), 1,
      anon_sym_STAR,
    ACTIONS(228), 1,
      sym_conjoin,
    ACTIONS(374), 1,
      anon_sym_LPAREN,
    STATE(153), 1,
      sym_insert,
    STATE(226), 1,
      sym_inserted,
    STATE(257), 1,
      sym_literal_lu,
    ACTIONS(376), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(165), 2,
      sym_num,
      sym_null_lu,
    STATE(246), 4,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
  [2705] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(210), 1,
      sym_string,
    ACTIONS(212), 1,
      sym_ident,
    ACTIONS(214), 1,
      aux_sym_num_token1,
    ACTIONS(216), 1,
      sym_global_var_prefix,
    ACTIONS(218), 1,
      sym_magic,
    ACTIONS(220), 1,
      anon_sym_LBRACK,
    ACTIONS(224), 1,
      anon_sym_STAR,
    ACTIONS(228), 1,
      sym_conjoin,
    ACTIONS(374), 1,
      anon_sym_LPAREN,
    STATE(153), 1,
      sym_insert,
    STATE(226), 1,
      sym_inserted,
    STATE(257), 1,
      sym_literal_lu,
    ACTIONS(230), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(165), 2,
      sym_num,
      sym_null_lu,
    STATE(239), 4,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
  [2765] = 18,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(117), 1,
      sym_string,
    ACTIONS(119), 1,
      sym_ident,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(123), 1,
      sym_global_var_prefix,
    ACTIONS(125), 1,
      sym_magic,
    ACTIONS(127), 1,
      anon_sym_LT,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(131), 1,
      anon_sym_LBRACK,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(141), 1,
      sym_conjoin,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    STATE(80), 1,
      sym_literal_lu,
    STATE(142), 1,
      sym_insert,
    STATE(232), 1,
      sym_inserted,
    ACTIONS(378), 2,
      sym_blank,
      sym_numbered_blank,
    STATE(53), 2,
      sym_num,
      sym_null_lu,
    STATE(454), 4,
      sym_output_element,
      sym_lu_cond,
      sym__lu_val,
      sym_lu_sequence,
  [2825] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(342), 1,
      anon_sym_DOT,
    STATE(45), 1,
      aux_sym_literal_lu_repeat1,
    STATE(95), 1,
      sym_output_var_set,
    ACTIONS(382), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(380), 12,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2863] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    ACTIONS(324), 1,
      anon_sym_LPAREN2,
    STATE(71), 1,
      sym_macro_name,
    STATE(90), 1,
      sym_output_var_set,
    ACTIONS(386), 7,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(384), 11,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2901] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(392), 1,
      anon_sym_DOT,
    STATE(61), 1,
      aux_sym_literal_lu_repeat1,
    ACTIONS(390), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(388), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2934] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    STATE(88), 1,
      sym_output_var_set,
    ACTIONS(397), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(395), 12,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2966] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    STATE(90), 1,
      sym_output_var_set,
    ACTIONS(386), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(384), 12,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [2998] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(401), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(399), 14,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DOT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3026] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    STATE(99), 1,
      sym_output_var_set,
    ACTIONS(330), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(328), 12,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3058] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 7,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(403), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      anon_sym_LPAREN2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3086] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(272), 1,
      sym_string,
    ACTIONS(274), 1,
      sym_ident,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(282), 1,
      anon_sym_LPAREN,
    STATE(74), 1,
      sym_not,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(219), 2,
      sym__cond_base_bool,
      sym__cond_bool,
    ACTIONS(284), 3,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
    STATE(26), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [3140] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(272), 1,
      sym_string,
    ACTIONS(274), 1,
      sym_ident,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(282), 1,
      anon_sym_LPAREN,
    STATE(67), 1,
      sym_not,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(234), 2,
      sym__cond_base_bool,
      sym__cond_bool,
    ACTIONS(284), 3,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
    STATE(26), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [3194] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(407), 14,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DOT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3222] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(272), 1,
      sym_string,
    ACTIONS(274), 1,
      sym_ident,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(282), 1,
      anon_sym_LPAREN,
    STATE(74), 1,
      sym_not,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(222), 2,
      sym__cond_base_bool,
      sym__cond_bool,
    ACTIONS(284), 3,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
    STATE(26), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [3276] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(322), 1,
      anon_sym_LBRACK2,
    STATE(93), 1,
      sym_output_var_set,
    ACTIONS(350), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(348), 12,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3308] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(413), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(411), 14,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DOT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3336] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(417), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(415), 14,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_DOT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3364] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(272), 1,
      sym_string,
    ACTIONS(274), 1,
      sym_ident,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(282), 1,
      anon_sym_LPAREN,
    STATE(74), 1,
      sym_not,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(229), 2,
      sym__cond_base_bool,
      sym__cond_bool,
    ACTIONS(284), 3,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
    STATE(26), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [3418] = 16,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(272), 1,
      sym_string,
    ACTIONS(274), 1,
      sym_ident,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(282), 1,
      anon_sym_LPAREN,
    STATE(67), 1,
      sym_not,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(230), 2,
      sym__cond_base_bool,
      sym__cond_bool,
    ACTIONS(284), 3,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
    STATE(26), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [3472] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(421), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(419), 14,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3499] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(425), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(423), 14,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3526] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 6,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(427), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3553] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(431), 14,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3580] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(320), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(318), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3606] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(435), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3632] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(439), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3658] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(443), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3684] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(447), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3710] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(451), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3736] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(330), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(328), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3762] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(457), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(455), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3788] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(461), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(459), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3814] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(465), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(463), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
  [3840] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(350), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(348), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3866] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(467), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
  [3892] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(471), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3918] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(397), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(395), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3944] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(475), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3970] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(481), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(479), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [3996] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(485), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(483), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PIPE,
  [4022] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(487), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [4048] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(493), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(491), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [4074] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(386), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(384), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [4100] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(495), 13,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_COMMA,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [4126] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(501), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(499), 11,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [4150] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(503), 1,
      sym_string,
    ACTIONS(505), 1,
      sym_ident,
    ACTIONS(507), 1,
      anon_sym_DOLLAR,
    ACTIONS(509), 1,
      sym_magic,
    ACTIONS(511), 1,
      anon_sym_LBRACK,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(515), 1,
      anon_sym_STAR,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    ACTIONS(519), 1,
      anon_sym_QMARK,
    STATE(396), 1,
      sym_chunk_cond,
    STATE(406), 1,
      sym_reduce_output,
    STATE(446), 1,
      sym_attr_prefix,
    STATE(455), 1,
      sym_attr_set_insert,
    STATE(108), 3,
      sym_pattern_element,
      sym_unknown,
      aux_sym_reduce_rule_repeat1,
  [4198] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(523), 3,
      aux_sym_str_op_isprefix_token2,
      aux_sym_str_op_isprefix_token3,
      aux_sym_str_op_issuffix_token2,
    ACTIONS(521), 13,
      aux_sym_str_op_eq_token1,
      aux_sym_str_op_eq_token2,
      aux_sym_str_op_isprefix_token1,
      aux_sym_str_op_hasprefix_token1,
      aux_sym_str_op_hasprefix_token2,
      aux_sym_str_op_hasprefix_token3,
      aux_sym_str_op_issuffix_token1,
      aux_sym_str_op_hassuffix_token1,
      aux_sym_str_op_hassuffix_token2,
      aux_sym_str_op_in_token1,
      aux_sym_str_op_in_token2,
      aux_sym_str_op_contains_token1,
      aux_sym_str_op_contains_token2,
  [4222] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(503), 1,
      sym_string,
    ACTIONS(505), 1,
      sym_ident,
    ACTIONS(507), 1,
      anon_sym_DOLLAR,
    ACTIONS(509), 1,
      sym_magic,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(515), 1,
      anon_sym_STAR,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    ACTIONS(525), 1,
      anon_sym_LBRACK,
    ACTIONS(527), 1,
      anon_sym_QMARK,
    STATE(396), 1,
      sym_chunk_cond,
    STATE(398), 1,
      sym_reduce_output,
    STATE(446), 1,
      sym_attr_prefix,
    STATE(455), 1,
      sym_attr_set_insert,
    STATE(108), 3,
      sym_pattern_element,
      sym_unknown,
      aux_sym_reduce_rule_repeat1,
  [4270] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(531), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(529), 11,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
  [4294] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(503), 1,
      sym_string,
    ACTIONS(505), 1,
      sym_ident,
    ACTIONS(507), 1,
      anon_sym_DOLLAR,
    ACTIONS(509), 1,
      sym_magic,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(515), 1,
      anon_sym_STAR,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    ACTIONS(533), 1,
      anon_sym_LBRACK,
    ACTIONS(535), 1,
      anon_sym_QMARK,
    STATE(396), 1,
      sym_chunk_cond,
    STATE(416), 1,
      sym_reduce_output,
    STATE(446), 1,
      sym_attr_prefix,
    STATE(455), 1,
      sym_attr_set_insert,
    STATE(108), 3,
      sym_pattern_element,
      sym_unknown,
      aux_sym_reduce_rule_repeat1,
  [4342] = 15,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(503), 1,
      sym_string,
    ACTIONS(505), 1,
      sym_ident,
    ACTIONS(507), 1,
      anon_sym_DOLLAR,
    ACTIONS(509), 1,
      sym_magic,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(515), 1,
      anon_sym_STAR,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    ACTIONS(537), 1,
      anon_sym_LBRACK,
    ACTIONS(539), 1,
      anon_sym_QMARK,
    STATE(396), 1,
      sym_chunk_cond,
    STATE(401), 1,
      sym_reduce_output,
    STATE(446), 1,
      sym_attr_prefix,
    STATE(455), 1,
      sym_attr_set_insert,
    STATE(108), 3,
      sym_pattern_element,
      sym_unknown,
      aux_sym_reduce_rule_repeat1,
  [4390] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(541), 1,
      sym_string,
    ACTIONS(544), 1,
      sym_ident,
    ACTIONS(547), 1,
      anon_sym_DOLLAR,
    ACTIONS(550), 1,
      sym_magic,
    ACTIONS(553), 1,
      anon_sym_LBRACK,
    ACTIONS(558), 1,
      anon_sym_STAR,
    ACTIONS(561), 1,
      anon_sym_QMARK,
    STATE(446), 1,
      sym_attr_prefix,
    STATE(455), 1,
      sym_attr_set_insert,
    ACTIONS(556), 2,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
    STATE(108), 3,
      sym_pattern_element,
      sym_unknown,
      aux_sym_reduce_rule_repeat1,
  [4430] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(563), 1,
      sym_string,
    ACTIONS(565), 1,
      sym_ident,
    ACTIONS(567), 1,
      anon_sym_LPAREN,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(283), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [4472] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(571), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(569), 9,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [4494] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    ACTIONS(567), 1,
      anon_sym_LPAREN,
    ACTIONS(573), 1,
      sym_string,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(372), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [4536] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    ACTIONS(567), 1,
      anon_sym_LPAREN,
    ACTIONS(575), 1,
      sym_string,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(373), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [4578] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    ACTIONS(567), 1,
      anon_sym_LPAREN,
    ACTIONS(577), 1,
      sym_string,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(382), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [4620] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    ACTIONS(567), 1,
      anon_sym_LPAREN,
    ACTIONS(579), 1,
      sym_string,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(245), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [4662] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    ACTIONS(567), 1,
      anon_sym_LPAREN,
    ACTIONS(581), 1,
      sym_string,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(423), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [4704] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    ACTIONS(567), 1,
      anon_sym_LPAREN,
    ACTIONS(583), 1,
      sym_string,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(288), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [4746] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    ACTIONS(567), 1,
      anon_sym_LPAREN,
    ACTIONS(585), 1,
      sym_string,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(277), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [4788] = 13,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    ACTIONS(567), 1,
      anon_sym_LPAREN,
    ACTIONS(587), 1,
      sym_string,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(503), 3,
      sym_clip,
      sym__string_val,
      sym_string_cond,
  [4830] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(591), 5,
      sym_ident,
      anon_sym_STAR,
      sym_conjoin,
      sym_blank,
      sym_numbered_blank,
    ACTIONS(589), 9,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [4852] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(505), 1,
      sym_ident,
    ACTIONS(507), 1,
      anon_sym_DOLLAR,
    ACTIONS(509), 1,
      sym_magic,
    ACTIONS(515), 1,
      anon_sym_STAR,
    ACTIONS(593), 1,
      sym_string,
    ACTIONS(595), 1,
      sym_weight,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    STATE(403), 1,
      sym_reduce_rule,
    STATE(446), 1,
      sym_attr_prefix,
    STATE(455), 1,
      sym_attr_set_insert,
    STATE(104), 3,
      sym_pattern_element,
      sym_unknown,
      aux_sym_reduce_rule_repeat1,
  [4891] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(503), 1,
      sym_string,
    ACTIONS(505), 1,
      sym_ident,
    ACTIONS(507), 1,
      anon_sym_DOLLAR,
    ACTIONS(509), 1,
      sym_magic,
    ACTIONS(515), 1,
      anon_sym_STAR,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    ACTIONS(599), 1,
      sym_weight,
    ACTIONS(601), 1,
      anon_sym_AT,
    STATE(446), 1,
      sym_attr_prefix,
    STATE(455), 1,
      sym_attr_set_insert,
    STATE(107), 3,
      sym_pattern_element,
      sym_unknown,
      aux_sym_reduce_rule_repeat1,
  [4930] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(505), 1,
      sym_ident,
    ACTIONS(507), 1,
      anon_sym_DOLLAR,
    ACTIONS(509), 1,
      sym_magic,
    ACTIONS(515), 1,
      anon_sym_STAR,
    ACTIONS(593), 1,
      sym_string,
    ACTIONS(595), 1,
      sym_weight,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    STATE(353), 1,
      sym_reduce_rule,
    STATE(446), 1,
      sym_attr_prefix,
    STATE(455), 1,
      sym_attr_set_insert,
    STATE(104), 3,
      sym_pattern_element,
      sym_unknown,
      aux_sym_reduce_rule_repeat1,
  [4969] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_DOT,
    ACTIONS(609), 1,
      anon_sym_AT,
    STATE(134), 1,
      aux_sym_pattern_element_repeat1,
    ACTIONS(605), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(603), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [4995] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(601), 1,
      anon_sym_AT,
    ACTIONS(607), 1,
      anon_sym_DOT,
    STATE(144), 1,
      aux_sym_pattern_element_repeat1,
    ACTIONS(613), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(611), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [5021] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    ACTIONS(567), 1,
      anon_sym_LPAREN,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(516), 2,
      sym_clip,
      sym_string_cond,
  [5059] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    ACTIONS(567), 1,
      anon_sym_LPAREN,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(428), 2,
      sym_clip,
      sym_string_cond,
  [5097] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    ACTIONS(567), 1,
      anon_sym_LPAREN,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(507), 2,
      sym_clip,
      sym_string_cond,
  [5135] = 12,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    ACTIONS(567), 1,
      anon_sym_LPAREN,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
    STATE(504), 2,
      sym_clip,
      sym_string_cond,
  [5173] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_DOT,
    STATE(136), 1,
      aux_sym_pattern_element_repeat1,
    ACTIONS(617), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(615), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [5196] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(619), 1,
      anon_sym_RPAREN,
    ACTIONS(623), 1,
      aux_sym_else_tok_token1,
    ACTIONS(625), 1,
      aux_sym_else_tok_token2,
    STATE(115), 1,
      sym_else_tok,
    STATE(377), 1,
      sym_elif_tok,
    STATE(487), 1,
      sym_string_else_choice,
    STATE(180), 2,
      sym_string_elif_choice,
      aux_sym_string_cond_repeat1,
    ACTIONS(621), 3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
  [5227] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(629), 2,
      sym_ident,
      anon_sym_DOLLAR,
    ACTIONS(627), 9,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_global_str_prefix,
      anon_sym_GT,
      anon_sym_LPAREN,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
  [5246] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_DOT,
    STATE(138), 1,
      aux_sym_pattern_element_repeat1,
    ACTIONS(633), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(631), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [5269] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(523), 2,
      sym_ident,
      anon_sym_DOLLAR,
    ACTIONS(521), 9,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_global_str_prefix,
      anon_sym_GT,
      anon_sym_LPAREN,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
  [5288] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_DOT,
    STATE(138), 1,
      aux_sym_pattern_element_repeat1,
    ACTIONS(637), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(635), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [5311] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(639), 1,
      anon_sym_RPAREN,
    ACTIONS(641), 1,
      aux_sym_else_tok_token1,
    ACTIONS(643), 1,
      aux_sym_else_tok_token2,
    STATE(290), 1,
      sym_else_tok,
    STATE(367), 1,
      sym_elif_tok,
    STATE(440), 1,
      sym_chunk_else_choice,
    STATE(141), 2,
      sym_chunk_elif_choice,
      aux_sym_chunk_cond_repeat1,
    ACTIONS(621), 3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
  [5342] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_DOT,
    STATE(138), 1,
      aux_sym_pattern_element_repeat1,
    ACTIONS(647), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(645), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [5365] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(653), 1,
      sym_clip_side,
    ACTIONS(651), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(649), 7,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [5386] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(659), 1,
      anon_sym_DOT,
    STATE(138), 1,
      aux_sym_pattern_element_repeat1,
    ACTIONS(657), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(655), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [5409] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_DOT,
    STATE(146), 1,
      aux_sym_pattern_element_repeat1,
    ACTIONS(664), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(662), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [5432] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_DOT,
    STATE(151), 1,
      aux_sym_pattern_element_repeat1,
    ACTIONS(668), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(666), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [5455] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      aux_sym_else_tok_token1,
    ACTIONS(643), 1,
      aux_sym_else_tok_token2,
    ACTIONS(670), 1,
      anon_sym_RPAREN,
    STATE(290), 1,
      sym_else_tok,
    STATE(367), 1,
      sym_elif_tok,
    STATE(497), 1,
      sym_chunk_else_choice,
    STATE(185), 2,
      sym_chunk_elif_choice,
      aux_sym_chunk_cond_repeat1,
    ACTIONS(621), 3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
  [5486] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(672), 1,
      sym_string,
    ACTIONS(674), 1,
      sym_ident,
    ACTIONS(676), 1,
      sym_global_var_prefix,
    ACTIONS(678), 1,
      sym_magic,
    STATE(86), 1,
      sym_literal_lu,
    STATE(228), 1,
      sym_inserted,
    STATE(48), 2,
      sym_num,
      sym_null_lu,
  [5521] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      aux_sym_else_tok_token1,
    ACTIONS(643), 1,
      aux_sym_else_tok_token2,
    ACTIONS(680), 1,
      anon_sym_RPAREN,
    STATE(58), 1,
      sym_else_tok,
    STATE(395), 1,
      sym_elif_tok,
    STATE(442), 1,
      sym_lu_else_choice,
    STATE(147), 2,
      sym_lu_elif_choice,
      aux_sym_lu_cond_repeat1,
    ACTIONS(621), 3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
  [5552] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_DOT,
    STATE(138), 1,
      aux_sym_pattern_element_repeat1,
    ACTIONS(684), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(682), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [5575] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(503), 1,
      sym_string,
    ACTIONS(505), 1,
      sym_ident,
    ACTIONS(507), 1,
      anon_sym_DOLLAR,
    ACTIONS(509), 1,
      sym_magic,
    ACTIONS(515), 1,
      anon_sym_STAR,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    STATE(446), 1,
      sym_attr_prefix,
    STATE(455), 1,
      sym_attr_set_insert,
    STATE(106), 3,
      sym_pattern_element,
      sym_unknown,
      aux_sym_reduce_rule_repeat1,
  [5608] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_DOT,
    STATE(138), 1,
      aux_sym_pattern_element_repeat1,
    ACTIONS(688), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(686), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [5631] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      aux_sym_else_tok_token1,
    ACTIONS(643), 1,
      aux_sym_else_tok_token2,
    ACTIONS(690), 1,
      anon_sym_RPAREN,
    STATE(58), 1,
      sym_else_tok,
    STATE(395), 1,
      sym_elif_tok,
    STATE(462), 1,
      sym_lu_else_choice,
    STATE(184), 2,
      sym_lu_elif_choice,
      aux_sym_lu_cond_repeat1,
    ACTIONS(621), 3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
  [5662] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_DOT,
    STATE(132), 1,
      aux_sym_pattern_element_repeat1,
    ACTIONS(694), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(692), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [5685] = 10,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(503), 1,
      sym_string,
    ACTIONS(505), 1,
      sym_ident,
    ACTIONS(507), 1,
      anon_sym_DOLLAR,
    ACTIONS(509), 1,
      sym_magic,
    ACTIONS(515), 1,
      anon_sym_STAR,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    STATE(446), 1,
      sym_attr_prefix,
    STATE(455), 1,
      sym_attr_set_insert,
    STATE(102), 3,
      sym_pattern_element,
      sym_unknown,
      aux_sym_reduce_rule_repeat1,
  [5718] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(623), 1,
      aux_sym_else_tok_token1,
    ACTIONS(625), 1,
      aux_sym_else_tok_token2,
    ACTIONS(696), 1,
      anon_sym_RPAREN,
    STATE(115), 1,
      sym_else_tok,
    STATE(377), 1,
      sym_elif_tok,
    STATE(477), 1,
      sym_string_else_choice,
    STATE(130), 2,
      sym_string_elif_choice,
      aux_sym_string_cond_repeat1,
    ACTIONS(621), 3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
  [5749] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(607), 1,
      anon_sym_DOT,
    STATE(138), 1,
      aux_sym_pattern_element_repeat1,
    ACTIONS(700), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(698), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [5772] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(320), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(704), 1,
      anon_sym_LPAREN2,
    ACTIONS(706), 1,
      anon_sym_AT2,
    STATE(195), 1,
      sym_macro_name,
    STATE(265), 1,
      sym_output_var_set,
    ACTIONS(318), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [5801] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(214), 1,
      aux_sym_num_token1,
    ACTIONS(224), 1,
      anon_sym_STAR,
    ACTIONS(708), 1,
      sym_string,
    ACTIONS(710), 1,
      sym_ident,
    ACTIONS(712), 1,
      sym_global_var_prefix,
    ACTIONS(714), 1,
      sym_magic,
    STATE(218), 1,
      sym_inserted,
    STATE(265), 1,
      sym_literal_lu,
    STATE(166), 2,
      sym_num,
      sym_null_lu,
  [5836] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(330), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(704), 1,
      anon_sym_LPAREN2,
    ACTIONS(706), 1,
      anon_sym_AT2,
    STATE(197), 1,
      sym_macro_name,
    STATE(258), 1,
      sym_output_var_set,
    ACTIONS(328), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [5865] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      aux_sym_else_tok_token1,
    ACTIONS(643), 1,
      aux_sym_else_tok_token2,
    ACTIONS(716), 1,
      anon_sym_RPAREN,
    STATE(58), 1,
      sym_else_tok,
    STATE(395), 1,
      sym_elif_tok,
    STATE(484), 1,
      sym_lu_else_choice,
    STATE(156), 2,
      sym_lu_elif_choice,
      aux_sym_lu_cond_repeat1,
    ACTIONS(621), 3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
  [5896] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      aux_sym_else_tok_token1,
    ACTIONS(643), 1,
      aux_sym_else_tok_token2,
    ACTIONS(718), 1,
      anon_sym_RPAREN,
    STATE(58), 1,
      sym_else_tok,
    STATE(395), 1,
      sym_elif_tok,
    STATE(494), 1,
      sym_lu_else_choice,
    STATE(184), 2,
      sym_lu_elif_choice,
      aux_sym_lu_cond_repeat1,
    ACTIONS(621), 3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
  [5927] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      aux_sym_else_tok_token1,
    ACTIONS(643), 1,
      aux_sym_else_tok_token2,
    ACTIONS(720), 1,
      anon_sym_RPAREN,
    STATE(290), 1,
      sym_else_tok,
    STATE(367), 1,
      sym_elif_tok,
    STATE(495), 1,
      sym_chunk_else_choice,
    STATE(158), 2,
      sym_chunk_elif_choice,
      aux_sym_chunk_cond_repeat1,
    ACTIONS(621), 3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
  [5958] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(641), 1,
      aux_sym_else_tok_token1,
    ACTIONS(643), 1,
      aux_sym_else_tok_token2,
    ACTIONS(722), 1,
      anon_sym_RPAREN,
    STATE(290), 1,
      sym_else_tok,
    STATE(367), 1,
      sym_elif_tok,
    STATE(501), 1,
      sym_chunk_else_choice,
    STATE(185), 2,
      sym_chunk_elif_choice,
      aux_sym_chunk_cond_repeat1,
    ACTIONS(621), 3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
  [5989] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(726), 2,
      sym_ident,
      anon_sym_DOLLAR,
    ACTIONS(724), 9,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_global_str_prefix,
      anon_sym_GT,
      anon_sym_LPAREN,
      aux_sym_not_token1,
      aux_sym_not_token2,
      aux_sym_not_token3,
  [6008] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(657), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(655), 7,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [6026] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(508), 1,
      sym_clip,
    STATE(518), 1,
      sym_attr_prefix,
  [6060] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(730), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(728), 7,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [6078] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(734), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(732), 7,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_DOT,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [6096] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(513), 1,
      sym_clip,
    STATE(518), 1,
      sym_attr_prefix,
  [6130] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(320), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(704), 1,
      anon_sym_LPAREN2,
    STATE(195), 1,
      sym_macro_name,
    STATE(265), 1,
      sym_output_var_set,
    ACTIONS(318), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6156] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(330), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(704), 1,
      anon_sym_LPAREN2,
    STATE(197), 1,
      sym_macro_name,
    STATE(258), 1,
      sym_output_var_set,
    ACTIONS(328), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6182] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(382), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(736), 1,
      anon_sym_DOT,
    STATE(169), 1,
      aux_sym_literal_lu_repeat1,
    STATE(272), 1,
      sym_output_var_set,
    ACTIONS(380), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6208] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(386), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(704), 1,
      anon_sym_LPAREN2,
    STATE(201), 1,
      sym_macro_name,
    STATE(236), 1,
      sym_output_var_set,
    ACTIONS(384), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6234] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(340), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(736), 1,
      anon_sym_DOT,
    STATE(187), 1,
      aux_sym_literal_lu_repeat1,
    STATE(242), 1,
      sym_output_var_set,
    ACTIONS(338), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6260] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(346), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(736), 1,
      anon_sym_DOT,
    STATE(173), 1,
      aux_sym_literal_lu_repeat1,
    STATE(244), 1,
      sym_output_var_set,
    ACTIONS(344), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6286] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(350), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(704), 1,
      anon_sym_LPAREN2,
    STATE(204), 1,
      sym_macro_name,
    STATE(248), 1,
      sym_output_var_set,
    ACTIONS(348), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6312] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(360), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(736), 1,
      anon_sym_DOT,
    STATE(174), 1,
      aux_sym_literal_lu_repeat1,
    STATE(252), 1,
      sym_output_var_set,
    ACTIONS(358), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6338] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(356), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(736), 1,
      anon_sym_DOT,
    STATE(187), 1,
      aux_sym_literal_lu_repeat1,
    STATE(251), 1,
      sym_output_var_set,
    ACTIONS(354), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6364] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(368), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(736), 1,
      anon_sym_DOT,
    STATE(187), 1,
      aux_sym_literal_lu_repeat1,
    STATE(259), 1,
      sym_output_var_set,
    ACTIONS(366), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6390] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(364), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(736), 1,
      anon_sym_DOT,
    STATE(177), 1,
      aux_sym_literal_lu_repeat1,
    STATE(254), 1,
      sym_output_var_set,
    ACTIONS(362), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6416] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    STATE(390), 1,
      sym_inserted,
    STATE(432), 1,
      sym_clip,
    STATE(465), 1,
      sym_num,
    STATE(518), 1,
      sym_attr_prefix,
  [6450] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(372), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    ACTIONS(736), 1,
      anon_sym_DOT,
    STATE(187), 1,
      aux_sym_literal_lu_repeat1,
    STATE(260), 1,
      sym_output_var_set,
    ACTIONS(370), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6476] = 11,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(129), 1,
      anon_sym_GT,
    ACTIONS(276), 1,
      anon_sym_DOLLAR,
    ACTIONS(278), 1,
      sym_global_var_prefix,
    ACTIONS(280), 1,
      sym_global_str_prefix,
    ACTIONS(565), 1,
      sym_ident,
    STATE(390), 1,
      sym_inserted,
    STATE(465), 1,
      sym_num,
    STATE(505), 1,
      sym_clip,
    STATE(518), 1,
      sym_attr_prefix,
  [6510] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(738), 1,
      sym_ident,
    ACTIONS(740), 1,
      anon_sym_DOLLAR,
    ACTIONS(742), 1,
      sym_global_var_prefix,
    ACTIONS(744), 1,
      sym_global_str_prefix,
    STATE(473), 1,
      sym_attr_prefix,
    STATE(341), 4,
      sym_set_surf,
      sym_set_global_var,
      sym_set_global_str,
      sym_set_chunk_attr,
  [6535] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(751), 1,
      aux_sym_else_tok_token1,
    STATE(377), 1,
      sym_elif_tok,
    ACTIONS(746), 2,
      anon_sym_RPAREN,
      aux_sym_else_tok_token2,
    STATE(180), 2,
      sym_string_elif_choice,
      aux_sym_string_cond_repeat1,
    ACTIONS(748), 3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
  [6558] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(738), 1,
      sym_ident,
    ACTIONS(740), 1,
      anon_sym_DOLLAR,
    ACTIONS(742), 1,
      sym_global_var_prefix,
    ACTIONS(744), 1,
      sym_global_str_prefix,
    STATE(473), 1,
      sym_attr_prefix,
    STATE(343), 4,
      sym_set_surf,
      sym_set_global_var,
      sym_set_global_str,
      sym_set_chunk_attr,
  [6583] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(755), 3,
      sym_ident,
      anon_sym_STAR,
      anon_sym_QMARK,
    ACTIONS(753), 6,
      sym_string,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
      anon_sym_LPAREN,
      anon_sym_LBRACE,
  [6600] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(738), 1,
      sym_ident,
    ACTIONS(740), 1,
      anon_sym_DOLLAR,
    ACTIONS(742), 1,
      sym_global_var_prefix,
    ACTIONS(744), 1,
      sym_global_str_prefix,
    STATE(473), 1,
      sym_attr_prefix,
    STATE(345), 4,
      sym_set_surf,
      sym_set_global_var,
      sym_set_global_str,
      sym_set_chunk_attr,
  [6625] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(762), 1,
      aux_sym_else_tok_token1,
    STATE(395), 1,
      sym_elif_tok,
    ACTIONS(757), 2,
      anon_sym_RPAREN,
      aux_sym_else_tok_token2,
    STATE(184), 2,
      sym_lu_elif_choice,
      aux_sym_lu_cond_repeat1,
    ACTIONS(759), 3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
  [6648] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(769), 1,
      aux_sym_else_tok_token1,
    STATE(367), 1,
      sym_elif_tok,
    ACTIONS(764), 2,
      anon_sym_RPAREN,
      aux_sym_else_tok_token2,
    STATE(185), 2,
      sym_chunk_elif_choice,
      aux_sym_chunk_cond_repeat1,
    ACTIONS(766), 3,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
  [6671] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(738), 1,
      sym_ident,
    ACTIONS(740), 1,
      anon_sym_DOLLAR,
    ACTIONS(742), 1,
      sym_global_var_prefix,
    ACTIONS(744), 1,
      sym_global_str_prefix,
    STATE(473), 1,
      sym_attr_prefix,
    STATE(350), 4,
      sym_set_surf,
      sym_set_global_var,
      sym_set_global_str,
      sym_set_chunk_attr,
  [6696] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(390), 1,
      aux_sym_else_tok_token1,
    ACTIONS(771), 1,
      anon_sym_DOT,
    STATE(187), 1,
      aux_sym_literal_lu_repeat1,
    ACTIONS(388), 6,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6717] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(776), 1,
      anon_sym_DOLLAR,
    ACTIONS(774), 7,
      sym_string,
      sym_ident,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_global_str_prefix,
      anon_sym_GT,
      anon_sym_LPAREN,
  [6733] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(780), 1,
      anon_sym_DOLLAR,
    ACTIONS(778), 7,
      sym_string,
      sym_ident,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_global_str_prefix,
      anon_sym_GT,
      anon_sym_LPAREN,
  [6749] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(740), 1,
      anon_sym_DOLLAR,
    ACTIONS(742), 1,
      sym_global_var_prefix,
    ACTIONS(744), 1,
      sym_global_str_prefix,
    STATE(473), 1,
      sym_attr_prefix,
    STATE(347), 4,
      sym_set_surf,
      sym_set_global_var,
      sym_set_global_str,
      sym_set_chunk_attr,
  [6771] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(334), 1,
      aux_sym_else_tok_token1,
    ACTIONS(332), 7,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      anon_sym_LPAREN2,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6787] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(405), 1,
      aux_sym_else_tok_token1,
    ACTIONS(403), 7,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      anon_sym_LPAREN2,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6803] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(782), 1,
      ts_builtin_sym_end,
    ACTIONS(784), 1,
      sym_ident,
    STATE(316), 1,
      aux_sym_reduce_rule_group_repeat1,
    STATE(193), 5,
      sym_output_rule,
      sym_retag_rule,
      sym_attr_rule,
      sym_reduce_rule_group,
      aux_sym_source_file_repeat1,
  [6823] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(591), 1,
      anon_sym_DOLLAR,
    ACTIONS(589), 7,
      sym_string,
      sym_ident,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_global_str_prefix,
      anon_sym_GT,
      anon_sym_LPAREN,
  [6839] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(330), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    STATE(258), 1,
      sym_output_var_set,
    ACTIONS(328), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6859] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(740), 1,
      anon_sym_DOLLAR,
    ACTIONS(742), 1,
      sym_global_var_prefix,
    ACTIONS(744), 1,
      sym_global_str_prefix,
    STATE(473), 1,
      sym_attr_prefix,
    STATE(412), 4,
      sym_set_surf,
      sym_set_global_var,
      sym_set_global_str,
      sym_set_chunk_attr,
  [6881] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(386), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    STATE(236), 1,
      sym_output_var_set,
    ACTIONS(384), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6901] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(7), 1,
      sym_ident,
    ACTIONS(787), 1,
      ts_builtin_sym_end,
    STATE(316), 1,
      aux_sym_reduce_rule_group_repeat1,
    STATE(193), 5,
      sym_output_rule,
      sym_retag_rule,
      sym_attr_rule,
      sym_reduce_rule_group,
      aux_sym_source_file_repeat1,
  [6921] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(571), 1,
      anon_sym_DOLLAR,
    ACTIONS(569), 7,
      sym_string,
      sym_ident,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_global_str_prefix,
      anon_sym_GT,
      anon_sym_LPAREN,
  [6937] = 9,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    ACTIONS(789), 1,
      sym_ident,
    ACTIONS(791), 1,
      sym_magic,
    ACTIONS(793), 1,
      anon_sym_COLON,
    ACTIONS(795), 1,
      anon_sym_LT,
    STATE(255), 1,
      sym_colon,
    STATE(337), 1,
      sym_lit_tag,
    STATE(496), 1,
      sym_lu_cond,
  [6965] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(350), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    STATE(248), 1,
      sym_output_var_set,
    ACTIONS(348), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [6985] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(401), 1,
      aux_sym_else_tok_token1,
    ACTIONS(399), 7,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7001] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(740), 1,
      anon_sym_DOLLAR,
    ACTIONS(742), 1,
      sym_global_var_prefix,
    ACTIONS(744), 1,
      sym_global_str_prefix,
    STATE(473), 1,
      sym_attr_prefix,
    STATE(356), 4,
      sym_set_surf,
      sym_set_global_var,
      sym_set_global_str,
      sym_set_chunk_attr,
  [7023] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(397), 1,
      aux_sym_else_tok_token1,
    ACTIONS(702), 1,
      anon_sym_LBRACK2,
    STATE(256), 1,
      sym_output_var_set,
    ACTIONS(395), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7043] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(409), 1,
      aux_sym_else_tok_token1,
    ACTIONS(407), 7,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7059] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(740), 1,
      anon_sym_DOLLAR,
    ACTIONS(742), 1,
      sym_global_var_prefix,
    ACTIONS(744), 1,
      sym_global_str_prefix,
    STATE(473), 1,
      sym_attr_prefix,
    STATE(331), 4,
      sym_set_surf,
      sym_set_global_var,
      sym_set_global_str,
      sym_set_chunk_attr,
  [7081] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(413), 1,
      aux_sym_else_tok_token1,
    ACTIONS(411), 7,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7097] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(417), 1,
      aux_sym_else_tok_token1,
    ACTIONS(415), 7,
      anon_sym_DOT,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7113] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(799), 1,
      anon_sym_DOLLAR,
    ACTIONS(797), 7,
      sym_string,
      sym_ident,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_global_str_prefix,
      anon_sym_GT,
      anon_sym_LPAREN,
  [7129] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(803), 1,
      anon_sym_DOLLAR,
    ACTIONS(801), 7,
      sym_string,
      sym_ident,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_global_str_prefix,
      anon_sym_GT,
      anon_sym_LPAREN,
  [7145] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    ACTIONS(807), 1,
      anon_sym_LPAREN,
    ACTIONS(809), 1,
      anon_sym_AT,
    STATE(275), 1,
      sym_attr_default,
    ACTIONS(805), 2,
      sym_string,
      sym_ident,
    STATE(220), 2,
      sym_attr_set_insert,
      aux_sym_attr_rule_repeat1,
  [7169] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(813), 1,
      anon_sym_DOLLAR,
    ACTIONS(811), 7,
      sym_string,
      sym_ident,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_global_str_prefix,
      anon_sym_GT,
      anon_sym_LPAREN,
  [7185] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(817), 1,
      anon_sym_DOLLAR,
    ACTIONS(815), 7,
      sym_string,
      sym_ident,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_global_str_prefix,
      anon_sym_GT,
      anon_sym_LPAREN,
  [7201] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(821), 1,
      anon_sym_DOLLAR,
    ACTIONS(819), 7,
      sym_string,
      sym_ident,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_global_str_prefix,
      anon_sym_GT,
      anon_sym_LPAREN,
  [7217] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(825), 1,
      anon_sym_DOLLAR,
    ACTIONS(823), 7,
      sym_string,
      sym_ident,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_global_str_prefix,
      anon_sym_GT,
      anon_sym_LPAREN,
  [7233] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(740), 1,
      anon_sym_DOLLAR,
    ACTIONS(742), 1,
      sym_global_var_prefix,
    ACTIONS(744), 1,
      sym_global_str_prefix,
    STATE(473), 1,
      sym_attr_prefix,
    STATE(336), 4,
      sym_set_surf,
      sym_set_global_var,
      sym_set_global_str,
      sym_set_chunk_attr,
  [7255] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    ACTIONS(809), 1,
      anon_sym_AT,
    ACTIONS(829), 1,
      anon_sym_SEMI,
    ACTIONS(827), 2,
      sym_string,
      sym_ident,
    STATE(233), 2,
      sym_attr_set_insert,
      aux_sym_attr_rule_repeat1,
  [7276] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(214), 1,
      aux_sym_num_token1,
    ACTIONS(224), 1,
      anon_sym_STAR,
    ACTIONS(831), 1,
      sym_string,
    ACTIONS(833), 1,
      sym_ident,
    ACTIONS(835), 1,
      sym_magic,
    STATE(168), 2,
      sym_num,
      sym_null_lu,
  [7299] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(70), 2,
      sym_and,
      sym_or,
    ACTIONS(837), 5,
      anon_sym_RPAREN,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
  [7314] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    ACTIONS(809), 1,
      anon_sym_AT,
    ACTIONS(839), 1,
      anon_sym_SEMI,
    ACTIONS(827), 2,
      sym_string,
      sym_ident,
    STATE(233), 2,
      sym_attr_set_insert,
      aux_sym_attr_rule_repeat1,
  [7335] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(841), 1,
      anon_sym_RPAREN,
    ACTIONS(843), 2,
      aux_sym_and_token1,
      aux_sym_and_token2,
    ACTIONS(845), 2,
      aux_sym_or_token1,
      aux_sym_or_token2,
    STATE(70), 2,
      sym_and,
      sym_or,
  [7354] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(70), 2,
      sym_and,
      sym_or,
    ACTIONS(847), 5,
      anon_sym_RPAREN,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
  [7369] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(851), 2,
      sym_ident,
      anon_sym_STAR,
    ACTIONS(849), 5,
      sym_string,
      aux_sym_num_token1,
      sym_global_var_prefix,
      sym_magic,
      anon_sym_GT,
  [7384] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(429), 1,
      aux_sym_else_tok_token1,
    ACTIONS(427), 6,
      anon_sym_RPAREN,
      anon_sym_LBRACK2,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7399] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(855), 2,
      sym_ident,
      anon_sym_STAR,
    ACTIONS(853), 5,
      sym_string,
      sym_weight,
      anon_sym_DOLLAR,
      sym_magic,
      anon_sym_LBRACK,
  [7414] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(214), 1,
      aux_sym_num_token1,
    ACTIONS(224), 1,
      anon_sym_STAR,
    ACTIONS(714), 1,
      sym_magic,
    ACTIONS(857), 1,
      sym_string,
    ACTIONS(859), 1,
      sym_ident,
    STATE(166), 2,
      sym_num,
      sym_null_lu,
  [7437] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      aux_sym_if_tok_token1,
    ACTIONS(863), 1,
      sym_always_tok,
    STATE(155), 1,
      sym_lu_if_choice,
    STATE(157), 1,
      sym_chunk_if_choice,
    STATE(376), 1,
      sym_if_tok,
    STATE(480), 1,
      sym_lu_always_choice,
    STATE(486), 1,
      sym_chunk_always_choice,
  [7462] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(865), 1,
      sym_string,
    ACTIONS(867), 1,
      sym_ident,
    ACTIONS(869), 1,
      sym_magic,
    STATE(60), 2,
      sym_num,
      sym_null_lu,
  [7485] = 3,
    ACTIONS(3), 1,
      sym_comment,
    STATE(70), 2,
      sym_and,
      sym_or,
    ACTIONS(837), 5,
      anon_sym_RPAREN,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
  [7500] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(871), 1,
      anon_sym_RPAREN,
    ACTIONS(843), 2,
      aux_sym_and_token1,
      aux_sym_and_token2,
    ACTIONS(845), 2,
      aux_sym_or_token1,
      aux_sym_or_token2,
    STATE(70), 2,
      sym_and,
      sym_or,
  [7519] = 8,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      aux_sym_if_tok_token1,
    ACTIONS(863), 1,
      sym_always_tok,
    STATE(135), 1,
      sym_chunk_if_choice,
    STATE(143), 1,
      sym_lu_if_choice,
    STATE(376), 1,
      sym_if_tok,
    STATE(452), 1,
      sym_lu_always_choice,
    STATE(478), 1,
      sym_chunk_always_choice,
  [7544] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(678), 1,
      sym_magic,
    ACTIONS(873), 1,
      sym_string,
    ACTIONS(875), 1,
      sym_ident,
    STATE(48), 2,
      sym_num,
      sym_null_lu,
  [7567] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 1,
      anon_sym_SEMI,
    ACTIONS(882), 1,
      anon_sym_LBRACK,
    ACTIONS(885), 1,
      anon_sym_AT,
    ACTIONS(877), 2,
      sym_string,
      sym_ident,
    STATE(233), 2,
      sym_attr_set_insert,
      aux_sym_attr_rule_repeat1,
  [7588] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(888), 1,
      anon_sym_RPAREN,
    ACTIONS(843), 2,
      aux_sym_and_token1,
      aux_sym_and_token2,
    ACTIONS(845), 2,
      aux_sym_or_token1,
      aux_sym_or_token2,
    STATE(70), 2,
      sym_and,
      sym_or,
  [7607] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(485), 1,
      aux_sym_else_tok_token1,
    ACTIONS(483), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7621] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(350), 1,
      aux_sym_else_tok_token1,
    ACTIONS(348), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7635] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(497), 1,
      aux_sym_else_tok_token1,
    ACTIONS(495), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7649] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(892), 1,
      aux_sym_else_tok_token1,
    ACTIONS(890), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7663] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(896), 1,
      aux_sym_else_tok_token1,
    ACTIONS(894), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7677] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(441), 1,
      aux_sym_else_tok_token1,
    ACTIONS(439), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7691] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(214), 1,
      aux_sym_num_token1,
    ACTIONS(224), 1,
      anon_sym_STAR,
    ACTIONS(831), 1,
      sym_string,
    ACTIONS(833), 1,
      sym_ident,
    STATE(168), 2,
      sym_num,
      sym_null_lu,
  [7711] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(437), 1,
      aux_sym_else_tok_token1,
    ACTIONS(435), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7725] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(900), 1,
      aux_sym_else_tok_token1,
    ACTIONS(898), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7739] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(445), 1,
      aux_sym_else_tok_token1,
    ACTIONS(443), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7753] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(904), 1,
      aux_sym_else_tok_token1,
    ACTIONS(902), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7767] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(908), 1,
      aux_sym_else_tok_token1,
    ACTIONS(906), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7781] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(865), 1,
      sym_string,
    ACTIONS(867), 1,
      sym_ident,
    STATE(60), 2,
      sym_num,
      sym_null_lu,
  [7801] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(397), 1,
      aux_sym_else_tok_token1,
    ACTIONS(395), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7815] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(425), 1,
      aux_sym_else_tok_token1,
    ACTIONS(423), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7829] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(469), 1,
      aux_sym_else_tok_token1,
    ACTIONS(467), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7843] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(449), 1,
      aux_sym_else_tok_token1,
    ACTIONS(447), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7857] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(453), 1,
      aux_sym_else_tok_token1,
    ACTIONS(451), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7871] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(531), 1,
      aux_sym_else_tok_token1,
    ACTIONS(529), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7885] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(457), 1,
      aux_sym_else_tok_token1,
    ACTIONS(455), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7899] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(290), 1,
      anon_sym_LPAREN,
    ACTIONS(795), 1,
      anon_sym_LT,
    ACTIONS(910), 1,
      sym_ident,
    ACTIONS(912), 1,
      sym_magic,
    STATE(357), 1,
      sym_lit_tag,
    STATE(457), 1,
      sym_lu_cond,
  [7921] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(461), 1,
      aux_sym_else_tok_token1,
    ACTIONS(459), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7935] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(320), 1,
      aux_sym_else_tok_token1,
    ACTIONS(318), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7949] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(386), 1,
      aux_sym_else_tok_token1,
    ACTIONS(384), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7963] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(489), 1,
      aux_sym_else_tok_token1,
    ACTIONS(487), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7977] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(477), 1,
      aux_sym_else_tok_token1,
    ACTIONS(475), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [7991] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(421), 1,
      aux_sym_else_tok_token1,
    ACTIONS(419), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [8005] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(493), 1,
      aux_sym_else_tok_token1,
    ACTIONS(491), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [8019] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(214), 1,
      aux_sym_num_token1,
    ACTIONS(224), 1,
      anon_sym_STAR,
    ACTIONS(857), 1,
      sym_string,
    ACTIONS(859), 1,
      sym_ident,
    STATE(166), 2,
      sym_num,
      sym_null_lu,
  [8039] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(214), 1,
      aux_sym_num_token1,
    ACTIONS(224), 1,
      anon_sym_STAR,
    ACTIONS(914), 1,
      sym_string,
    ACTIONS(916), 1,
      sym_ident,
    STATE(171), 2,
      sym_num,
      sym_null_lu,
  [8059] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(330), 1,
      aux_sym_else_tok_token1,
    ACTIONS(328), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [8073] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(433), 1,
      aux_sym_else_tok_token1,
    ACTIONS(431), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [8087] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(465), 1,
      aux_sym_else_tok_token1,
    ACTIONS(463), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [8101] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(501), 1,
      aux_sym_else_tok_token1,
    ACTIONS(499), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [8115] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(793), 1,
      anon_sym_COLON,
    ACTIONS(918), 1,
      aux_sym_arrow_token1,
    ACTIONS(920), 1,
      sym_ident,
    ACTIONS(922), 1,
      anon_sym_GT,
    ACTIONS(924), 1,
      anon_sym_EQ,
    STATE(200), 1,
      sym_colon,
  [8137] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(473), 1,
      aux_sym_else_tok_token1,
    ACTIONS(471), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [8151] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(926), 1,
      sym_string,
    ACTIONS(928), 1,
      sym_ident,
    STATE(47), 2,
      sym_num,
      sym_null_lu,
  [8171] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(481), 1,
      aux_sym_else_tok_token1,
    ACTIONS(479), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [8185] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(932), 1,
      anon_sym_DOLLAR,
    ACTIONS(934), 1,
      anon_sym_LBRACK,
    ACTIONS(930), 2,
      sym_string,
      sym_ident,
    STATE(160), 2,
      sym_attr_set_insert,
      sym_pattern_clip,
  [8203] = 7,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(507), 1,
      anon_sym_DOLLAR,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    ACTIONS(936), 1,
      sym_string,
    ACTIONS(938), 1,
      sym_ident,
    STATE(434), 1,
      sym_attr_set_insert,
    STATE(466), 1,
      sym_attr_prefix,
  [8225] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    ACTIONS(809), 1,
      anon_sym_AT,
    ACTIONS(940), 2,
      sym_string,
      sym_ident,
    STATE(217), 2,
      sym_attr_set_insert,
      aux_sym_attr_rule_repeat1,
  [8243] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(135), 1,
      anon_sym_STAR,
    ACTIONS(873), 1,
      sym_string,
    ACTIONS(875), 1,
      sym_ident,
    STATE(48), 2,
      sym_num,
      sym_null_lu,
  [8263] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(944), 1,
      aux_sym_else_tok_token1,
    ACTIONS(942), 5,
      anon_sym_RPAREN,
      aux_sym_if_tok_token1,
      aux_sym_elif_tok_token1,
      aux_sym_elif_tok_token2,
      aux_sym_else_tok_token2,
  [8277] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      aux_sym_if_tok_token1,
    ACTIONS(946), 1,
      sym_always_tok,
    STATE(155), 1,
      sym_lu_if_choice,
    STATE(399), 1,
      sym_if_tok,
    STATE(480), 1,
      sym_lu_always_choice,
  [8296] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    STATE(388), 1,
      sym_attr_pair,
    STATE(402), 1,
      sym_attr_set_insert,
    ACTIONS(948), 2,
      sym_string,
      sym_ident,
  [8313] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      aux_sym_if_tok_token1,
    ACTIONS(950), 1,
      sym_always_tok,
    STATE(150), 1,
      sym_string_if_choice,
    STATE(397), 1,
      sym_if_tok,
    STATE(441), 1,
      sym_string_always_choice,
  [8332] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      aux_sym_if_tok_token1,
    ACTIONS(946), 1,
      sym_always_tok,
    STATE(143), 1,
      sym_lu_if_choice,
    STATE(399), 1,
      sym_if_tok,
    STATE(452), 1,
      sym_lu_always_choice,
  [8351] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(847), 5,
      anon_sym_RPAREN,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
  [8362] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(952), 5,
      anon_sym_RPAREN,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
  [8373] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    ACTIONS(954), 1,
      anon_sym_LBRACK,
    STATE(359), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8392] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      aux_sym_if_tok_token1,
    ACTIONS(956), 1,
      sym_always_tok,
    STATE(135), 1,
      sym_chunk_if_choice,
    STATE(410), 1,
      sym_if_tok,
    STATE(478), 1,
      sym_chunk_always_choice,
  [8411] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(732), 5,
      sym_string,
      sym_ident,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AT,
  [8422] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    ACTIONS(958), 1,
      anon_sym_LBRACK,
    STATE(396), 1,
      sym_chunk_cond,
    STATE(408), 1,
      sym_reduce_output,
  [8441] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(960), 5,
      anon_sym_RPAREN,
      aux_sym_and_token1,
      aux_sym_and_token2,
      aux_sym_or_token1,
      aux_sym_or_token2,
  [8452] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(226), 1,
      anon_sym_LBRACE,
    ACTIONS(962), 1,
      anon_sym_LPAREN,
    STATE(243), 3,
      sym_chunk_cond,
      sym_output_chunk,
      sym__chunk_val,
  [8467] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    STATE(493), 3,
      sym_chunk_cond,
      sym_output_chunk,
      sym__chunk_val,
  [8482] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(966), 2,
      sym_ident,
      anon_sym_STAR,
    ACTIONS(964), 3,
      sym_string,
      aux_sym_num_token1,
      sym_magic,
  [8495] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(597), 1,
      anon_sym_LBRACK,
    STATE(328), 1,
      sym_attr_pair,
    STATE(402), 1,
      sym_attr_set_insert,
    ACTIONS(948), 2,
      sym_string,
      sym_ident,
  [8512] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(880), 5,
      sym_string,
      sym_ident,
      anon_sym_SEMI,
      anon_sym_LBRACK,
      anon_sym_AT,
  [8523] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(968), 5,
      sym_ident,
      sym_magic,
      anon_sym_COLON,
      anon_sym_LT,
      anon_sym_LPAREN,
  [8534] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    ACTIONS(970), 1,
      anon_sym_LBRACK,
    STATE(366), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8553] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(137), 1,
      anon_sym_LBRACE,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    STATE(483), 3,
      sym_chunk_cond,
      sym_output_chunk,
      sym__chunk_val,
  [8568] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(226), 1,
      anon_sym_LBRACE,
    ACTIONS(962), 1,
      anon_sym_LPAREN,
    STATE(238), 3,
      sym_chunk_cond,
      sym_output_chunk,
      sym__chunk_val,
  [8583] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(861), 1,
      aux_sym_if_tok_token1,
    ACTIONS(956), 1,
      sym_always_tok,
    STATE(157), 1,
      sym_chunk_if_choice,
    STATE(410), 1,
      sym_if_tok,
    STATE(486), 1,
      sym_chunk_always_choice,
  [8602] = 6,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    ACTIONS(972), 1,
      anon_sym_LBRACK,
    STATE(387), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8621] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(974), 4,
      sym_string,
      sym_ident,
      anon_sym_LBRACK,
      anon_sym_AT,
  [8631] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(976), 1,
      sym_ident,
    ACTIONS(978), 1,
      anon_sym_DOLLAR,
    ACTIONS(980), 1,
      anon_sym_LBRACK,
    ACTIONS(982), 1,
      anon_sym_LBRACE,
  [8647] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(984), 1,
      sym_ident,
    ACTIONS(986), 1,
      anon_sym_DOLLAR,
    ACTIONS(988), 1,
      anon_sym_LBRACK,
    ACTIONS(990), 1,
      anon_sym_LBRACE,
  [8663] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(368), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8679] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(369), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8695] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(371), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8711] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(374), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8727] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(396), 1,
      sym_chunk_cond,
    STATE(411), 1,
      sym_reduce_output,
  [8743] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(378), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8759] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(379), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8775] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(380), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8791] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(383), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8807] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(385), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8823] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(992), 1,
      sym_ident,
    ACTIONS(994), 1,
      anon_sym_DOLLAR,
    ACTIONS(996), 1,
      anon_sym_LBRACK,
    ACTIONS(998), 1,
      anon_sym_LBRACE,
  [8839] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(386), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8855] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(360), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8871] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1000), 1,
      aux_sym_arrow_token1,
    ACTIONS(1002), 1,
      sym_ident,
    STATE(122), 1,
      sym_arrow,
    STATE(326), 1,
      aux_sym_reduce_rule_group_repeat1,
  [8887] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(361), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8903] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(362), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8919] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(375), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8935] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1004), 1,
      sym_ident,
    ACTIONS(1006), 1,
      anon_sym_DOLLAR,
    ACTIONS(1008), 1,
      anon_sym_LBRACK,
    ACTIONS(1010), 1,
      anon_sym_LBRACE,
  [8951] = 5,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(513), 1,
      anon_sym_LPAREN,
    ACTIONS(517), 1,
      anon_sym_LBRACE,
    STATE(364), 1,
      sym_reduce_output,
    STATE(396), 1,
      sym_chunk_cond,
  [8967] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1012), 1,
      anon_sym_SEMI,
    ACTIONS(1014), 1,
      anon_sym_COMMA,
    STATE(322), 1,
      aux_sym_retag_rule_repeat1,
  [8980] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1017), 1,
      anon_sym_RBRACK,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    STATE(348), 1,
      aux_sym_reduce_rule_repeat2,
  [8993] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1021), 1,
      anon_sym_RBRACK,
    STATE(348), 1,
      aux_sym_reduce_rule_repeat2,
  [9006] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1023), 1,
      anon_sym_DOT,
    ACTIONS(1026), 1,
      anon_sym_SEMI,
    STATE(325), 1,
      aux_sym_output_rule_repeat1,
  [9019] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1028), 1,
      aux_sym_arrow_token1,
    ACTIONS(1030), 1,
      sym_ident,
    STATE(326), 1,
      aux_sym_reduce_rule_group_repeat1,
  [9032] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1033), 1,
      anon_sym_RBRACK,
    STATE(348), 1,
      aux_sym_reduce_rule_repeat2,
  [9045] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1035), 1,
      anon_sym_SEMI,
    ACTIONS(1037), 1,
      anon_sym_COMMA,
    STATE(346), 1,
      aux_sym_retag_rule_repeat1,
  [9058] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1039), 1,
      anon_sym_RBRACK,
    ACTIONS(1041), 1,
      anon_sym_COMMA,
    STATE(338), 1,
      aux_sym_output_var_set_repeat1,
  [9071] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1043), 1,
      anon_sym_SEMI,
    ACTIONS(1045), 1,
      anon_sym_PIPE,
    STATE(339), 1,
      aux_sym_reduce_rule_group_repeat2,
  [9084] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1047), 1,
      anon_sym_RBRACK,
    STATE(332), 1,
      aux_sym_reduce_rule_repeat2,
  [9097] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1049), 1,
      anon_sym_RBRACK,
    STATE(348), 1,
      aux_sym_reduce_rule_repeat2,
  [9110] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(795), 1,
      anon_sym_LT,
    ACTIONS(1051), 1,
      sym_ident,
    STATE(414), 1,
      sym_lit_tag,
  [9123] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1053), 1,
      anon_sym_DOT,
    ACTIONS(1055), 1,
      anon_sym_SEMI,
    STATE(325), 1,
      aux_sym_output_rule_repeat1,
  [9136] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1053), 1,
      anon_sym_DOT,
    ACTIONS(1057), 1,
      anon_sym_SEMI,
    STATE(325), 1,
      aux_sym_output_rule_repeat1,
  [9149] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1059), 1,
      anon_sym_RBRACK,
    STATE(324), 1,
      aux_sym_reduce_rule_repeat2,
  [9162] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1053), 1,
      anon_sym_DOT,
    ACTIONS(1061), 1,
      anon_sym_SEMI,
    STATE(334), 1,
      aux_sym_output_rule_repeat1,
  [9175] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1041), 1,
      anon_sym_COMMA,
    ACTIONS(1063), 1,
      anon_sym_RBRACK,
    STATE(355), 1,
      aux_sym_output_var_set_repeat1,
  [9188] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1065), 1,
      anon_sym_SEMI,
    ACTIONS(1067), 1,
      anon_sym_PIPE,
    STATE(339), 1,
      aux_sym_reduce_rule_group_repeat2,
  [9201] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    ACTIONS(1070), 1,
      sym_ident,
    STATE(437), 1,
      sym_num,
  [9214] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1072), 1,
      anon_sym_RBRACK,
    STATE(342), 1,
      aux_sym_reduce_rule_repeat2,
  [9227] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1074), 1,
      anon_sym_RBRACK,
    STATE(348), 1,
      aux_sym_reduce_rule_repeat2,
  [9240] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1076), 1,
      anon_sym_RBRACK,
    STATE(344), 1,
      aux_sym_reduce_rule_repeat2,
  [9253] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1078), 1,
      anon_sym_RBRACK,
    STATE(348), 1,
      aux_sym_reduce_rule_repeat2,
  [9266] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1080), 1,
      anon_sym_RBRACK,
    STATE(327), 1,
      aux_sym_reduce_rule_repeat2,
  [9279] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1037), 1,
      anon_sym_COMMA,
    ACTIONS(1082), 1,
      anon_sym_SEMI,
    STATE(322), 1,
      aux_sym_retag_rule_repeat1,
  [9292] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1084), 1,
      anon_sym_RBRACK,
    STATE(349), 1,
      aux_sym_reduce_rule_repeat2,
  [9305] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1086), 1,
      anon_sym_RBRACK,
    ACTIONS(1088), 1,
      anon_sym_COMMA,
    STATE(348), 1,
      aux_sym_reduce_rule_repeat2,
  [9318] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1091), 1,
      anon_sym_RBRACK,
    STATE(348), 1,
      aux_sym_reduce_rule_repeat2,
  [9331] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1093), 1,
      anon_sym_RBRACK,
    STATE(323), 1,
      aux_sym_reduce_rule_repeat2,
  [9344] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1041), 1,
      anon_sym_COMMA,
    ACTIONS(1095), 1,
      anon_sym_RBRACK,
    STATE(352), 1,
      aux_sym_output_var_set_repeat1,
  [9357] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1041), 1,
      anon_sym_COMMA,
    ACTIONS(1097), 1,
      anon_sym_RBRACK,
    STATE(355), 1,
      aux_sym_output_var_set_repeat1,
  [9370] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1045), 1,
      anon_sym_PIPE,
    ACTIONS(1099), 1,
      anon_sym_SEMI,
    STATE(330), 1,
      aux_sym_reduce_rule_group_repeat2,
  [9383] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1101), 1,
      anon_sym_RBRACK,
    STATE(348), 1,
      aux_sym_reduce_rule_repeat2,
  [9396] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1103), 1,
      anon_sym_RBRACK,
    ACTIONS(1105), 1,
      anon_sym_COMMA,
    STATE(355), 1,
      aux_sym_output_var_set_repeat1,
  [9409] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1019), 1,
      anon_sym_COMMA,
    ACTIONS(1108), 1,
      anon_sym_RBRACK,
    STATE(354), 1,
      aux_sym_reduce_rule_repeat2,
  [9422] = 4,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1053), 1,
      anon_sym_DOT,
    ACTIONS(1055), 1,
      anon_sym_SEMI,
    STATE(335), 1,
      aux_sym_output_rule_repeat1,
  [9435] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1110), 1,
      sym_ident,
    STATE(384), 1,
      sym_set_var,
  [9445] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1112), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9453] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1114), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9461] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1116), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9469] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1118), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9477] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1120), 2,
      anon_sym_RBRACK,
      anon_sym_COMMA,
  [9485] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1122), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9493] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1124), 2,
      anon_sym_DOT,
      anon_sym_SEMI,
  [9501] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1126), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9509] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1128), 1,
      anon_sym_LPAREN,
    STATE(297), 1,
      sym_condition,
  [9519] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1130), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9527] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1132), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9535] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1134), 2,
      anon_sym_RBRACK,
      anon_sym_COMMA,
  [9543] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1136), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9551] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1138), 2,
      anon_sym_RBRACK,
      anon_sym_COMMA,
  [9559] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1140), 2,
      anon_sym_RBRACK,
      anon_sym_COMMA,
  [9567] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1142), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9575] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1144), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9583] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1128), 1,
      anon_sym_LPAREN,
    STATE(27), 1,
      sym_condition,
  [9593] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1146), 1,
      anon_sym_LPAREN,
    STATE(117), 1,
      sym_condition,
  [9603] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1148), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9611] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1150), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9619] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1152), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9627] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1154), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9635] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1156), 2,
      anon_sym_RBRACK,
      anon_sym_COMMA,
  [9643] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1158), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9651] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1103), 2,
      anon_sym_RBRACK,
      anon_sym_COMMA,
  [9659] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1160), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9667] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1162), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9675] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1164), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9683] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1012), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [9691] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1166), 2,
      ts_builtin_sym_end,
      sym_ident,
  [9699] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(121), 1,
      aux_sym_num_token1,
    STATE(445), 1,
      sym_num,
  [9709] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1168), 2,
      sym_string,
      sym_ident,
  [9717] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1170), 2,
      ts_builtin_sym_end,
      sym_ident,
  [9725] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1128), 1,
      anon_sym_LPAREN,
    STATE(299), 1,
      sym_condition,
  [9735] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1172), 2,
      ts_builtin_sym_end,
      sym_ident,
  [9743] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1128), 1,
      anon_sym_LPAREN,
    STATE(56), 1,
      sym_condition,
  [9753] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1174), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9761] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1146), 1,
      anon_sym_LPAREN,
    STATE(114), 1,
      sym_condition,
  [9771] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1176), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9779] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1128), 1,
      anon_sym_LPAREN,
    STATE(57), 1,
      sym_condition,
  [9789] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1128), 1,
      anon_sym_LPAREN,
    STATE(287), 1,
      sym_condition,
  [9799] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1178), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9807] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1180), 2,
      sym_string,
      sym_ident,
  [9815] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1065), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9823] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1182), 2,
      ts_builtin_sym_end,
      sym_ident,
  [9831] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1128), 1,
      anon_sym_LPAREN,
    STATE(284), 1,
      sym_condition,
  [9841] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1184), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9849] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1186), 2,
      ts_builtin_sym_end,
      sym_ident,
  [9857] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1188), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9865] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1190), 2,
      ts_builtin_sym_end,
      sym_ident,
  [9873] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1128), 1,
      anon_sym_LPAREN,
    STATE(289), 1,
      sym_condition,
  [9883] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1192), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9891] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1086), 2,
      anon_sym_RBRACK,
      anon_sym_COMMA,
  [9899] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1194), 2,
      ts_builtin_sym_end,
      sym_ident,
  [9907] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1026), 2,
      anon_sym_DOT,
      anon_sym_SEMI,
  [9915] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1128), 1,
      anon_sym_LPAREN,
    STATE(295), 1,
      sym_condition,
  [9925] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1196), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9933] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1198), 2,
      anon_sym_SEMI,
      anon_sym_PIPE,
  [9941] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1110), 1,
      sym_ident,
    STATE(351), 1,
      sym_set_var,
  [9951] = 3,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1110), 1,
      sym_ident,
    STATE(329), 1,
      sym_set_var,
  [9961] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1200), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
  [9969] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1202), 2,
      ts_builtin_sym_end,
      sym_ident,
  [9977] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1204), 2,
      ts_builtin_sym_end,
      sym_ident,
  [9985] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1206), 1,
      anon_sym_RPAREN,
  [9992] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1208), 1,
      anon_sym_RPAREN,
  [9999] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1210), 1,
      sym_ident,
  [10006] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1212), 1,
      sym_ident,
  [10013] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1214), 1,
      anon_sym_RBRACK,
  [10020] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1216), 1,
      anon_sym_RBRACK,
  [10027] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1218), 1,
      sym_ident,
  [10034] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1220), 1,
      sym_ident,
  [10041] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1222), 1,
      anon_sym_RPAREN,
  [10048] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1224), 1,
      anon_sym_RBRACE,
  [10055] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1070), 1,
      sym_ident,
  [10062] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(609), 1,
      anon_sym_AT,
  [10069] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1226), 1,
      anon_sym_DOT,
  [10076] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1228), 1,
      anon_sym_LPAREN,
  [10083] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1230), 1,
      sym_clip_side,
  [10090] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1232), 1,
      anon_sym_EQ,
  [10097] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1234), 1,
      anon_sym_EQ,
  [10104] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(670), 1,
      anon_sym_RPAREN,
  [10111] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(696), 1,
      anon_sym_RPAREN,
  [10118] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(690), 1,
      anon_sym_RPAREN,
  [10125] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1236), 1,
      sym_ident,
  [10132] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1238), 1,
      anon_sym_GT,
  [10139] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1240), 1,
      anon_sym_DOT,
  [10146] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1242), 1,
      sym_ident,
  [10153] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1244), 1,
      anon_sym_LPAREN,
  [10160] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1246), 1,
      anon_sym_COLON,
  [10167] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1248), 1,
      sym_ident,
  [10174] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1250), 1,
      anon_sym_EQ,
  [10181] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1252), 1,
      sym_ident,
  [10188] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(680), 1,
      anon_sym_RPAREN,
  [10195] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1254), 1,
      sym_ident,
  [10202] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1256), 1,
      anon_sym_RPAREN,
  [10209] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(601), 1,
      anon_sym_AT,
  [10216] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1258), 1,
      sym_ident,
  [10223] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1055), 1,
      anon_sym_SEMI,
  [10230] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1260), 1,
      anon_sym_AT,
  [10237] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1262), 1,
      sym_ident,
  [10244] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1264), 1,
      ts_builtin_sym_end,
  [10251] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1266), 1,
      sym_ident,
  [10258] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1268), 1,
      anon_sym_RPAREN,
  [10265] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1270), 1,
      sym_ident,
  [10272] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1272), 1,
      sym_ident,
  [10279] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1274), 1,
      anon_sym_DOT,
  [10286] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1276), 1,
      sym_ident,
  [10293] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1278), 1,
      sym_ident,
  [10300] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1280), 1,
      sym_ident,
  [10307] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1282), 1,
      sym_ident,
  [10314] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1284), 1,
      sym_ident,
  [10321] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1286), 1,
      anon_sym_RPAREN,
  [10328] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1288), 1,
      sym_ident,
  [10335] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1290), 1,
      sym_ident,
  [10342] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1292), 1,
      anon_sym_EQ,
  [10349] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1294), 1,
      anon_sym_AT,
  [10356] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1296), 1,
      anon_sym_EQ,
  [10363] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(619), 1,
      anon_sym_RPAREN,
  [10370] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(639), 1,
      anon_sym_RPAREN,
  [10377] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1298), 1,
      anon_sym_RBRACK,
  [10384] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(716), 1,
      anon_sym_RPAREN,
  [10391] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1300), 1,
      anon_sym_COLON,
  [10398] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1302), 1,
      sym_ident,
  [10405] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1304), 1,
      anon_sym_RPAREN,
  [10412] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(718), 1,
      anon_sym_RPAREN,
  [10419] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1306), 1,
      sym_ident,
  [10426] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(720), 1,
      anon_sym_RPAREN,
  [10433] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1308), 1,
      anon_sym_RPAREN,
  [10440] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1310), 1,
      sym_ident,
  [10447] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1312), 1,
      sym_ident,
  [10454] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1314), 1,
      sym_ident,
  [10461] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(738), 1,
      sym_ident,
  [10468] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1316), 1,
      sym_ident,
  [10475] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1318), 1,
      anon_sym_RPAREN,
  [10482] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1320), 1,
      anon_sym_RPAREN,
  [10489] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(722), 1,
      anon_sym_RPAREN,
  [10496] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1061), 1,
      anon_sym_SEMI,
  [10503] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1322), 1,
      anon_sym_RPAREN,
  [10510] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1324), 1,
      sym_ident,
  [10517] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1326), 1,
      anon_sym_RPAREN,
  [10524] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1328), 1,
      sym_ident,
  [10531] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1330), 1,
      anon_sym_RPAREN,
  [10538] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1332), 1,
      sym_ident,
  [10545] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1334), 1,
      anon_sym_RPAREN,
  [10552] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1336), 1,
      anon_sym_RBRACK,
  [10559] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1338), 1,
      anon_sym_RBRACE,
  [10566] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1340), 1,
      sym_ident,
  [10573] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1342), 1,
      anon_sym_RBRACK,
  [10580] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1344), 1,
      anon_sym_RBRACE,
  [10587] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1346), 1,
      sym_ident,
  [10594] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1348), 1,
      sym_ident,
  [10601] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1350), 1,
      sym_ident,
  [10608] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1352), 1,
      sym_ident,
  [10615] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1354), 1,
      anon_sym_RBRACE,
  [10622] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1356), 1,
      sym_ident,
  [10629] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1358), 1,
      sym_ident,
  [10636] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1360), 1,
      anon_sym_RBRACK,
  [10643] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1362), 1,
      anon_sym_COLON,
  [10650] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1364), 1,
      sym_ident,
  [10657] = 2,
    ACTIONS(3), 1,
      sym_comment,
    ACTIONS(1366), 1,
      sym_ident,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(2)] = 0,
  [SMALL_STATE(3)] = 46,
  [SMALL_STATE(4)] = 92,
  [SMALL_STATE(5)] = 138,
  [SMALL_STATE(6)] = 184,
  [SMALL_STATE(7)] = 227,
  [SMALL_STATE(8)] = 270,
  [SMALL_STATE(9)] = 313,
  [SMALL_STATE(10)] = 356,
  [SMALL_STATE(11)] = 396,
  [SMALL_STATE(12)] = 436,
  [SMALL_STATE(13)] = 476,
  [SMALL_STATE(14)] = 516,
  [SMALL_STATE(15)] = 556,
  [SMALL_STATE(16)] = 596,
  [SMALL_STATE(17)] = 636,
  [SMALL_STATE(18)] = 676,
  [SMALL_STATE(19)] = 716,
  [SMALL_STATE(20)] = 756,
  [SMALL_STATE(21)] = 795,
  [SMALL_STATE(22)] = 834,
  [SMALL_STATE(23)] = 873,
  [SMALL_STATE(24)] = 943,
  [SMALL_STATE(25)] = 1013,
  [SMALL_STATE(26)] = 1083,
  [SMALL_STATE(27)] = 1141,
  [SMALL_STATE(28)] = 1209,
  [SMALL_STATE(29)] = 1277,
  [SMALL_STATE(30)] = 1342,
  [SMALL_STATE(31)] = 1411,
  [SMALL_STATE(32)] = 1461,
  [SMALL_STATE(33)] = 1525,
  [SMALL_STATE(34)] = 1589,
  [SMALL_STATE(35)] = 1653,
  [SMALL_STATE(36)] = 1717,
  [SMALL_STATE(37)] = 1781,
  [SMALL_STATE(38)] = 1845,
  [SMALL_STATE(39)] = 1909,
  [SMALL_STATE(40)] = 1973,
  [SMALL_STATE(41)] = 2014,
  [SMALL_STATE(42)] = 2055,
  [SMALL_STATE(43)] = 2085,
  [SMALL_STATE(44)] = 2145,
  [SMALL_STATE(45)] = 2205,
  [SMALL_STATE(46)] = 2243,
  [SMALL_STATE(47)] = 2281,
  [SMALL_STATE(48)] = 2319,
  [SMALL_STATE(49)] = 2357,
  [SMALL_STATE(50)] = 2417,
  [SMALL_STATE(51)] = 2455,
  [SMALL_STATE(52)] = 2493,
  [SMALL_STATE(53)] = 2531,
  [SMALL_STATE(54)] = 2569,
  [SMALL_STATE(55)] = 2607,
  [SMALL_STATE(56)] = 2645,
  [SMALL_STATE(57)] = 2705,
  [SMALL_STATE(58)] = 2765,
  [SMALL_STATE(59)] = 2825,
  [SMALL_STATE(60)] = 2863,
  [SMALL_STATE(61)] = 2901,
  [SMALL_STATE(62)] = 2934,
  [SMALL_STATE(63)] = 2966,
  [SMALL_STATE(64)] = 2998,
  [SMALL_STATE(65)] = 3026,
  [SMALL_STATE(66)] = 3058,
  [SMALL_STATE(67)] = 3086,
  [SMALL_STATE(68)] = 3140,
  [SMALL_STATE(69)] = 3194,
  [SMALL_STATE(70)] = 3222,
  [SMALL_STATE(71)] = 3276,
  [SMALL_STATE(72)] = 3308,
  [SMALL_STATE(73)] = 3336,
  [SMALL_STATE(74)] = 3364,
  [SMALL_STATE(75)] = 3418,
  [SMALL_STATE(76)] = 3472,
  [SMALL_STATE(77)] = 3499,
  [SMALL_STATE(78)] = 3526,
  [SMALL_STATE(79)] = 3553,
  [SMALL_STATE(80)] = 3580,
  [SMALL_STATE(81)] = 3606,
  [SMALL_STATE(82)] = 3632,
  [SMALL_STATE(83)] = 3658,
  [SMALL_STATE(84)] = 3684,
  [SMALL_STATE(85)] = 3710,
  [SMALL_STATE(86)] = 3736,
  [SMALL_STATE(87)] = 3762,
  [SMALL_STATE(88)] = 3788,
  [SMALL_STATE(89)] = 3814,
  [SMALL_STATE(90)] = 3840,
  [SMALL_STATE(91)] = 3866,
  [SMALL_STATE(92)] = 3892,
  [SMALL_STATE(93)] = 3918,
  [SMALL_STATE(94)] = 3944,
  [SMALL_STATE(95)] = 3970,
  [SMALL_STATE(96)] = 3996,
  [SMALL_STATE(97)] = 4022,
  [SMALL_STATE(98)] = 4048,
  [SMALL_STATE(99)] = 4074,
  [SMALL_STATE(100)] = 4100,
  [SMALL_STATE(101)] = 4126,
  [SMALL_STATE(102)] = 4150,
  [SMALL_STATE(103)] = 4198,
  [SMALL_STATE(104)] = 4222,
  [SMALL_STATE(105)] = 4270,
  [SMALL_STATE(106)] = 4294,
  [SMALL_STATE(107)] = 4342,
  [SMALL_STATE(108)] = 4390,
  [SMALL_STATE(109)] = 4430,
  [SMALL_STATE(110)] = 4472,
  [SMALL_STATE(111)] = 4494,
  [SMALL_STATE(112)] = 4536,
  [SMALL_STATE(113)] = 4578,
  [SMALL_STATE(114)] = 4620,
  [SMALL_STATE(115)] = 4662,
  [SMALL_STATE(116)] = 4704,
  [SMALL_STATE(117)] = 4746,
  [SMALL_STATE(118)] = 4788,
  [SMALL_STATE(119)] = 4830,
  [SMALL_STATE(120)] = 4852,
  [SMALL_STATE(121)] = 4891,
  [SMALL_STATE(122)] = 4930,
  [SMALL_STATE(123)] = 4969,
  [SMALL_STATE(124)] = 4995,
  [SMALL_STATE(125)] = 5021,
  [SMALL_STATE(126)] = 5059,
  [SMALL_STATE(127)] = 5097,
  [SMALL_STATE(128)] = 5135,
  [SMALL_STATE(129)] = 5173,
  [SMALL_STATE(130)] = 5196,
  [SMALL_STATE(131)] = 5227,
  [SMALL_STATE(132)] = 5246,
  [SMALL_STATE(133)] = 5269,
  [SMALL_STATE(134)] = 5288,
  [SMALL_STATE(135)] = 5311,
  [SMALL_STATE(136)] = 5342,
  [SMALL_STATE(137)] = 5365,
  [SMALL_STATE(138)] = 5386,
  [SMALL_STATE(139)] = 5409,
  [SMALL_STATE(140)] = 5432,
  [SMALL_STATE(141)] = 5455,
  [SMALL_STATE(142)] = 5486,
  [SMALL_STATE(143)] = 5521,
  [SMALL_STATE(144)] = 5552,
  [SMALL_STATE(145)] = 5575,
  [SMALL_STATE(146)] = 5608,
  [SMALL_STATE(147)] = 5631,
  [SMALL_STATE(148)] = 5662,
  [SMALL_STATE(149)] = 5685,
  [SMALL_STATE(150)] = 5718,
  [SMALL_STATE(151)] = 5749,
  [SMALL_STATE(152)] = 5772,
  [SMALL_STATE(153)] = 5801,
  [SMALL_STATE(154)] = 5836,
  [SMALL_STATE(155)] = 5865,
  [SMALL_STATE(156)] = 5896,
  [SMALL_STATE(157)] = 5927,
  [SMALL_STATE(158)] = 5958,
  [SMALL_STATE(159)] = 5989,
  [SMALL_STATE(160)] = 6008,
  [SMALL_STATE(161)] = 6026,
  [SMALL_STATE(162)] = 6060,
  [SMALL_STATE(163)] = 6078,
  [SMALL_STATE(164)] = 6096,
  [SMALL_STATE(165)] = 6130,
  [SMALL_STATE(166)] = 6156,
  [SMALL_STATE(167)] = 6182,
  [SMALL_STATE(168)] = 6208,
  [SMALL_STATE(169)] = 6234,
  [SMALL_STATE(170)] = 6260,
  [SMALL_STATE(171)] = 6286,
  [SMALL_STATE(172)] = 6312,
  [SMALL_STATE(173)] = 6338,
  [SMALL_STATE(174)] = 6364,
  [SMALL_STATE(175)] = 6390,
  [SMALL_STATE(176)] = 6416,
  [SMALL_STATE(177)] = 6450,
  [SMALL_STATE(178)] = 6476,
  [SMALL_STATE(179)] = 6510,
  [SMALL_STATE(180)] = 6535,
  [SMALL_STATE(181)] = 6558,
  [SMALL_STATE(182)] = 6583,
  [SMALL_STATE(183)] = 6600,
  [SMALL_STATE(184)] = 6625,
  [SMALL_STATE(185)] = 6648,
  [SMALL_STATE(186)] = 6671,
  [SMALL_STATE(187)] = 6696,
  [SMALL_STATE(188)] = 6717,
  [SMALL_STATE(189)] = 6733,
  [SMALL_STATE(190)] = 6749,
  [SMALL_STATE(191)] = 6771,
  [SMALL_STATE(192)] = 6787,
  [SMALL_STATE(193)] = 6803,
  [SMALL_STATE(194)] = 6823,
  [SMALL_STATE(195)] = 6839,
  [SMALL_STATE(196)] = 6859,
  [SMALL_STATE(197)] = 6881,
  [SMALL_STATE(198)] = 6901,
  [SMALL_STATE(199)] = 6921,
  [SMALL_STATE(200)] = 6937,
  [SMALL_STATE(201)] = 6965,
  [SMALL_STATE(202)] = 6985,
  [SMALL_STATE(203)] = 7001,
  [SMALL_STATE(204)] = 7023,
  [SMALL_STATE(205)] = 7043,
  [SMALL_STATE(206)] = 7059,
  [SMALL_STATE(207)] = 7081,
  [SMALL_STATE(208)] = 7097,
  [SMALL_STATE(209)] = 7113,
  [SMALL_STATE(210)] = 7129,
  [SMALL_STATE(211)] = 7145,
  [SMALL_STATE(212)] = 7169,
  [SMALL_STATE(213)] = 7185,
  [SMALL_STATE(214)] = 7201,
  [SMALL_STATE(215)] = 7217,
  [SMALL_STATE(216)] = 7233,
  [SMALL_STATE(217)] = 7255,
  [SMALL_STATE(218)] = 7276,
  [SMALL_STATE(219)] = 7299,
  [SMALL_STATE(220)] = 7314,
  [SMALL_STATE(221)] = 7335,
  [SMALL_STATE(222)] = 7354,
  [SMALL_STATE(223)] = 7369,
  [SMALL_STATE(224)] = 7384,
  [SMALL_STATE(225)] = 7399,
  [SMALL_STATE(226)] = 7414,
  [SMALL_STATE(227)] = 7437,
  [SMALL_STATE(228)] = 7462,
  [SMALL_STATE(229)] = 7485,
  [SMALL_STATE(230)] = 7500,
  [SMALL_STATE(231)] = 7519,
  [SMALL_STATE(232)] = 7544,
  [SMALL_STATE(233)] = 7567,
  [SMALL_STATE(234)] = 7588,
  [SMALL_STATE(235)] = 7607,
  [SMALL_STATE(236)] = 7621,
  [SMALL_STATE(237)] = 7635,
  [SMALL_STATE(238)] = 7649,
  [SMALL_STATE(239)] = 7663,
  [SMALL_STATE(240)] = 7677,
  [SMALL_STATE(241)] = 7691,
  [SMALL_STATE(242)] = 7711,
  [SMALL_STATE(243)] = 7725,
  [SMALL_STATE(244)] = 7739,
  [SMALL_STATE(245)] = 7753,
  [SMALL_STATE(246)] = 7767,
  [SMALL_STATE(247)] = 7781,
  [SMALL_STATE(248)] = 7801,
  [SMALL_STATE(249)] = 7815,
  [SMALL_STATE(250)] = 7829,
  [SMALL_STATE(251)] = 7843,
  [SMALL_STATE(252)] = 7857,
  [SMALL_STATE(253)] = 7871,
  [SMALL_STATE(254)] = 7885,
  [SMALL_STATE(255)] = 7899,
  [SMALL_STATE(256)] = 7921,
  [SMALL_STATE(257)] = 7935,
  [SMALL_STATE(258)] = 7949,
  [SMALL_STATE(259)] = 7963,
  [SMALL_STATE(260)] = 7977,
  [SMALL_STATE(261)] = 7991,
  [SMALL_STATE(262)] = 8005,
  [SMALL_STATE(263)] = 8019,
  [SMALL_STATE(264)] = 8039,
  [SMALL_STATE(265)] = 8059,
  [SMALL_STATE(266)] = 8073,
  [SMALL_STATE(267)] = 8087,
  [SMALL_STATE(268)] = 8101,
  [SMALL_STATE(269)] = 8115,
  [SMALL_STATE(270)] = 8137,
  [SMALL_STATE(271)] = 8151,
  [SMALL_STATE(272)] = 8171,
  [SMALL_STATE(273)] = 8185,
  [SMALL_STATE(274)] = 8203,
  [SMALL_STATE(275)] = 8225,
  [SMALL_STATE(276)] = 8243,
  [SMALL_STATE(277)] = 8263,
  [SMALL_STATE(278)] = 8277,
  [SMALL_STATE(279)] = 8296,
  [SMALL_STATE(280)] = 8313,
  [SMALL_STATE(281)] = 8332,
  [SMALL_STATE(282)] = 8351,
  [SMALL_STATE(283)] = 8362,
  [SMALL_STATE(284)] = 8373,
  [SMALL_STATE(285)] = 8392,
  [SMALL_STATE(286)] = 8411,
  [SMALL_STATE(287)] = 8422,
  [SMALL_STATE(288)] = 8441,
  [SMALL_STATE(289)] = 8452,
  [SMALL_STATE(290)] = 8467,
  [SMALL_STATE(291)] = 8482,
  [SMALL_STATE(292)] = 8495,
  [SMALL_STATE(293)] = 8512,
  [SMALL_STATE(294)] = 8523,
  [SMALL_STATE(295)] = 8534,
  [SMALL_STATE(296)] = 8553,
  [SMALL_STATE(297)] = 8568,
  [SMALL_STATE(298)] = 8583,
  [SMALL_STATE(299)] = 8602,
  [SMALL_STATE(300)] = 8621,
  [SMALL_STATE(301)] = 8631,
  [SMALL_STATE(302)] = 8647,
  [SMALL_STATE(303)] = 8663,
  [SMALL_STATE(304)] = 8679,
  [SMALL_STATE(305)] = 8695,
  [SMALL_STATE(306)] = 8711,
  [SMALL_STATE(307)] = 8727,
  [SMALL_STATE(308)] = 8743,
  [SMALL_STATE(309)] = 8759,
  [SMALL_STATE(310)] = 8775,
  [SMALL_STATE(311)] = 8791,
  [SMALL_STATE(312)] = 8807,
  [SMALL_STATE(313)] = 8823,
  [SMALL_STATE(314)] = 8839,
  [SMALL_STATE(315)] = 8855,
  [SMALL_STATE(316)] = 8871,
  [SMALL_STATE(317)] = 8887,
  [SMALL_STATE(318)] = 8903,
  [SMALL_STATE(319)] = 8919,
  [SMALL_STATE(320)] = 8935,
  [SMALL_STATE(321)] = 8951,
  [SMALL_STATE(322)] = 8967,
  [SMALL_STATE(323)] = 8980,
  [SMALL_STATE(324)] = 8993,
  [SMALL_STATE(325)] = 9006,
  [SMALL_STATE(326)] = 9019,
  [SMALL_STATE(327)] = 9032,
  [SMALL_STATE(328)] = 9045,
  [SMALL_STATE(329)] = 9058,
  [SMALL_STATE(330)] = 9071,
  [SMALL_STATE(331)] = 9084,
  [SMALL_STATE(332)] = 9097,
  [SMALL_STATE(333)] = 9110,
  [SMALL_STATE(334)] = 9123,
  [SMALL_STATE(335)] = 9136,
  [SMALL_STATE(336)] = 9149,
  [SMALL_STATE(337)] = 9162,
  [SMALL_STATE(338)] = 9175,
  [SMALL_STATE(339)] = 9188,
  [SMALL_STATE(340)] = 9201,
  [SMALL_STATE(341)] = 9214,
  [SMALL_STATE(342)] = 9227,
  [SMALL_STATE(343)] = 9240,
  [SMALL_STATE(344)] = 9253,
  [SMALL_STATE(345)] = 9266,
  [SMALL_STATE(346)] = 9279,
  [SMALL_STATE(347)] = 9292,
  [SMALL_STATE(348)] = 9305,
  [SMALL_STATE(349)] = 9318,
  [SMALL_STATE(350)] = 9331,
  [SMALL_STATE(351)] = 9344,
  [SMALL_STATE(352)] = 9357,
  [SMALL_STATE(353)] = 9370,
  [SMALL_STATE(354)] = 9383,
  [SMALL_STATE(355)] = 9396,
  [SMALL_STATE(356)] = 9409,
  [SMALL_STATE(357)] = 9422,
  [SMALL_STATE(358)] = 9435,
  [SMALL_STATE(359)] = 9445,
  [SMALL_STATE(360)] = 9453,
  [SMALL_STATE(361)] = 9461,
  [SMALL_STATE(362)] = 9469,
  [SMALL_STATE(363)] = 9477,
  [SMALL_STATE(364)] = 9485,
  [SMALL_STATE(365)] = 9493,
  [SMALL_STATE(366)] = 9501,
  [SMALL_STATE(367)] = 9509,
  [SMALL_STATE(368)] = 9519,
  [SMALL_STATE(369)] = 9527,
  [SMALL_STATE(370)] = 9535,
  [SMALL_STATE(371)] = 9543,
  [SMALL_STATE(372)] = 9551,
  [SMALL_STATE(373)] = 9559,
  [SMALL_STATE(374)] = 9567,
  [SMALL_STATE(375)] = 9575,
  [SMALL_STATE(376)] = 9583,
  [SMALL_STATE(377)] = 9593,
  [SMALL_STATE(378)] = 9603,
  [SMALL_STATE(379)] = 9611,
  [SMALL_STATE(380)] = 9619,
  [SMALL_STATE(381)] = 9627,
  [SMALL_STATE(382)] = 9635,
  [SMALL_STATE(383)] = 9643,
  [SMALL_STATE(384)] = 9651,
  [SMALL_STATE(385)] = 9659,
  [SMALL_STATE(386)] = 9667,
  [SMALL_STATE(387)] = 9675,
  [SMALL_STATE(388)] = 9683,
  [SMALL_STATE(389)] = 9691,
  [SMALL_STATE(390)] = 9699,
  [SMALL_STATE(391)] = 9709,
  [SMALL_STATE(392)] = 9717,
  [SMALL_STATE(393)] = 9725,
  [SMALL_STATE(394)] = 9735,
  [SMALL_STATE(395)] = 9743,
  [SMALL_STATE(396)] = 9753,
  [SMALL_STATE(397)] = 9761,
  [SMALL_STATE(398)] = 9771,
  [SMALL_STATE(399)] = 9779,
  [SMALL_STATE(400)] = 9789,
  [SMALL_STATE(401)] = 9799,
  [SMALL_STATE(402)] = 9807,
  [SMALL_STATE(403)] = 9815,
  [SMALL_STATE(404)] = 9823,
  [SMALL_STATE(405)] = 9831,
  [SMALL_STATE(406)] = 9841,
  [SMALL_STATE(407)] = 9849,
  [SMALL_STATE(408)] = 9857,
  [SMALL_STATE(409)] = 9865,
  [SMALL_STATE(410)] = 9873,
  [SMALL_STATE(411)] = 9883,
  [SMALL_STATE(412)] = 9891,
  [SMALL_STATE(413)] = 9899,
  [SMALL_STATE(414)] = 9907,
  [SMALL_STATE(415)] = 9915,
  [SMALL_STATE(416)] = 9925,
  [SMALL_STATE(417)] = 9933,
  [SMALL_STATE(418)] = 9941,
  [SMALL_STATE(419)] = 9951,
  [SMALL_STATE(420)] = 9961,
  [SMALL_STATE(421)] = 9969,
  [SMALL_STATE(422)] = 9977,
  [SMALL_STATE(423)] = 9985,
  [SMALL_STATE(424)] = 9992,
  [SMALL_STATE(425)] = 9999,
  [SMALL_STATE(426)] = 10006,
  [SMALL_STATE(427)] = 10013,
  [SMALL_STATE(428)] = 10020,
  [SMALL_STATE(429)] = 10027,
  [SMALL_STATE(430)] = 10034,
  [SMALL_STATE(431)] = 10041,
  [SMALL_STATE(432)] = 10048,
  [SMALL_STATE(433)] = 10055,
  [SMALL_STATE(434)] = 10062,
  [SMALL_STATE(435)] = 10069,
  [SMALL_STATE(436)] = 10076,
  [SMALL_STATE(437)] = 10083,
  [SMALL_STATE(438)] = 10090,
  [SMALL_STATE(439)] = 10097,
  [SMALL_STATE(440)] = 10104,
  [SMALL_STATE(441)] = 10111,
  [SMALL_STATE(442)] = 10118,
  [SMALL_STATE(443)] = 10125,
  [SMALL_STATE(444)] = 10132,
  [SMALL_STATE(445)] = 10139,
  [SMALL_STATE(446)] = 10146,
  [SMALL_STATE(447)] = 10153,
  [SMALL_STATE(448)] = 10160,
  [SMALL_STATE(449)] = 10167,
  [SMALL_STATE(450)] = 10174,
  [SMALL_STATE(451)] = 10181,
  [SMALL_STATE(452)] = 10188,
  [SMALL_STATE(453)] = 10195,
  [SMALL_STATE(454)] = 10202,
  [SMALL_STATE(455)] = 10209,
  [SMALL_STATE(456)] = 10216,
  [SMALL_STATE(457)] = 10223,
  [SMALL_STATE(458)] = 10230,
  [SMALL_STATE(459)] = 10237,
  [SMALL_STATE(460)] = 10244,
  [SMALL_STATE(461)] = 10251,
  [SMALL_STATE(462)] = 10258,
  [SMALL_STATE(463)] = 10265,
  [SMALL_STATE(464)] = 10272,
  [SMALL_STATE(465)] = 10279,
  [SMALL_STATE(466)] = 10286,
  [SMALL_STATE(467)] = 10293,
  [SMALL_STATE(468)] = 10300,
  [SMALL_STATE(469)] = 10307,
  [SMALL_STATE(470)] = 10314,
  [SMALL_STATE(471)] = 10321,
  [SMALL_STATE(472)] = 10328,
  [SMALL_STATE(473)] = 10335,
  [SMALL_STATE(474)] = 10342,
  [SMALL_STATE(475)] = 10349,
  [SMALL_STATE(476)] = 10356,
  [SMALL_STATE(477)] = 10363,
  [SMALL_STATE(478)] = 10370,
  [SMALL_STATE(479)] = 10377,
  [SMALL_STATE(480)] = 10384,
  [SMALL_STATE(481)] = 10391,
  [SMALL_STATE(482)] = 10398,
  [SMALL_STATE(483)] = 10405,
  [SMALL_STATE(484)] = 10412,
  [SMALL_STATE(485)] = 10419,
  [SMALL_STATE(486)] = 10426,
  [SMALL_STATE(487)] = 10433,
  [SMALL_STATE(488)] = 10440,
  [SMALL_STATE(489)] = 10447,
  [SMALL_STATE(490)] = 10454,
  [SMALL_STATE(491)] = 10461,
  [SMALL_STATE(492)] = 10468,
  [SMALL_STATE(493)] = 10475,
  [SMALL_STATE(494)] = 10482,
  [SMALL_STATE(495)] = 10489,
  [SMALL_STATE(496)] = 10496,
  [SMALL_STATE(497)] = 10503,
  [SMALL_STATE(498)] = 10510,
  [SMALL_STATE(499)] = 10517,
  [SMALL_STATE(500)] = 10524,
  [SMALL_STATE(501)] = 10531,
  [SMALL_STATE(502)] = 10538,
  [SMALL_STATE(503)] = 10545,
  [SMALL_STATE(504)] = 10552,
  [SMALL_STATE(505)] = 10559,
  [SMALL_STATE(506)] = 10566,
  [SMALL_STATE(507)] = 10573,
  [SMALL_STATE(508)] = 10580,
  [SMALL_STATE(509)] = 10587,
  [SMALL_STATE(510)] = 10594,
  [SMALL_STATE(511)] = 10601,
  [SMALL_STATE(512)] = 10608,
  [SMALL_STATE(513)] = 10615,
  [SMALL_STATE(514)] = 10622,
  [SMALL_STATE(515)] = 10629,
  [SMALL_STATE(516)] = 10636,
  [SMALL_STATE(517)] = 10643,
  [SMALL_STATE(518)] = 10650,
  [SMALL_STATE(519)] = 10657,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [7] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [11] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 2, 0, 19),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [15] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 2, 0, 19),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [19] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 3, 0, 27),
  [21] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [23] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 3, 0, 27),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [27] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 4, 0, 41),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [31] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 4, 0, 41),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [35] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 4, 0, 44),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [39] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 4, 0, 44),
  [41] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [43] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 4, 0, 42),
  [45] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 4, 0, 42),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [49] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 3, 0, 28),
  [51] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 3, 0, 28),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(451),
  [55] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 5, 0, 56),
  [57] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 5, 0, 56),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [61] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 5, 0, 59),
  [63] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 5, 0, 59),
  [65] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 6, 0, 70),
  [67] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 6, 0, 70),
  [69] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 2, 0, 18),
  [71] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 2, 0, 18),
  [73] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 4, 0, 43),
  [75] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 4, 0, 43),
  [77] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 7, 0, 74),
  [79] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 7, 0, 74),
  [81] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 1, 0, 11),
  [83] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 1, 0, 11),
  [85] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 6, 0, 68),
  [87] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 6, 0, 68),
  [89] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 5, 0, 57),
  [91] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 5, 0, 57),
  [93] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 5, 0, 58),
  [95] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 5, 0, 58),
  [97] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 6, 0, 69),
  [99] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 6, 0, 69),
  [101] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_clip, 7, 0, 75),
  [103] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_clip, 7, 0, 75),
  [105] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_cond, 3, 0, 0),
  [107] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_cond, 3, 0, 0),
  [109] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_cond, 4, 0, 0),
  [111] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_cond, 4, 0, 0),
  [113] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_cond, 5, 0, 0),
  [115] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_cond, 5, 0, 0),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(40),
  [121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(449),
  [125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(66),
  [137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(417),
  [141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(142),
  [143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(25),
  [145] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0), SHIFT_REPEAT(40),
  [148] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0), SHIFT_REPEAT(40),
  [151] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0), SHIFT_REPEAT(42),
  [154] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0), SHIFT_REPEAT(449),
  [157] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0), SHIFT_REPEAT(276),
  [160] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0), SHIFT_REPEAT(223),
  [163] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0), SHIFT_REPEAT(291),
  [166] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0), SHIFT_REPEAT(34),
  [169] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0), SHIFT_REPEAT(231),
  [172] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0), SHIFT_REPEAT(66),
  [175] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0), SHIFT_REPEAT(33),
  [178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0),
  [180] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0), SHIFT_REPEAT(142),
  [183] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_reduce_output_repeat1, 2, 0, 0), SHIFT_REPEAT(24),
  [186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [188] = {.entry = {.count = 1, .reusable = false}}, SHIFT(24),
  [190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [194] = {.entry = {.count = 1, .reusable = false}}, SHIFT(212),
  [196] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [200] = {.entry = {.count = 1, .reusable = false}}, SHIFT(214),
  [202] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [206] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [212] = {.entry = {.count = 1, .reusable = false}}, SHIFT(152),
  [214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(36),
  [222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(192),
  [226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(153),
  [230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(239),
  [232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(431),
  [234] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_output_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(40),
  [237] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_output_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(40),
  [240] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_output_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(42),
  [243] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_output_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(449),
  [246] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_output_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(276),
  [249] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_output_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(223),
  [252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_output_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(291),
  [255] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_output_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(34),
  [258] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_output_chunk_repeat1, 2, 0, 0),
  [260] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_output_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(281),
  [263] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_output_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(66),
  [266] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_output_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(142),
  [269] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_output_chunk_repeat1, 2, 0, 0), SHIFT_REPEAT(29),
  [272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [274] = {.entry = {.count = 1, .reusable = false}}, SHIFT(14),
  [276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(433),
  [278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(515),
  [282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(447),
  [288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(29),
  [296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(32),
  [300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(35),
  [304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(38),
  [310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(253),
  [312] = {.entry = {.count = 1, .reusable = false}}, SHIFT(39),
  [314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_element, 1, 0, 0),
  [320] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_element, 1, 0, 0),
  [322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(419),
  [324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [328] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_element, 2, 0, 0),
  [330] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_element, 2, 0, 0),
  [332] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_num, 1, 0, 0),
  [334] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_num, 1, 0, 0),
  [336] = {.entry = {.count = 1, .reusable = false}}, SHIFT(370),
  [338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 4, 0, 25),
  [340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 4, 0, 25),
  [342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [344] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 4, 0, 26),
  [346] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 4, 0, 26),
  [348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_element, 4, 0, 0),
  [350] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_element, 4, 0, 0),
  [352] = {.entry = {.count = 1, .reusable = false}}, SHIFT(363),
  [354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 5, 0, 38),
  [356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 5, 0, 38),
  [358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 5, 0, 39),
  [360] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 5, 0, 39),
  [362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 5, 0, 40),
  [364] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 5, 0, 40),
  [366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 6, 0, 53),
  [368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 6, 0, 53),
  [370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 6, 0, 55),
  [372] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 6, 0, 55),
  [374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [376] = {.entry = {.count = 1, .reusable = false}}, SHIFT(246),
  [378] = {.entry = {.count = 1, .reusable = false}}, SHIFT(454),
  [380] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 3, 0, 17),
  [382] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 3, 0, 17),
  [384] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_element, 3, 0, 0),
  [386] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_element, 3, 0, 0),
  [388] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_literal_lu_repeat1, 2, 0, 36),
  [390] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_literal_lu_repeat1, 2, 0, 36),
  [392] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literal_lu_repeat1, 2, 0, 36), SHIFT_REPEAT(302),
  [395] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_element, 5, 0, 0),
  [397] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_element, 5, 0, 0),
  [399] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_literal_lu_repeat1, 2, 0, 34),
  [401] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_literal_lu_repeat1, 2, 0, 34),
  [403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_null_lu, 1, 0, 0),
  [405] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_null_lu, 1, 0, 0),
  [407] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_literal_lu_repeat1, 3, 0, 50),
  [409] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_literal_lu_repeat1, 3, 0, 50),
  [411] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_literal_lu_repeat1, 4, 0, 64),
  [413] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_literal_lu_repeat1, 4, 0, 64),
  [415] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_literal_lu_repeat1, 4, 0, 65),
  [417] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_literal_lu_repeat1, 4, 0, 65),
  [419] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lu_cond, 3, 0, 0),
  [421] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lu_cond, 3, 0, 0),
  [423] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lu_cond, 4, 0, 0),
  [425] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lu_cond, 4, 0, 0),
  [427] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_macro_name, 3, 0, 0),
  [429] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_macro_name, 3, 0, 0),
  [431] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lu_cond, 5, 0, 0),
  [433] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lu_cond, 5, 0, 0),
  [435] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 5, 0, 35),
  [437] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 5, 0, 35),
  [439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_var_set, 4, 0, 0),
  [441] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_var_set, 4, 0, 0),
  [443] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 5, 0, 37),
  [445] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 5, 0, 37),
  [447] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 6, 0, 51),
  [449] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 6, 0, 51),
  [451] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 6, 0, 52),
  [453] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 6, 0, 52),
  [455] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 6, 0, 54),
  [457] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 6, 0, 54),
  [459] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_element, 6, 0, 0),
  [461] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_element, 6, 0, 0),
  [463] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk_cond, 4, 0, 0),
  [465] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_chunk_cond, 4, 0, 0),
  [467] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk_cond, 3, 0, 0),
  [469] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_chunk_cond, 3, 0, 0),
  [471] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_var_set, 3, 0, 0),
  [473] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_var_set, 3, 0, 0),
  [475] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 7, 0, 67),
  [477] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 7, 0, 67),
  [479] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 4, 0, 24),
  [481] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 4, 0, 24),
  [483] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk_cond, 5, 0, 0),
  [485] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_chunk_cond, 5, 0, 0),
  [487] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_lu, 7, 0, 66),
  [489] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_lu, 7, 0, 66),
  [491] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lu_sequence, 3, 0, 0),
  [493] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lu_sequence, 3, 0, 0),
  [495] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lu_sequence, 2, 0, 0),
  [497] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lu_sequence, 2, 0, 0),
  [499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_chunk, 3, 0, 0),
  [501] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_chunk, 3, 0, 0),
  [503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [505] = {.entry = {.count = 1, .reusable = false}}, SHIFT(124),
  [507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [515] = {.entry = {.count = 1, .reusable = false}}, SHIFT(182),
  [517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [519] = {.entry = {.count = 1, .reusable = false}}, SHIFT(405),
  [521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_not, 1, 0, 0),
  [523] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_not, 1, 0, 0),
  [525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [527] = {.entry = {.count = 1, .reusable = false}}, SHIFT(393),
  [529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_chunk, 2, 0, 0),
  [531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_output_chunk, 2, 0, 0),
  [533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [535] = {.entry = {.count = 1, .reusable = false}}, SHIFT(415),
  [537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [539] = {.entry = {.count = 1, .reusable = false}}, SHIFT(400),
  [541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_rule_repeat1, 2, 0, 0), SHIFT_REPEAT(455),
  [544] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_reduce_rule_repeat1, 2, 0, 0), SHIFT_REPEAT(124),
  [547] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_rule_repeat1, 2, 0, 0), SHIFT_REPEAT(433),
  [550] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_rule_repeat1, 2, 0, 0), SHIFT_REPEAT(274),
  [553] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_rule_repeat1, 2, 0, 0), SHIFT_REPEAT(491),
  [556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_reduce_rule_repeat1, 2, 0, 0),
  [558] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_reduce_rule_repeat1, 2, 0, 0), SHIFT_REPEAT(182),
  [561] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_reduce_rule_repeat1, 2, 0, 0),
  [563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_condition, 3, 0, 0),
  [571] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_condition, 3, 0, 0),
  [573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(382),
  [579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(288),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_else_tok, 1, 0, 0),
  [591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_else_tok, 1, 0, 0),
  [593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_element, 2, 0, 3),
  [605] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_element, 2, 0, 3),
  [607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_element, 1, 0, 1),
  [613] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_element, 1, 0, 1),
  [615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_element, 3, 0, 6),
  [617] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_element, 3, 0, 6),
  [619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [623] = {.entry = {.count = 1, .reusable = false}}, SHIFT(194),
  [625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_or, 1, 0, 0),
  [629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_or, 1, 0, 0),
  [631] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_element, 6, 0, 22),
  [633] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_element, 6, 0, 22),
  [635] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_element, 3, 0, 3),
  [637] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_element, 3, 0, 3),
  [639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [641] = {.entry = {.count = 1, .reusable = false}}, SHIFT(119),
  [643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_element, 4, 0, 6),
  [647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_element, 4, 0, 6),
  [649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_clip, 2, 0, 0),
  [651] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_clip, 2, 0, 0),
  [653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [655] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_pattern_element_repeat1, 2, 0, 0),
  [657] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_pattern_element_repeat1, 2, 0, 0),
  [659] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_pattern_element_repeat1, 2, 0, 0), SHIFT_REPEAT(273),
  [662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_element, 4, 0, 14),
  [664] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_element, 4, 0, 14),
  [666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_element, 4, 0, 15),
  [668] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_element, 4, 0, 15),
  [670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [674] = {.entry = {.count = 1, .reusable = false}}, SHIFT(41),
  [676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_element, 2, 0, 1),
  [684] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_element, 2, 0, 1),
  [686] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_element, 5, 0, 14),
  [688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_element, 5, 0, 14),
  [690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_element, 5, 0, 22),
  [694] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_element, 5, 0, 22),
  [696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_element, 5, 0, 15),
  [700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_element, 5, 0, 15),
  [702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [710] = {.entry = {.count = 1, .reusable = false}}, SHIFT(154),
  [712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_and, 1, 0, 0),
  [726] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_and, 1, 0, 0),
  [728] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pattern_clip, 3, 0, 0),
  [730] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pattern_clip, 3, 0, 0),
  [732] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attr_set_insert, 3, 0, 0),
  [734] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attr_set_insert, 3, 0, 0),
  [736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(427),
  [740] = {.entry = {.count = 1, .reusable = false}}, SHIFT(340),
  [742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(470),
  [746] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_string_cond_repeat1, 2, 0, 0),
  [748] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_cond_repeat1, 2, 0, 0), SHIFT_REPEAT(436),
  [751] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_cond_repeat1, 2, 0, 0),
  [753] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unknown, 1, 0, 0),
  [755] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unknown, 1, 0, 0),
  [757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_lu_cond_repeat1, 2, 0, 0),
  [759] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_lu_cond_repeat1, 2, 0, 0), SHIFT_REPEAT(436),
  [762] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_lu_cond_repeat1, 2, 0, 0),
  [764] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_chunk_cond_repeat1, 2, 0, 0),
  [766] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_chunk_cond_repeat1, 2, 0, 0), SHIFT_REPEAT(436),
  [769] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_chunk_cond_repeat1, 2, 0, 0),
  [771] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_literal_lu_repeat1, 2, 0, 36), SHIFT_REPEAT(301),
  [774] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_str_op_contains, 1, 0, 0),
  [776] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_str_op_contains, 1, 0, 0),
  [778] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_str_op_in, 1, 0, 0),
  [780] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_str_op_in, 1, 0, 0),
  [782] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [784] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(269),
  [787] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(337),
  [791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(496),
  [793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [797] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_str_op, 1, 0, 0),
  [799] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_str_op, 1, 0, 0),
  [801] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_str_op_eq, 1, 0, 0),
  [803] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_str_op_eq, 1, 0, 0),
  [805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_str_op_isprefix, 1, 0, 0),
  [813] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_str_op_isprefix, 1, 0, 0),
  [815] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_str_op_hasprefix, 1, 0, 0),
  [817] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_str_op_hasprefix, 1, 0, 0),
  [819] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_str_op_issuffix, 1, 0, 0),
  [821] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_str_op_issuffix, 1, 0, 0),
  [823] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_str_op_hassuffix, 1, 0, 0),
  [825] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_str_op_hassuffix, 1, 0, 0),
  [827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(168),
  [835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [837] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__cond_bool, 2, 0, 0),
  [839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__cond_bool, 3, 0, 0),
  [849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_insert, 1, 0, 0),
  [851] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_insert, 1, 0, 0),
  [853] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_arrow, 1, 0, 0),
  [855] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_arrow, 1, 0, 0),
  [857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [859] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(447),
  [863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(60),
  [869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [875] = {.entry = {.count = 1, .reusable = false}}, SHIFT(48),
  [877] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attr_rule_repeat1, 2, 0, 0), SHIFT_REPEAT(233),
  [880] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attr_rule_repeat1, 2, 0, 0),
  [882] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attr_rule_repeat1, 2, 0, 0), SHIFT_REPEAT(491),
  [885] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attr_rule_repeat1, 2, 0, 0), SHIFT_REPEAT(430),
  [888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [890] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk_elif_choice, 3, 0, 12),
  [892] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_chunk_elif_choice, 3, 0, 12),
  [894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lu_if_choice, 3, 0, 12),
  [896] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lu_if_choice, 3, 0, 12),
  [898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk_if_choice, 3, 0, 12),
  [900] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_chunk_if_choice, 3, 0, 12),
  [902] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_if_choice, 3, 0, 12),
  [904] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_if_choice, 3, 0, 12),
  [906] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lu_elif_choice, 3, 0, 12),
  [908] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_lu_elif_choice, 3, 0, 12),
  [910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(357),
  [912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [916] = {.entry = {.count = 1, .reusable = false}}, SHIFT(171),
  [918] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_reduce_rule_group_repeat1, 1, 0, 0),
  [920] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_reduce_rule_group_repeat1, 1, 0, 0),
  [922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [928] = {.entry = {.count = 1, .reusable = false}}, SHIFT(47),
  [930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(453),
  [934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [942] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_elif_choice, 3, 0, 12),
  [944] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_elif_choice, 3, 0, 12),
  [946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(118),
  [952] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__cond_base_bool, 3, 0, 0),
  [954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [960] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__cond_base_bool, 4, 0, 0),
  [962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [964] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_inserted, 1, 0, 0),
  [966] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_inserted, 1, 0, 0),
  [968] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_colon, 1, 0, 0),
  [970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [974] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attr_default, 4, 0, 10),
  [976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [982] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [988] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [990] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [1000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [1002] = {.entry = {.count = 1, .reusable = false}}, SHIFT(326),
  [1004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [1006] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [1008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [1010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [1012] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_retag_rule_repeat1, 2, 0, 0),
  [1014] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_retag_rule_repeat1, 2, 0, 0), SHIFT_REPEAT(279),
  [1017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [1019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [1021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [1023] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_output_rule_repeat1, 2, 0, 0), SHIFT_REPEAT(333),
  [1026] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_output_rule_repeat1, 2, 0, 0),
  [1028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_reduce_rule_group_repeat1, 2, 0, 0),
  [1030] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_reduce_rule_group_repeat1, 2, 0, 0), SHIFT_REPEAT(326),
  [1033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [1035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [1037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [1039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [1041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [1043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [1045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [1047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [1049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [1051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(414),
  [1053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [1055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [1057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(407),
  [1059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [1061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [1063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [1065] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_reduce_rule_group_repeat2, 2, 0, 0),
  [1067] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_rule_group_repeat2, 2, 0, 0), SHIFT_REPEAT(120),
  [1070] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attr_prefix, 1, 0, 0),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [1076] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [1078] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [1080] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1082] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [1084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [1086] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_reduce_rule_repeat2, 2, 0, 0),
  [1088] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_reduce_rule_repeat2, 2, 0, 0), SHIFT_REPEAT(196),
  [1091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [1093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [1095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [1097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [1099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [1101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [1103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_output_var_set_repeat1, 2, 0, 0),
  [1105] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_output_var_set_repeat1, 2, 0, 0), SHIFT_REPEAT(358),
  [1108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [1110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [1112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 7, 0, 45),
  [1114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 7, 0, 46),
  [1116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 7, 0, 47),
  [1118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 6, 0, 29),
  [1120] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_surf, 5, 0, 48),
  [1122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 7, 0, 49),
  [1124] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lit_tag, 3, 0, 0),
  [1126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 6, 0, 30),
  [1128] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [1130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 8, 0, 60),
  [1132] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 8, 0, 61),
  [1134] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_global_var, 4, 0, 31),
  [1136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 8, 0, 62),
  [1138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_global_str, 4, 0, 31),
  [1140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_chunk_attr, 4, 0, 31),
  [1142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 8, 0, 63),
  [1144] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 6, 0, 32),
  [1146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [1148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 9, 0, 71),
  [1150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 9, 0, 72),
  [1152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 9, 0, 73),
  [1154] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_output, 3, 0, 0),
  [1156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_var, 3, 0, 33),
  [1158] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 10, 0, 76),
  [1160] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 10, 0, 77),
  [1162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 11, 0, 78),
  [1164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 4, 0, 16),
  [1166] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_retag_rule, 7, 0, 9),
  [1168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [1170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attr_rule, 4, 0, 2),
  [1172] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_rule, 4, 0, 1),
  [1174] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_output, 1, 0, 0),
  [1176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 2, 0, 4),
  [1178] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 3, 0, 7),
  [1180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [1182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule_group, 5, 0, 0),
  [1184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 5, 0, 20),
  [1186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_rule, 6, 0, 1),
  [1188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 5, 0, 21),
  [1190] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule_group, 4, 0, 0),
  [1192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 5, 0, 23),
  [1194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attr_rule, 5, 0, 2),
  [1196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_rule, 4, 0, 13),
  [1198] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_reduce_output, 2, 0, 0),
  [1200] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attr_pair, 2, 0, 8),
  [1202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_retag_rule, 6, 0, 9),
  [1204] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_output_rule, 5, 0, 1),
  [1206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_else_choice, 2, 0, 5),
  [1208] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [1210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [1212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [1214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [1216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [1218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [1220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [1222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lu_always_choice, 2, 0, 5),
  [1224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [1226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [1228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_elif_tok, 1, 0, 0),
  [1230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [1232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [1234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [1236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(3),
  [1238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [1240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [1242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(475),
  [1244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_if_tok, 1, 0, 0),
  [1246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [1248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [1250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [1252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [1254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [1256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lu_else_choice, 2, 0, 5),
  [1258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [1260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [1262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [1264] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [1266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [1268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [1270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [1272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [1274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [1276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [1278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [1280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [1282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(448),
  [1284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [1286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(300),
  [1288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [1290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [1292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [1294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [1296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [1298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [1300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(149),
  [1302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [1304] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk_always_choice, 2, 0, 5),
  [1306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [1308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [1310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [1312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [1314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [1316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [1318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_chunk_else_choice, 2, 0, 5),
  [1320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [1322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [1324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [1326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [1328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [1330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [1332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [1334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_always_choice, 2, 0, 5),
  [1336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [1338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [1340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [1342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [1344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [1346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [1348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [1350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [1352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [1354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [1356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [1358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [1360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [1362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [1364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2),
  [1366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_rtx(void) {
  static const TSLanguage language = {
    .version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
